(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    120229,       2764]
NotebookOptionsPosition[    110194,       2632]
NotebookOutlinePosition[    110532,       2647]
CellTagsIndexPosition[    110489,       2644]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["K\[RHacek]iv\[AAcute]nek\[CloseCurlyQuote]s walk", "Title",
 CellChangeTimes->{{3.801272573653221*^9, 3.801272575020199*^9}, {
  3.8025924073871717`*^9, 3.8025924094124813`*^9}, {3.8065542028166437`*^9, 
  3.806554208694776*^9}},ExpressionUUID->"824dcfa0-5751-4b99-b500-\
b5712eea01a9"],

Cell["\<\
The zero-variance estimator for reflectance from a half rod with isotropic \
scattering\
\>", "Subtitle",
 CellChangeTimes->{{3.801272578060986*^9, 
  3.801272589824136*^9}},ExpressionUUID->"4f7f9a71-5f70-49fb-8169-\
5456dfc05bb5"],

Cell[TextData[{
 "Jaroslav K\[RHacek]iv\[AAcute]nek and Eugene d\[CloseCurlyQuote]Eon\
\[LineSeparator]\[LineSeparator]Supplemental material for ",
 StyleBox["SIGGRAPH 2020",
  FontWeight->"Bold"],
 " course: ",
 StyleBox["Advances in Monte Carlo Rendering: The Legacy of Jaroslav Krivanek",
  FontSlant->"Italic"],
 ".  https://doi.org/10.1145/3388769.3407458"
}], "Text",
 CellChangeTimes->{{3.8025926324724073`*^9, 3.802592646996422*^9}, {
  3.802592692084893*^9, 3.802592707091778*^9}, {3.802592745948763*^9, 
  3.802592782135564*^9}, {3.806554214120068*^9, 
  3.806554240540545*^9}},ExpressionUUID->"d12bce77-43ca-4973-b43c-\
c30004240db1"],

Cell[CellGroupData[{

Cell["Derivation and testing", "Section",
 CellChangeTimes->{{3.802592657270426*^9, 
  3.802592682808978*^9}},ExpressionUUID->"59874e66-23fc-4f24-b422-\
60e6c7ca74dd"],

Cell["GRT statistics for classical exponential radiative transfer:", "Text",
 CellChangeTimes->{{3.801272552713798*^9, 
  3.801272568339239*^9}},ExpressionUUID->"6c6ecae1-e24a-48b3-961c-\
b884a480f85c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pc", "[", "s_", "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"-", "s"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pu", "[", "s_", "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"-", "s"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Xc", "[", "s_", "]"}], ":=", 
  RowBox[{"Exp", "[", 
   RowBox[{"-", "s"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.8012582863872213`*^9, 3.801258294372871*^9}, {
  3.8012685707636023`*^9, 3.8012685709353857`*^9}},
 CellLabel->"In[75]:=",ExpressionUUID->"4c791002-f550-4b50-86ef-cd21cf91b294"],

Cell[TextData[{
 "The ",
 StyleBox["importance-to-escape",
  FontWeight->"Bold"],
 " function for entering a collision at position x in the rod:"
}], "Text",
 CellChangeTimes->{{3.801272597544509*^9, 
  3.80127261581007*^9}},ExpressionUUID->"7b3ed350-b501-4db3-860a-\
28f9ededf6ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"W", "[", 
   RowBox[{"x_", ",", "\[Alpha]_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"HeavisideTheta", "[", "x", "]"}], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SqrtBox[
       RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}], " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       SqrtBox[
        RowBox[{"1", "-", "\[Alpha]"}]]}], " ", "x"}]]}], "+", 
   RowBox[{"HeavisideTheta", "[", 
    RowBox[{"-", "x"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.801258310960352*^9, 3.8012583171687717`*^9}, {
   3.801258488474766*^9, 3.80125851551084*^9}, 3.801360057371625*^9},
 CellLabel->"In[78]:=",ExpressionUUID->"6c518972-df53-463a-b986-b39e60b8ffe4"],

Cell["Verify the albedo calculation:", "Text",
 CellChangeTimes->{{3.801272810549406*^9, 
  3.801272814968199*^9}},ExpressionUUID->"dd28e819-9f0e-4742-8e92-\
994d7c818dab"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["2", "\[Alpha]"], 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", "1"}], "==", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"pu", "[", "s", "]"}], 
      RowBox[{"W", "[", 
       RowBox[{"s", ",", "\[Alpha]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"s", ",", "0", ",", "Infinity"}], "}"}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"0", "<", "\[Alpha]", "<", "1"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.80127265214179*^9, 3.801272684416912*^9}, 
   3.801360060627524*^9},
 CellLabel->"In[79]:=",ExpressionUUID->"7b68c253-5f76-4fbe-9c97-f4aeb9fc7a0a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.801272659496017*^9, 3.801272685133889*^9}, 
   3.8012732654897614`*^9, 3.80127341240091*^9, {3.801360061117462*^9, 
   3.801360085060748*^9}},
 CellLabel->"Out[79]=",ExpressionUUID->"4fea19d9-38c9-4338-a4f9-ac6ea84aecac"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"R", "[", "\[Alpha]_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox["2", "\[Alpha]"], 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SqrtBox[
       RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}], "-", "1"}]}]], "Input",
 CellChangeTimes->{3.801272822940859*^9},
 CellLabel->"In[80]:=",ExpressionUUID->"eb44641d-91db-4551-a0d3-3be31fcce33c"],

Cell["Distribution for sampling initial collision depth:", "Text",
 CellChangeTimes->{{3.801272828168645*^9, 
  3.8012728363060102`*^9}},ExpressionUUID->"2c8b3dd8-bb4f-4805-8e99-\
c1151dceb5dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"p1", "[", 
   RowBox[{"x_", ",", "\[Alpha]_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"pu", "[", "x", "]"}], 
   FractionBox[
    RowBox[{"W", "[", 
     RowBox[{"x", ",", "\[Alpha]"}], "]"}], 
    RowBox[{"R", "[", "\[Alpha]", "]"}]]}]}]], "Input",
 CellChangeTimes->{{3.801258372723875*^9, 3.801258378124407*^9}, {
   3.801258523393538*^9, 3.801258552760086*^9}, 3.8013600632237597`*^9},
 CellLabel->"In[81]:=",ExpressionUUID->"3935c173-18db-409f-8883-dc0b399276aa"],

Cell[BoxData[
 RowBox[{
  RowBox[{"samplex1", "[", "\[Alpha]_", "]"}], ":=", 
  FractionBox[
   RowBox[{"-", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", 
      RowBox[{"RandomReal", "[", "]"}]}], "]"}]}], 
   RowBox[{"1", "+", 
    SqrtBox[
     RowBox[{"1", "-", "\[Alpha]"}]]}]]}]], "Input",
 CellLabel->"In[82]:=",ExpressionUUID->"9b9721b5-b9cf-4381-9e1d-6c4306657b56"],

Cell["\<\
Probability to scattering into the positive (deeper) direction:\
\>", "Text",
 CellChangeTimes->{{3.801272864942371*^9, 
  3.8012728732996893`*^9}},ExpressionUUID->"ab138e7e-cb39-4324-8b59-\
bc62c8bc99f9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pplus", "[", "\[Alpha]_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SqrtBox[
      RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.801258603724235*^9, 3.8012586173585777`*^9}},
 CellLabel->
  "In[159]:=",ExpressionUUID->"26f623a8-34b3-44ad-a3a8-1dc961b95e86"],

Cell["\<\
Free-path (FP) length sampling in the outward (negative) direction:\
\>", "Text",
 CellChangeTimes->{{3.801272989403164*^9, 3.801272998241613*^9}, {
  3.8012730917781963`*^9, 
  3.8012730924200153`*^9}},ExpressionUUID->"58f2f805-5ac8-42c5-aa5c-\
a84faba99ddd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleFPNegative", "[", "\[Alpha]_", "]"}], ":=", 
  FractionBox[
   RowBox[{"-", 
    RowBox[{"Log", "[", 
     RowBox[{"1", "-", 
      RowBox[{"RandomReal", "[", "]"}]}], "]"}]}], 
   RowBox[{"1", "-", 
    SqrtBox[
     RowBox[{"1", "-", "\[Alpha]"}]]}]]}]], "Input",
 CellChangeTimes->{{3.8012730093714333`*^9, 3.8012730229765263`*^9}},
 CellLabel->"In[84]:=",ExpressionUUID->"7534810d-deee-47b1-be64-400c26183171"],

Cell[BoxData[
 RowBox[{
  RowBox[{"FPNegativePDF", "[", 
   RowBox[{"s_", ",", "x_", ",", "\[Alpha]_"}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "s"}], " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       SqrtBox[
        RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}]], " ", 
   RowBox[{"(", 
    RowBox[{"1", "-", 
     SqrtBox[
      RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}]}]], "Input",
 CellChangeTimes->{{3.801273336555468*^9, 3.801273404358305*^9}},
 CellLabel->"In[85]:=",ExpressionUUID->"9048dd49-a5bf-487a-93f0-a0a43de71fcd"],

Cell["\<\
Probability that we escape the medium when flying in the negative direction:\
\>", "Text",
 CellChangeTimes->{{3.8012731033697453`*^9, 3.801273114753635*^9}, {
  3.801374456139883*^9, 
  3.801374459282194*^9}},ExpressionUUID->"6693868f-016b-4a05-93ed-\
dd968a07f6ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"probEscape", "[", 
   RowBox[{"x_", ",", "\[Alpha]_"}], "]"}], ":=", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "x"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      SqrtBox[
       RowBox[{"1", "-", "\[Alpha]"}]]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.8012733938800583`*^9, 3.801273396394343*^9}, {
  3.8013744452597*^9, 3.801374450610569*^9}},
 CellLabel->
  "In[156]:=",ExpressionUUID->"0daf29b4-16e9-49e7-b546-a603c362d68f"],

Cell[CellGroupData[{

Cell["The zero variance random walk:", "Subsection",
 CellChangeTimes->{{3.801273131993462*^9, 
  3.801273136431582*^9}},ExpressionUUID->"81721721-dff7-454c-a8a9-\
ad0b8dfa50dc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ZeroVarianceHalfRod", "[", "\[Alpha]_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "w", ",", "s", ",", "count"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"w", "=", "1"}], ";", 
     RowBox[{"(*", " ", 
      RowBox[{
      "particle", " ", "begins", " ", "with", " ", "unit", " ", "weight"}], 
      " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"x", "=", 
      RowBox[{"samplex1", "[", "\[Alpha]", "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "sample", " ", "the", " ", "first", " ", "collision", " ", "depth", " ",
        "from", " ", "p1"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"w", "*=", 
      FractionBox[
       RowBox[{"pu", "[", "x", "]"}], 
       RowBox[{"p1", "[", 
        RowBox[{"x", ",", "\[Alpha]"}], "]"}]]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "adjust", " ", "weight", " ", "due", " ", "to", " ", "sampling", " ", 
       "guided", " ", "first", " ", "depth"}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"x", ">", "0"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
          RowBox[{"\"\<x: \>\"", "<>", 
           RowBox[{"ToString", "[", "x", "]"}], "<>", 
           "\"\<, \\tw * W[x]: \>\""}], ",", 
          RowBox[{"w", " ", "*", " ", 
           RowBox[{"W", "[", 
            RowBox[{"x", ",", "\[Alpha]"}], "]"}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"w", "*=", "\[Alpha]"}], ";", " ", 
        RowBox[{"(*", " ", 
         RowBox[{"absorb", " ", "with", " ", "implicit", " ", "capture"}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"RandomReal", "[", "]"}], "<", 
           RowBox[{"pplus", "[", "\[Alpha]", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"sample", " ", "positive", " ", "direction"}], " ", "*)"}],
           "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"w", "*=", 
            FractionBox[
             RowBox[{"(", 
              RowBox[{"1", "/", "2"}], ")"}], 
             RowBox[{"pplus", "[", "\[Alpha]", "]"}]]}], ";", " ", 
           RowBox[{"(*", " ", 
            RowBox[{
            "weight", " ", "adjustment", " ", "for", " ", "guided", " ", 
             "phase", " ", "function", " ", "sampling"}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"s", "=", 
            RowBox[{"samplex1", "[", "\[Alpha]", "]"}]}], ";", 
           RowBox[{"w", "*=", 
            FractionBox[
             RowBox[{"pc", "[", "s", "]"}], 
             RowBox[{"p1", "[", 
              RowBox[{"s", ",", "\[Alpha]"}], "]"}]]}], ";", 
           RowBox[{"x", "+=", "s"}], ";"}], " ", 
          RowBox[{"(*", " ", 
           RowBox[{
            RowBox[{"\"\<+\>\"", " ", "free"}], "-", 
            RowBox[{"path", " ", "sampling"}]}], " ", "*)"}], 
          "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"sample", " ", "negative", " ", "direction"}], " ", "*)"}],
           "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"w", "*=", 
            FractionBox[
             RowBox[{"(", 
              RowBox[{"1", "/", "2"}], ")"}], 
             RowBox[{"1", "-", 
              RowBox[{"pplus", "[", "\[Alpha]", "]"}]}]]}], ";", " ", 
           RowBox[{"(*", " ", 
            RowBox[{
            "weight", " ", "adjustment", " ", "for", " ", "guided", " ", 
             "phase", " ", "function", " ", "sampling"}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"s", "=", 
            RowBox[{"sampleFPNegative", "[", "\[Alpha]", "]"}]}], ";", " ", 
           RowBox[{"(*", " ", 
            RowBox[{
             RowBox[{"\"\<-\>\"", " ", "free"}], "-", 
             RowBox[{"path", " ", "sampling"}]}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x", "-", "s"}], "<", "0"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"w", "*=", 
               FractionBox[
                RowBox[{"Xc", "[", "x", "]"}], 
                RowBox[{"probEscape", "[", 
                 RowBox[{"x", ",", "\[Alpha]"}], "]"}]]}], ";"}], " ", 
             RowBox[{"(*", " ", 
              RowBox[{"expected", "-", 
               RowBox[{"value", " ", "weight", " ", "for", " ", "escape"}]}], 
              " ", "*)"}], "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
             
             RowBox[{
              RowBox[{"w", "*=", 
               FractionBox[
                RowBox[{"pc", "[", "s", "]"}], 
                RowBox[{"FPNegativePDF", "[", 
                 RowBox[{"s", ",", "x", ",", "\[Alpha]"}], "]"}]]}], ";"}]}], 
            " ", 
            RowBox[{"(*", " ", 
             RowBox[{
             "weight", " ", "adjustment", " ", "for", " ", "guided", " ", 
              "FP", " ", "sampling"}], " ", "*)"}], "\[IndentingNewLine]", 
            "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"x", "-=", "s"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     "w"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.8012731427645073`*^9, 3.80127314547228*^9}, 
   3.8012732576716347`*^9, {3.801273408814543*^9, 3.801273410901414*^9}, {
   3.801360071367052*^9, 3.80136007363865*^9}, {3.801360139119158*^9, 
   3.801360303532276*^9}, 
   3.801374466028285*^9},ExpressionUUID->"8b7d6aae-fbfd-4492-a81a-\
7b92c3181bb3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Testing:", "Subsection",
 CellChangeTimes->{{3.801273272480125*^9, 
  3.801273273256563*^9}},ExpressionUUID->"38780f2e-4c9c-4c18-9881-\
569ce4fef70a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"test\[Alpha]", "=", "0.97"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"R", "[", "test\[Alpha]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ZeroVarianceHalfRod", "[", "test\[Alpha]", "]"}]}], "Input",
 CellChangeTimes->{{3.8012732754009037`*^9, 3.8012732914651747`*^9}},
 CellLabel->
  "In[118]:=",ExpressionUUID->"a68997a7-c527-4e02-9032-369d5deace72"],

Cell[BoxData["0.7047317922538399`"], "Output",
 CellChangeTimes->{
  3.801273291856151*^9, {3.801273412585492*^9, 3.801273423535102*^9}, {
   3.801360085357733*^9, 3.8013601010055447`*^9}},
 CellLabel->
  "Out[119]=",ExpressionUUID->"8dedf53a-d8f3-4e9c-85bc-d2fa609335b9"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.29491, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538401`"}],
  SequenceForm["x: 1.29491, \tw * W[x]: ", 0.7047317922538401],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101008883*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"69d8931a-ce75-4c2a-bfd2-8922218a7487"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.72286, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538403`"}],
  SequenceForm["x: 1.72286, \tw * W[x]: ", 0.7047317922538403],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101012746*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"7e6b0285-5a59-4f3f-84c7-173874cf955b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.832951, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538404`"}],
  SequenceForm["x: 0.832951, \tw * W[x]: ", 0.7047317922538404],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101016219*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"410e337f-1012-40e9-9aee-4072001ef412"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.92483, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538406`"}],
  SequenceForm["x: 1.92483, \tw * W[x]: ", 0.7047317922538406],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101018611*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"2b76826f-e585-4869-805a-4e52d7e5eb79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.28977, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538409`"}],
  SequenceForm["x: 2.28977, \tw * W[x]: ", 0.7047317922538409],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101021686*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"d62b71c5-0c5e-43e8-ae7a-b943ef1167d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.32812, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538411`"}],
  SequenceForm["x: 3.32812, \tw * W[x]: ", 0.7047317922538411],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101024499*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"796d3fde-3d88-49db-a70b-ed90c0c332d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.07792, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538412`"}],
  SequenceForm["x: 3.07792, \tw * W[x]: ", 0.7047317922538412],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.80136010102778*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"abbd050e-d12f-4764-8fd0-d92e6484ae61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.13528, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538414`"}],
  SequenceForm["x: 3.13528, \tw * W[x]: ", 0.7047317922538414],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010308123`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"0c05bfc4-ff9f-48e0-be2b-430a4acde2c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.43727, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538414`"}],
  SequenceForm["x: 2.43727, \tw * W[x]: ", 0.7047317922538414],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101033662*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"a279d0f1-b25d-41d5-b281-ca52f85075e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.75867, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538416`"}],
  SequenceForm["x: 4.75867, \tw * W[x]: ", 0.7047317922538416],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101036166*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"b5ef5cc2-257e-4e08-bd06-e9077a9a1c89"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.05377, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538419`"}],
  SequenceForm["x: 4.05377, \tw * W[x]: ", 0.7047317922538419],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101037887*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"761c4f14-b0f1-4b17-b767-0ccd15196272"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.58779, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253842`"}],
  SequenceForm["x: 4.58779, \tw * W[x]: ", 0.704731792253842],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.80136010103961*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"3cd1e69a-1095-4069-b219-f49fe4987e56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.99321, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253842`"}],
  SequenceForm["x: 2.99321, \tw * W[x]: ", 0.704731792253842],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010413647`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"b75c65c9-3567-4b56-82a1-5954e17f7ee7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.97068, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538422`"}],
  SequenceForm["x: 1.97068, \tw * W[x]: ", 0.7047317922538422],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101043357*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"5f7c52a8-2cba-4f3f-9e85-04f0cd6e2b32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.26927, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538424`"}],
  SequenceForm["x: 2.26927, \tw * W[x]: ", 0.7047317922538424],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010450983`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"1601528b-b854-4056-afee-a5f7c759f70c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.21257, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538425`"}],
  SequenceForm["x: 2.21257, \tw * W[x]: ", 0.7047317922538425],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101046834*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"c1c723ed-ec69-4dd8-b1f5-b3cc4cc68c6f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.99765, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538429`"}],
  SequenceForm["x: 3.99765, \tw * W[x]: ", 0.7047317922538429],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101048658*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"4ca5637b-569c-4522-b4ce-7432788480ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 8.6123, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253843`"}],
  SequenceForm["x: 8.6123, \tw * W[x]: ", 0.704731792253843],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101050519*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"47ec09ad-8548-41e2-92b0-d6cdcf5e9c6b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.6588, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538431`"}],
  SequenceForm["x: 6.6588, \tw * W[x]: ", 0.7047317922538431],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010522614`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"020c5859-af5a-4bd5-a980-1870d40502ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.41337, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538433`"}],
  SequenceForm["x: 6.41337, \tw * W[x]: ", 0.7047317922538433],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.80136010105411*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"05f0dc67-5b49-452f-b50d-2ec5c75d409d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.239, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538435`"}],
  SequenceForm["x: 6.239, \tw * W[x]: ", 0.7047317922538435],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101056306*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"70583d77-1c62-4df7-b027-2d16bede75bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.93042, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538433`"}],
  SequenceForm["x: 4.93042, \tw * W[x]: ", 0.7047317922538433],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101057972*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"78638122-8707-48de-b5de-22f8a4e3f5c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.13264, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538435`"}],
  SequenceForm["x: 6.13264, \tw * W[x]: ", 0.7047317922538435],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010596123`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"0a3cb051-5109-427a-86cb-6a3722c4eda1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.33105, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538436`"}],
  SequenceForm["x: 5.33105, \tw * W[x]: ", 0.7047317922538436],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101061159*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"7e5094bf-c58c-4b21-a519-6473944191a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.60989, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538441`"}],
  SequenceForm["x: 2.60989, \tw * W[x]: ", 0.7047317922538441],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101062784*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"5802a63d-284d-4b69-b3e1-12c997adb086"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.201164, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253844`"}],
  SequenceForm["x: 0.201164, \tw * W[x]: ", 0.704731792253844],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010644417`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"cb86687b-9983-460d-93eb-d25fb694c434"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.307096, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538442`"}],
  SequenceForm["x: 0.307096, \tw * W[x]: ", 0.7047317922538442],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010662003`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"09043a44-7018-4458-8265-aea3bd680040"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.205747, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538443`"}],
  SequenceForm["x: 0.205747, \tw * W[x]: ", 0.7047317922538443],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101068013*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"ecee2c71-ca11-4352-b841-61ff027bc482"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.5776, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538444`"}],
  SequenceForm["x: 2.5776, \tw * W[x]: ", 0.7047317922538444],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101069764*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"cc8e8f25-6cce-40b4-9a53-e47c5f29d772"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.10801, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538447`"}],
  SequenceForm["x: 6.10801, \tw * W[x]: ", 0.7047317922538447],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101071905*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"f089efa6-926c-411c-999d-13f449854eed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.21147, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253845`"}],
  SequenceForm["x: 5.21147, \tw * W[x]: ", 0.704731792253845],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010741453`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"ff79ebbb-35e9-48e4-98d5-88d3fc3a37bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.0139, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253845`"}],
  SequenceForm["x: 5.0139, \tw * W[x]: ", 0.704731792253845],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101076557*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"1ed9f935-0e26-4d18-80d5-5b99106074a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.59519, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538451`"}],
  SequenceForm["x: 4.59519, \tw * W[x]: ", 0.7047317922538451],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101078638*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"0707047f-7243-48c0-8a1f-80c013ddde40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.08794, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253845`"}],
  SequenceForm["x: 4.08794, \tw * W[x]: ", 0.704731792253845],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010804253`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"3460bc3d-357a-4b6d-a059-27322f22de23"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.37939, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538451`"}],
  SequenceForm["x: 3.37939, \tw * W[x]: ", 0.7047317922538451],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101082197*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"a7bcd4fb-b71d-4ca1-aa24-6663f4957410"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.91109, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538453`"}],
  SequenceForm["x: 4.91109, \tw * W[x]: ", 0.7047317922538453],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101083955*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"290727cd-0af5-444a-bf2c-fc0918ad6ca8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.357, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538457`"}],
  SequenceForm["x: 5.357, \tw * W[x]: ", 0.7047317922538457],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101085935*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"1fe39040-93ea-4024-94eb-da5ee23fda63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.33032, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538456`"}],
  SequenceForm["x: 5.33032, \tw * W[x]: ", 0.7047317922538456],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010877743`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"7b0b939e-6a68-42e0-8175-eeb6db4265fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.5647, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538456`"}],
  SequenceForm["x: 6.5647, \tw * W[x]: ", 0.7047317922538456],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601010896683`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"9ac8aa02-d1ae-4534-a463-62f06d2a9922"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.90876, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253846`"}],
  SequenceForm["x: 3.90876, \tw * W[x]: ", 0.704731792253846],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101092368*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"fd2ea6cd-b3a0-45e9-b7be-4fb7cc96e962"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.87589, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538464`"}],
  SequenceForm["x: 4.87589, \tw * W[x]: ", 0.7047317922538464],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101095964*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"44877cc0-ec13-4d3b-9413-e5eac69d0970"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.69087, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538464`"}],
  SequenceForm["x: 3.69087, \tw * W[x]: ", 0.7047317922538464],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101098518*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"256f8440-5190-4b80-9e99-0c62c213cb3f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.00789, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538467`"}],
  SequenceForm["x: 4.00789, \tw * W[x]: ", 0.7047317922538467],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601011010847`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"52f463cf-51db-4ca9-9eb1-b888afa66255"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.19257, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538473`"}],
  SequenceForm["x: 4.19257, \tw * W[x]: ", 0.7047317922538473],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101103615*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"cc740316-b899-43f8-99a5-2e2f10808af1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.62955, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538473`"}],
  SequenceForm["x: 4.62955, \tw * W[x]: ", 0.7047317922538473],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601011060038`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"e437219f-e537-46be-95bf-f8446a44afc7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.87512, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538475`"}],
  SequenceForm["x: 5.87512, \tw * W[x]: ", 0.7047317922538475],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601011081553`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"f62df830-26a5-488a-97fd-182786fc4f31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.32386, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538479`"}],
  SequenceForm["x: 6.32386, \tw * W[x]: ", 0.7047317922538479],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101109977*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"9abfd2ab-c112-4bf6-a027-3a8af36c1eff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 9.41901, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253848`"}],
  SequenceForm["x: 9.41901, \tw * W[x]: ", 0.704731792253848],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601011117697`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"2f7b2e8a-2512-43c5-83ee-c98ae363cdc1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 8.39116, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538482`"}],
  SequenceForm["x: 8.39116, \tw * W[x]: ", 0.7047317922538482],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601011145782`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"4c762987-e59f-4c9b-bc4e-da221767410c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 7.41774, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538484`"}],
  SequenceForm["x: 7.41774, \tw * W[x]: ", 0.7047317922538484],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101117262*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"c5e5d76b-01b6-404d-a881-e097683793d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 8.91478, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538486`"}],
  SequenceForm["x: 8.91478, \tw * W[x]: ", 0.7047317922538486],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101119762*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"f5f182b7-b991-46e9-a312-3759a449efa1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 8.95088, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538489`"}],
  SequenceForm["x: 8.95088, \tw * W[x]: ", 0.7047317922538489],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.80136010112166*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"be651fb9-84ed-43b5-becc-285ade0948b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 9.24522, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538491`"}],
  SequenceForm["x: 9.24522, \tw * W[x]: ", 0.7047317922538491],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101123354*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"72a69670-00c5-453d-852b-4fc4896501b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 7.26932, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538493`"}],
  SequenceForm["x: 7.26932, \tw * W[x]: ", 0.7047317922538493],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101125084*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"fdd486e8-223e-4f93-ac1e-1ef9a371912d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 9.25401, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538495`"}],
  SequenceForm["x: 9.25401, \tw * W[x]: ", 0.7047317922538495],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101126828*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"e19a98f4-01e8-4766-8c33-c4182933bbeb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 7.46038, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538496`"}],
  SequenceForm["x: 7.46038, \tw * W[x]: ", 0.7047317922538496],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101128552*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"d1700741-baec-4074-b667-2370312f4434"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 7.23241, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538497`"}],
  SequenceForm["x: 7.23241, \tw * W[x]: ", 0.7047317922538497],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101130494*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"9f5330f1-6c38-49d2-8475-5846caa7e034"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 7.88475, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538501`"}],
  SequenceForm["x: 7.88475, \tw * W[x]: ", 0.7047317922538501],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101132697*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"acf589ad-553f-4493-a487-37d1b0e54b73"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 7.81939, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538503`"}],
  SequenceForm["x: 7.81939, \tw * W[x]: ", 0.7047317922538503],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.8013601011346693`*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"272ccb43-e675-4242-8954-8f0862f746e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.98991, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538502`"}],
  SequenceForm["x: 4.98991, \tw * W[x]: ", 0.7047317922538502],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101137027*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"09ad9cab-a5a0-41ad-a0c9-d4a73cf68771"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.68763, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538504`"}],
  SequenceForm["x: 5.68763, \tw * W[x]: ", 0.7047317922538504],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101139489*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"6c2a1ae0-0590-4f96-b23f-594927215ff1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.48337, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538504`"}],
  SequenceForm["x: 5.48337, \tw * W[x]: ", 0.7047317922538504],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101141692*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"913f2cf2-148c-409e-8e9f-ca776cdfe3af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.86879, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538506`"}],
  SequenceForm["x: 2.86879, \tw * W[x]: ", 0.7047317922538506],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101143889*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"4d1cb42d-06de-43cc-8a3e-0afd37945fe3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.41573, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.704731792253851`"}],
  SequenceForm["x: 1.41573, \tw * W[x]: ", 0.704731792253851],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101146015*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"24456315-4627-4490-ae5b-dba9c137f047"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.13781, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7047317922538512`"}],
  SequenceForm["x: 1.13781, \tw * W[x]: ", 0.7047317922538512],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.801273291860182*^9, {3.801273412588705*^9, 3.80127342353808*^9}, {
   3.8013600853603907`*^9, 3.801360101148011*^9}},
 CellLabel->
  "During evaluation of \
In[118]:=",ExpressionUUID->"255d85a6-dc34-4f83-ae85-159d94f25e20"]
}, Open  ]],

Cell[BoxData["0.7047317922538514`"], "Output",
 CellChangeTimes->{
  3.801273291856151*^9, {3.801273412585492*^9, 3.801273423535102*^9}, {
   3.801360085357733*^9, 3.801360101150105*^9}},
 CellLabel->
  "Out[120]=",ExpressionUUID->"9a9c225f-7986-468c-92cb-9be3b70fba30"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compare transition kernels", "Section",
 CellChangeTimes->{{3.8013772475696583`*^9, 
  3.801377250247492*^9}},ExpressionUUID->"e764da99-c553-4c60-ae7b-\
b110a8742860"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Tanalog", "[", 
   RowBox[{"x_", ",", "c_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{"-", 
     RowBox[{"Abs", "[", "x", "]"}]}], "]"}], 
   FractionBox["1", "2"]}]}]], "Input",
 CellChangeTimes->{{3.8013766680438213`*^9, 3.8013766793409147`*^9}},
 CellLabel->
  "In[181]:=",ExpressionUUID->"85ff0135-8b2a-460b-9764-27a1b0c9a2ab"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Tguided", "[", 
   RowBox[{"x_", ",", "c_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"pplus", "[", "c", "]"}], 
    RowBox[{"HeavisideTheta", "[", "x", "]"}], 
    RowBox[{"p1", "[", 
     RowBox[{
      RowBox[{"Abs", "[", "x", "]"}], ",", "c"}], "]"}]}], "+", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "-", 
      RowBox[{"pplus", "[", "c", "]"}]}], ")"}], 
    RowBox[{"HeavisideTheta", "[", 
     RowBox[{"-", "x"}], "]"}], 
    RowBox[{"FPNegativePDF", "[", 
     RowBox[{
      RowBox[{"Abs", "[", "x", "]"}], ",", "0", ",", "c"}], 
     "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.801376680562778*^9, 3.8013766880927887`*^9}},
 CellLabel->
  "In[182]:=",ExpressionUUID->"f5a95d02-ac38-4386-8006-e68414e1f91f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Tanalog", "[", 
      RowBox[{"x", ",", "c"}], "]"}], ",", 
     RowBox[{"Tguided", "[", 
      RowBox[{"x", ",", ".1"}], "]"}], ",", 
     RowBox[{"Tguided", "[", 
      RowBox[{"x", ",", ".5"}], "]"}], ",", 
     RowBox[{"Tguided", "[", 
      RowBox[{"x", ",", ".9"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\[Alpha] = 1\>\"", ",", "\"\<\[Alpha] = .1\>\"", ",", 
      "\"\<\[Alpha] = .5\>\"", ",", "\"\<\[Alpha] = .9\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"T", "[", "s", "]"}], ","}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ","}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.80137778216639*^9, 3.8013777939483337`*^9}, {
  3.801377828003639*^9, 3.801377981577924*^9}, {3.801378014609355*^9, 
  3.801378133083969*^9}},
 CellLabel->
  "In[237]:=",ExpressionUUID->"6a7d3762-58db-4daf-8a81-47c6febfd3df"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJw11Xk41fkCx/GQlC0tyBSiGB2mlCLJ/bRIGylXYxtKZQkhKaRkS2ooD0JF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        "]]},
      Annotation[#, "Charting`Private`Tag$34420#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVz3801Xccx3HdhjbObVq7VsjPOdwc+XHOdW+23tlBRwuFFmsqaUfnYqRb
LCa7KDpku3RdwkjO9/spx697dVyL99rpnuNmd3QZjRmurl1CCY271t13f7zO
8zz+fDmfTov6kmVmZraX2f/1Bs68yWTCQS/TROxOCtI2XIs2jCZ0juD7dDFu
k/u6r6yZ8GulMd/WjgI/j/DTs89MWH/VzmeEcYBNwdgvoyYMkmuqox0o2D+z
/Kiq1YS+wxvKCCcKoq5q7vqfNOGhplrHUHcKMgcKUpN63+BbuzKLBX4UDA9b
zT9I+BcnGlhB/EMUOPyUtj3A/jUelp4LkZ2hoDP5ofnWCSOGdc43SnMoOFXi
++J38QZCW+p5pZSCdUl2EcI6qkqn/glopaCR/ecO2fQr5JWn8KfUFNQc9M0Y
Kl5DjYubj+dTCsQpCVmeYas4NNnP6XtNQfbmO5kZiy/xWGLmyUpbGhLyBtxG
6GUsSOUTpQ8NN3r0shrhC7RQ3NNeDKOhe9LDutllCdnZ99eEZ2hwfXf/JzF1
z/Db/Kexzd/Q0MEtEupmDCgMiXThVtEwqWp34vFm8XPWwr4QBQ16rxt+eG8G
l10XblEaGmxyCc970zSqWHOR4XM0ePGeezWt/IFh3bgvYDOB/ODFQWXWKJZE
aS2FjgTej2n5Ls5Wi1eGuyL4gQQ6Xqm29rk9QvE2y67gowSaxvWlcwW9qEtW
WzecIzCWw/mh1r8XLzm3+1tlEGDvOtB2RNeDq4roLy4wvniK1iqhB0USdUfY
eQKheqHtNeOP2L2cJXopImBYel7PTVcikSwcDM4iwGUZ5cnHFdi9FBc8l0vg
RCNX5fiOAnUn7t6KvkxAEnx8ZKhLjvYVXaxexsYr99cDOXLsFFr0SfII9Ftd
/tj6cTtuKU9P+khM4Al3y/W40hb82a1wo6yQQPwRe8V44m2s+HtayC8hsLCy
JrjwsBHZSTpDPeMc6QCyP2xEDv/62bdLCdSMi/uDZhvQaachZYyxol+rinxc
hxG1TcU5ZQRaV1NcDWMV6F8d/t4DCYFfBU577GrK0eMzy2bPcgJLuUN7I+Il
uD6VEiphHLtNdPsslmFebmBeYgWB6EA2a5O6EKtlf1laSJl/KtGOpE/zcfCa
WctXjAcjx300mjz8Xqw6Osr4Zt9h9GvKxO110XfoSgIfTDgsvSEZKB6wP2Yj
I7B75jeBND4ZnzhLzC8xdrdOr/ROSsDFm/JOHWOB+R5qSh+D/HCtencVgf8A
y0Toug==
        "]], LineBox[CompressedData["
1:eJwVxXk02wcAB/AsmdVs+szGpkvSMqzibbqhm+t965y0jl9CxjDUe6ir1HPE
0KqjaLXpo0wdXbxEIu0ks04zR53z0G2qzFWs1D1vpK3Ond+2Pz7vYxgWzw2n
UigU2//8v42GhXRmwRdjJpQG30IZ0kvcHsRYJWC/9G3SJVIG9fm0yu8skrGe
89hxxk+GrOjvY4dZ32AirHg8112G7iOF+dU62VgJsl9dMZMhMpIVcU9dDJrx
zfW1H+rQpJU+0pUswu4kb6utRwrhR3rDCiMxiIcFTcx7UlwiFINVD8VoTzLt
KJBI4Vs292uKmQSh0+Ls9HwpVIYeXazpOty1bTkyyZbC1IahKHaRY+cqU5Ux
KEH/3RCXhsKfMF1Lt2Ys1ML66SvMi/7tEFixnySwxPhA1bJt29UPk41u7Vun
asAWTfzu5T+EaOGLehm7Gq6eurSXjWMwNrZ2LHhSDkHIWNYx5RTKcqq+yA0s
Ra8XQ5vQncVZ5Wy+/FAx/jbUOz9UMYdvfwxId9IUIDnJ/LRAfxG0B42FnvWX
MTalw43oW0Z8hl1Tp+gSQtPslw54rKJBzqvYj81Bt/lnl7s11rDk8q5lSlIW
TF9vXRa7q+Bot2keZJEBRmuMq0bBM3gTVlGOx/mg7FBliU+fI6+xdzShIAmb
nPvBPSYbKDRxrqFUnsOkVcj7JrkvsbIh5VMG4pDgp/OW0dQ/aJ4o0zf1ioLB
jXn/VxlbsM70ztr+ORzyQKH0BX8bfR+ODlWdCYOfwwX3vvs7eGdtRyK8EoKG
4Dgj271dvObmTeXRA7Gl5Uxr4u3j6qhDaTDFD9xHdscZ5WrQg+b5ui0+0LJ7
o7O1Wo3fxuL7S+p90Cl+fCpIpIal0SNfptAHx/hppyvlaty2nKB65/ng4GFl
kUGPGpqzHm8yCR/0x346p/dcjYHUT8Ljlrg4oWl2/aAHiQuZM9ckdC62zm0d
knNIuBrocZx1uFBM9tZ6+pFoXnQqWqZxwVREtBSFkahhhX7pscrBHk+8qJVG
Itnhq3J+MwdK0WGHAxIS9tMzI8EBHJzVXu+V3CGREzDDz/LiwDS1jevWQOL6
55s2t504uHHy6zN5rSSOimwo+uYcJD6rKKENk2DTr1C99giwAqOZonESg4Pi
XYWKwOwvNjKnP0l4Hx1ZNFggQJSPt11cITF/syNTY4CAJrWObbhO4r2oOmZ+
F4H2mNQ/OjZIJJ6gVOkoCaSMuIWE7pDgKSNVNXcIfAz9v0iShEA3W99OSOBf
Jt287g==
        "]]},
      Annotation[#, "Charting`Private`Tag$34420#2"]& ], 
     TagBox[
      {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBsQNO/CFib1JlAgAAADoAAAACAAAALj8W6v///78O1QA9OdDBP2/5I4j5
+v+/uHHLydzRwT+wszEm8/X/v7CEL32A08E/MihNYubr/79SQtJXyNbBPzcR
hNrM1/+/MqDl3FndwT9A4/HKma//v68XYSmE6sE/UofNqzNf/7+vt6Xk9QTC
P3fPhG1nvv6/joBQrU46wj/U1AvqwWH9v+5nsp4asMI/HcBvFDcc/L+E1PoO
xyDDP7VrxAUP3fq/aw4iD9GRwz9gjDHw2YL5v8W+15pjD8Q/+JJ7iL8/+L8W
191Wa4fEP6MO3hmY4fa/+C5hG6sMxT+cSjFy04n1vy255APGksU/gmxheClJ
9L90TKBV3xLGP3sDqndy7fK/5aJMNSOhxj9hgM8k1qjxvxp0yDUuKcc/lb3l
mJxq8L+VW3HYpbHHP7rfKAysIu6/pn2AUEVJyD8jEEBCVJ7rvxA3IgEq2sg/
siqIauLj6L8mdB0nCnvJP9/FsSA2Nua/0lqZD+4cyj/lLJUyv7bjv7CziWuH
t8o/EX6pNi4B4b9FzG+aQGPLPyw27yyl89y/WNI8P2wHzD+DRO3QuXjXv8EY
NeOnvcw/FVSukFkX0r/+AKWXEnXNP7L2xQ/IJMq/tyWwkk0kzj+l2+WN6YS+
v6/iOojk5s4/2nwWn50zvr9/PYN6xOnOPw4eR7BR4r2/0ZBCsaTszj92YKjS
uT+9v6ibP+xl8s4/RuVqF4r6u782vuWY6/3OP+ju76AqcLm/ugl40gMVzz8q
Avqza1u0vz+LgvNnQ88/XqMqxR8KtL94nQyBUEbPP5JEW9bTuLO/+J/aUzlJ
zz/6hrz4Oxazv8k8XMkLT88/ywt/PQzRsb8OaKr0s1rPP9gqCI5Zja6/rBAZ
UhFyzz9dURy022Okvxudk1UAoc8/7PP1OXXEo79BAq3M4qPPP3yWz78OJaO/
sO8fh8Wmzz+c24LLQeahv8/1KsaLrM8/tMvSxU/Rnr+Cz4FtG7jPP6/0bCPo
2pS/KpOVZkfPzz/OOSAvG5yTv/POKRYu0s8/7n7TOk5dkr/THXoJFdXPP1gS
dKRov4+/Q6tnu+Pazz9TOw4CAcmFvw2hI02E5s8/ksV0GWdLg7/njUUbbenP
P9BP2zDNzYC/SAlVLVbszz+byFC/MqV3vwh0VR0p8s8/GN0d7v6pcr8IyVL7
EvXPPyvj1TmWXWu/0ndWHf33zz8mDHCXLmdhv5+0ZoPn+s8/OQUvp+DlVL9Q
Wcas8PzPP2QS9Zg=
        "]], LineBox[CompressedData["
1:eJwVjnsw1AkAxxcJ23BS3MSsV8OwjXTSyTr3vSuJi2Y9drjK8zrknUk4s9nf
7llRzXo0KlHbrEemsqeHVx55hE07e15nD3VYSXcIF3n+fuf++Mznj88/H4vw
BN+f1Wk0GmuL/+2saV8x9s4fDdxe0f45BdIL3F/FOCbCI8vGfLRbAfJS2u27
9smQO/CMN2oV4EU/jO1n/gLr9Ti6VYUC7ebZWSX6fLTlatXlZSoQGcmMqCHz
0Z0ZZFJBU6Cenj7YlixBwSiXfmpTDrGdYb/UshSOHcb83TNyCNnS34sVpegW
2s4oh+XwL1T1XLQtR1jDM15GnRzzFl5tzDf3Eay+sOPoBTmsnRnSfLcqlIln
6+7MvobsSYhbdfZTGJrrCIn3PTg0oWZKBLbgoMCT7FqWYe/881VWmww6odNl
rMed8JT8KT8Z2Af2othv+512HPM20Fh6NoQxN1Yum9YKUcgQ70DtKJxC3Vt7
XzSh6yRDl20wDpVaS45Lcz1mLQwv9RWp4LMqemfHrUHyhX1hIqMpMKNiTg0+
foKhUX3fiO5pxBbbZBR9UY3QtG/ea3n9g8ukKqjzj0do3+eU0645hzGHvz7s
klfCWqdxutRjHoepJSOhsByMxphjmpcXsJc7naeslYC2pl6ZNLEIpefnGYed
9/DZpyn4pdUneKeu0ToGSjDiGGJi9esSIrfPR3zVdQuJAfo7LUeXYeGw1CDj
FGLP9cnAbYwVnJOFBdJzClB1Wlzxb+oqygrW9QanchHgmuHR3bQGGXlwcjnz
GqqD4yxZG+tY67llcGM4Gyv0oxr1nE3ssjE1IcOF8O11+Zpxk8TTE9Hx5/MF
oLvsaG0sIZHl/ehNjVCA1tLhE2ckJDQrj/hrpAtwIDUt7HYViYbJa+7VPwmg
Z1Z7dc9LEvH1nFehhwSQxTqoDBdJqJcHPqQP8/Gdtm2unheFyZg5jzgbPlbO
rxhX+VDYzU6ovMLgQzrSVeYdQIF0/l70mwEfptKI51fDKYxrO4/obhLY4JRO
0dMoOL2+p2XUR6BWYuaqVU4BXFe/H7kE4nU/dpU/oKDyWz38NomAdUqzr3s1
BXpCYcS5KALXfwiKymzc6jlROfl+BJIWigo0+ilobLtxxZ5JgHk62lSipHBW
nnJ8yozAeIdz5ZG3FPhnz9hJDAmwbyqbiQ8UHtyNjbJXI6Ctft/T4uPWb7FL
DbnMQ0tMysCLTxRWvuSYDczwcHHQPSR0jULFt/pi6QQP+2H0N0VRIBI7HfOU
PPwHP3HLqw==
        "]]},
      Annotation[#, "Charting`Private`Tag$34420#3"]& ], 
     TagBox[
      {RGBColor[0.922526, 0.385626, 0.209179], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBsQNO/CFib1JlAgAAADoAAAACAAAALj8W6v///7/ZBFAAWFi9P2/5I4j5
+v+/HyxA6aVevT+wszEm8/X/v8eC6Sz1ZL0/MihNYubr/78LwpHFl3G9PzcR
hNrM1/+/FiRiRO2KvT9A4/HKma//v4gFhLnZvb0/UofNqzNf/7/yOCiRuiS+
P3fPhG1nvv6/TV5Ypqz2vj/U1AvqwWH9v9W19RPbaMA/HcBvFDcc/L8mz7bc
d1PBP7VrxAUP3fq/cf3olTFGwj9gjDHw2YL5v7Vp/sCIXMM/+JJ7iL8/+L/t
G+1DOG/EP6MO3hmY4fa/36aq4h2qxT+cSjFy04n1v+biTkm08cY/gmxheClJ
9L//bRzUsTTIP3sDqndy7fK/0+o30winyT9hgM8k1qjxv4Y5LnW3FMs/lb3l
mJxq8L/WCGy49o7MP7rfKAysIu6/kDC3Hr5Azj8jEEBCVJ7rv6G7+iqt7M8/
siqIauLj6L+gdE37pOvQP9/FsSA2Nua/qLGPzMjq0T/lLJUyv7bjv8QL8mdB
5tI/EX6pNi4B4b+8yrutnAbUPyw27yyl89y/oCO3Rj4j1T+DRO3QuXjXvxEq
y0GHadY/FVSukFkX0r+mfCODAb3XP7L2xQ/IJMq/8kG8wMoL2T+l2+WN6YS+
v+3AON+ji9o/2nwWn50zvr9ynwIeaJHaPw4eR7BR4r2/LF59nS2X2j92YKjS
uT+9v1g0nF+8oto/RuVqF4r6u7+jnCH46LnaP+ju76AqcLm/FfuPt37o2j8q
Avqza1u0v2dvQV2eRts/XqMqxR8KtL+hNUg6i0zbP5JEW9bTuLO/VbbSYHlS
2z/6hrz4Oxazv31KkYtZXts/ywt/PQzRsb+33IxfKXbbP9gqCI5Zja6/v9Rx
QAem2z9dURy022Okv8EPzOC9Btw/7PP1OXXEo78EXYTbtQzcP3yWz78OJaO/
4jSlG68S3D+c24LLQeahv4LHNW2lHtw/tMvSxU/Rnr/SiCpdoTbcP6/0bCPo
2pS/85hTrdZm3D/OOSAvG5yTvxsQMR/jbNw/7n7TOk5dkr8A1dLa8HLcP1gS
dKRov4+/vEF8MBB/3D9TOw4CAcmFv1nBGF1el9w/ksV0GWdLg79CWMokdZ3c
P9BP2zDNzYC/77VzOI2j3D+byFC/MqV3v2ufyETBr9w/GN0d7v6pcr/MvQE+
3bXcPyvj1TmWXWu/G8hNhPq73D8mDHCXLmdhv1at8xcZwtw/OQUvp+DlVL+/
eahfX8bcP326/Ig=
        "]], LineBox[CompressedData["
1:eJwVxXsw1AkAB3DP8ei2Wy513NCtG2asQdNwd7jmK/K6dg2bbt10kpIuryjv
poc6iTRecYYzfrs2j3S7t0oI65XWqjvJZWV/UrZbtMOqbB6xv7v74zMfxtFT
nOMGenp6Xv/5f09jt4aX/4QjJfjUvaReEmfLAobj3ZPxkZ4+lVNPQnc+q7rW
LQ0by5bdD6tIXIy7nTDGzMa2bE4cvYjEwJf5eTX0S1hikw4tGSROnGDG3tOV
ouTz2t9XbEh0mJ991p9Wh7UOiZnZcQUIF6sxkb0As1x96xcRClwJFT35bUSA
KzUjRe0sBcIrlI/Sneohtkm/dc5dgSUGq5851Yj3nJXQICMFHD1tRaX7hCjL
bwiZEkxCdidqnzj/LhZ9avna+efwmNG3y4nowdinL9ujLk/gq6XONa9+GfJk
csrBehzBdc//DIl4ir3TFUl/9IzBn21pqG2V440Lm5YmGkVRlPzirjYSZIxr
pe/8CKQhtrRQy1egb560Sil4jAWG1fmnVUrIqzUWZ9pkSEt1ji7argI5bOfr
9q0UcpLOiR2aQ6aa8aRg6AGOZH03a8JSQ+Kxv2u0ux8Dzt8UDBgvYmZlb6N+
Xy8czbrmBEFLGArMvXvGRQLbrnh/46tvUZA6Z6P27oTeukHT6Zl3CG35MSMx
sh0rYd2HBx2W4eqcnKjStkLhHvWFwy9aqL0m/Hxr7yCZS7ewJz/g5K1xn/IS
MaxvvI4wsl3Fo8mE5kmxCMJDRMP7zDW0qwcuX+PeBnfPhaCh7nXc99Y6RV9t
gvhwor3Xxkdcit5U/vpJA1bN/Qw7Dm7i8SxtRyEhAGfU+2vbSh2CLLbETFfy
Ye69pa+rRgd3Np0WWMxHn2By/091OuzoNhK15PGxKzMrulqow+hnMePl6Xxs
3dlWaD2oQ6nZ8IVr4XzIEnYrrd7pMCuPrt9twYePqVPxVhaFZIam7dh1HlZT
Vm2EYRSWlGl6gbk8iBTSm2wuhdcBMlPXczzYiWI7C49SoEXOhZkk8rBxUKAy
z6IwUtFarmLx0Fa3c49JPQXCr+LYDzQekmgaaX0zBeF062SqMQ+OGRJOgJhC
jibwQ8UmgRvfR/6c20UhLMZ0m2qBwOm3VWWGYxTYWtNO0V8EmIfi7OomKCya
DzqqHxJ49cCzyfcFhWxhiROzh0Bo5YQkZ57CwIH7Cy0iAqYGjcEMDQV7G2nz
RgOBnviMv3uXKeiv+K8HEwTSnwVEHVmnkOdRIq+qJOCK7W8oioJUaeirKSbw
L2u+16s=
        "]]},
      Annotation[#, 
       "Charting`Private`Tag$34420#4"]& ], {}}, {{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}}}, {{{}, {GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 0.06766764714219568}], 
           Offset[{0, 0}, {2.0833333333333335`, 0.06766764714219568}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.06766764714219568}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.06766764714219568}], 
           Offset[{0., 0.}, {2.1633333333333336`, 0.06766764714219568}], 
           Offset[{0, 0}, {2.401984316547943, 0.12713441572540213`}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.401984316547943, 
            0.12713441572540213`}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.12713441572540213`}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.12713441572540213`}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 0.06766764714219568}], 
           Offset[{0, 0}, {2.0833333333333335`, 0.06766764714219568}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.06766764714219568}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.06766764714219568}], 
           Offset[{0., 0.}, {2.1633333333333336`, 0.06766764714219568}], 
           Offset[{0, 0}, {2.401984316547943, 0.12713441572540213`}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.401984316547943, 
            0.12713441572540213`}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.12713441572540213`}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.12713441572540213`}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{39., 6.500000000000009}, {2.401984316547943, 
            0.12713441572540213`}], 
           Offset[{39., -6.499999999999991}, {2.401984316547943, 
            0.12713441572540213`}], 
           Offset[{10.000000000000002`, -6.499999999999998}, {
            2.401984316547943, 0.12713441572540213`}], 
           Offset[{9.999999999999998, 6.500000000000002}, {2.401984316547943, 
            0.12713441572540213`}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"\[Alpha] = 1\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{24.5, 5.440092820663267*^-15}, \
{2.401984316547943, 0.12713441572540213}], {0, 0}]}], GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 0.0010147645025721274`}], 
           Offset[{0, 0}, {2.0833333333333335`, 0.0010147645025721274`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.0010147645025721274`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.0010147645025721274`}], 
           Offset[{0., 0.}, {2.1633333333333336`, 0.0010147645025721274`}], 
           Offset[{0, 0}, {2.401984316547943, -0.006419563076504561}], 
           Offset[{5., 1.1102230246251565`*^-15}, {
            2.401984316547943, -0.006419563076504561}], 
           Offset[{10., 2.220446049250313*^-15}, {
            2.401984316547943, -0.006419563076504561}], 
           Offset[{10., 2.220446049250313*^-15}, {
            2.401984316547943, -0.006419563076504561}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 0.0010147645025721274`}], 
           Offset[{0, 0}, {2.0833333333333335`, 0.0010147645025721274`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.0010147645025721274`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.0010147645025721274`}], 
           Offset[{0., 0.}, {2.1633333333333336`, 0.0010147645025721274`}], 
           Offset[{0, 0}, {2.401984316547943, -0.006419563076504561}], 
           Offset[{5., 1.1102230246251565`*^-15}, {
            2.401984316547943, -0.006419563076504561}], 
           Offset[{10., 2.220446049250313*^-15}, {
            2.401984316547943, -0.006419563076504561}], 
           Offset[{10., 2.220446049250313*^-15}, {
            2.401984316547943, -0.006419563076504561}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{42., 6.500000000000009}, {
            2.401984316547943, -0.006419563076504561}], 
           Offset[{42., -6.499999999999991}, {
            2.401984316547943, -0.006419563076504561}], 
           Offset[{10.000000000000002`, -6.499999999999998}, {
            2.401984316547943, -0.006419563076504561}], 
           Offset[{10., 6.500000000000002}, {
            2.401984316547943, -0.006419563076504561}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"\[Alpha] = .1\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{26., 5.773159728050814*^-15}, \
{2.401984316547943, -0.006419563076504561}], {0, 0}]}], GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 0.008225569174833193}], 
           Offset[{0, 0}, {2.0833333333333335`, 0.008225569174833193}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.008225569174833193}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.008225569174833193}], 
           Offset[{0., 0.}, {2.1633333333333336`, 0.008225569174833193}], 
           Offset[{0, 0}, {2.401984316547943, 0.0380704427236589}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.401984316547943, 
            0.0380704427236589}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.0380704427236589}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.0380704427236589}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 0.008225569174833193}], 
           Offset[{0, 0}, {2.0833333333333335`, 0.008225569174833193}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.008225569174833193}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.008225569174833193}], 
           Offset[{0., 0.}, {2.1633333333333336`, 0.008225569174833193}], 
           Offset[{0, 0}, {2.401984316547943, 0.0380704427236589}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.401984316547943, 
            0.0380704427236589}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.0380704427236589}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.0380704427236589}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{42., 6.500000000000009}, {2.401984316547943, 
            0.0380704427236589}], 
           Offset[{42., -6.499999999999991}, {2.401984316547943, 
            0.0380704427236589}], 
           Offset[{10.000000000000002`, -6.499999999999998}, {
            2.401984316547943, 0.0380704427236589}], 
           Offset[{10., 6.500000000000002}, {2.401984316547943, 
            0.0380704427236589}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"\[Alpha] = .5\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{26., 5.773159728050814*^-15}, \
{2.401984316547943, 0.0380704427236589}], {0, 0}]}], GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 0.032355763252730756`}], 
           Offset[{0, 0}, {2.0833333333333335`, 0.032355763252730756`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.032355763252730756`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.032355763252730756`}], 
           Offset[{0., 0.}, {2.1633333333333336`, 0.032355763252730756`}], 
           Offset[{0, 0}, {2.401984316547943, 0.08257838086437234}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.401984316547943, 
            0.08257838086437234}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.08257838086437234}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.08257838086437234}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 0.032355763252730756`}], 
           Offset[{0, 0}, {2.0833333333333335`, 0.032355763252730756`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.032355763252730756`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 0.032355763252730756`}], 
           Offset[{0., 0.}, {2.1633333333333336`, 0.032355763252730756`}], 
           Offset[{0, 0}, {2.401984316547943, 0.08257838086437234}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.401984316547943, 
            0.08257838086437234}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.08257838086437234}], 
           Offset[{10., 2.220446049250313*^-15}, {2.401984316547943, 
            0.08257838086437234}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{42., 6.500000000000009}, {2.401984316547943, 
            0.08257838086437234}], 
           Offset[{42., -6.499999999999991}, {2.401984316547943, 
            0.08257838086437234}], 
           Offset[{10.000000000000002`, -6.499999999999998}, {
            2.401984316547943, 0.08257838086437234}], 
           Offset[{10., 6.500000000000002}, {2.401984316547943, 
            0.08257838086437234}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"\[Alpha] = .9\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{26., 5.773159728050814*^-15}, \
{2.401984316547943, 0.08257838086437234}], {0, 0}]}]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      RowBox[{"T", "(", "s", ")"}], TraditionalForm], ""}, {
     FormBox["s", TraditionalForm], ""}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.3, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.5, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.08, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.06, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.04, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.02, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.02, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.04, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.06, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.08, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.12, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.14, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.16, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.18, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.22, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.24, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.26, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.28, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.32, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.34, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.36, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.38, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.42, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.44, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.46, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.48, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.52, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.54, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.56, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.58, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{All, 77.86509832146095}, {All, All}},
  ImageSize->400,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-2, 2}, {0., 0.4997701443195795}},
  PlotRangeClipping->False,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.08090169943749476]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.801377963412291*^9, 3.801377982150642*^9}, {
  3.8013780160259132`*^9, 3.8013781335861187`*^9}},
 CellLabel->
  "Out[237]=",ExpressionUUID->"4492fd5f-db8c-40bf-985c-d129299d2ff3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Tanalog", "[", 
      RowBox[{"x", ",", "c"}], "]"}], "/", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Tguided", "[", 
        RowBox[{"x", ",", ".1"}], "]"}], ",", 
       RowBox[{"Tguided", "[", 
        RowBox[{"x", ",", ".5"}], "]"}], ",", 
       RowBox[{"Tguided", "[", 
        RowBox[{"x", ",", ".9"}], "]"}]}], "}"}]}], "//", "Evaluate"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
   RowBox[{"PlotLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<\[Alpha] = .1\>\"", ",", "\"\<\[Alpha] = .5\>\"", ",", 
      "\"\<\[Alpha] = .9\>\""}], "}"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"w", "'"}], ","}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"s", ","}], "}"}]}], "}"}]}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.80137977253778*^9, 3.801379803135413*^9}},
 CellLabel->
  "In[266]:=",ExpressionUUID->"d504ca0d-975f-4aea-b11f-3d0b81f1bd41"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBEQLu/SFib1JlAgAAACAAAAACAAAALj8W6v///7+/lqBIfP73P2/5I4j5
+v+/EDnPc6MF+D+wszEm8/X/vygW5MDMDPg/MihNYubr/7/bp0vDJRv4PzcR
hNrM1/+/89vqevE3+D9A4/HKma//v4kUz0Twcfg/UofNqzNf/78TUm3Ij+f4
P3fPhG1nvv6/+oRwXHvZ+T/U1AvqwWH9v7fJLDwEBvw/HcBvFDcc/L+JkgRX
2Tf+P7VrxAUP3fq/AY/xJa1EAEBgjDHw2YL5v48Q9eNgoAFA+JJ7iL8/+L+D
dRNSBP8CQKMO3hmY4fa/oLF4RteZBECcSjFy04n1vzB1gAvrTgZAgmxheClJ
9L9nwGDNNgcIQHsDqndy7fK/zi+BsRgLCkBhgM8k1qjxvxMMwqWtEwxAlb3l
mJxq8L80Mhu1dDkOQLrfKAysIu6/IzqPP9FeEEAjEEBCVJ7rv2KEP3x+oxFA
siqIauLj6L9Ekxcv5x8TQN/FsSA2Nua/DuwXpIO0FEDlLJUyv7bjv00SKvPv
SxZAEX6pNi4B4b/ErwYDTykYQCw27yyl89y/z/p3J9UKGkCDRO3QuXjXv0c5
MYgBPxxAFVSukFkX0r8cWSiZVJceQLL2xQ/IJMq/UWQVWh16IECl2+WN6YS+
vzBaUel73CFAXVEctNtjpL9awf/aK0IjQDsFL6fg5VS/bXZm6s75I0BFgQRZ

        "]], 
       LineBox[{{0.0012755102040816321`, 10.012107876393422`}, {
        0.12244421942330848`, 11.231764485628803`}, {0.20123994058656178`, 
        12.1035411102694}, {0.28663988211205954`, 13.124957386229442`}, {
        0.3704807786936793, 14.211535869677167`}, {0.44868099767835984`, 
        15.305944183044819`}, {0.533485437025285, 16.588236786581742`}, {
        0.6126491987752708, 17.882009569073276`}, {0.6902539155813786, 
        19.24819815701973}, {0.7154279797231198, 19.72674838259419}}]},
      Annotation[#, "Charting`Private`Tag$61446#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBEQLu/SFib1JlAgAAACAAAAACAAAALj8W6v///78NouMZcx7fP2/5I4j5
+v+/PWT0/1wl3z+wszEm8/X/vwOjPG9ILN8/MihNYubr/7/4GtHqIzrfPzcR
hNrM1/+//NScX+1V3z9A4/HKma//vyZglozKjd8/UofNqzNf/7/ZfM1esP7f
P3fPhG1nvv6/u1iPvZ5y4D/U1AvqwWH9v9qhu8rUd+E/HcBvFDcc/L9zUkSM
V3riP7VrxAUP3fq/kkTUoUiG4z9gjDHw2YL5vyUEtq8fuuQ/+JJ7iL8/+L+h
FY88gOrlP6MO3hmY4fa/VXnLNxtI5z+cSjFy04n1v6DDkD+FtOg/gmxheClJ
9L92+xpBgBzqP3sDqndy7fK/ftLTbAq66z9hgM8k1qjxv7OQyGUpU+0/lb3l
mJxq8L+3UO+cHfvuP7rfKAysIu6/BPQHux1x8D8jEEBCVJ7rv9tYEXbZYfE/
siqIauLj6L/BO/kMX3byP9/FsSA2Nua/5JHrqYuW8z/lLJUyv7bjv/PC7Loc
s/Q/EX6pNi4B4b9XRkoOCvr1Pyw27yyl89y/dyUk9ls99z+DRO3QuXjXvz+4
4UO1sPg/FVSukFkX0r8oknhF1jP6P7L2xQ/IJMq/g9eqB1ey+z+l2+WN6YS+
vwoEaU28af0/XVEctNtjpL8caSTOhxz/PzsFL6fg5VS/5OCnYp34/z8RWh9B

        "]], LineBox[CompressedData["
1:eJwB8QIO/SFib1JlAgAAAC4AAAACAAAANwUvp+DlVD9r0wgpsgMAQDXiAR6B
WL8/snq3C3FyAUAj8Lv5OsLJP4AaGpJccgJASaPZzU5Y0j+PbL8DUZgDQEVN
EgP1tdc/yH5tvrLKBECPX9eAMLfcP11EJKhP+QVAx04dDVAS4T882L3n9FQH
QO0hFX7SmuM/FLgqYNesCEB1dCthjxbmP52tvfwpEQpA19wQUmbI6D8hUpWF
laoLQGB5POcHTOs/QxR5WDM/DUDDKzeKwwXuP8LgTf76Dw9AJgm86KRI8D/K
+HAr/20QQB28a0UFiPE/BZ3SGWhcEUAA+gKpcuLyP5dihyJQbhJA91G9XsUl
9D/w0DAqKX0TQNs0XxslhPU/WME3BEC0FEBwVxARItz2P9r0M2CI+BVAGZTk
WAQd+D/9pO6Y5TgXQK5boKfzePk/yuUjm+uoGEBXPX9IyL36P4D1QKcKFRpA
sV5tIjr8+z8ZSplCYo4bQPgKQwO5Vf0/C9sm7+8/HUBS0Ts2HZj+P6g0G3B/
7B5ACjsLwbyd/j9S1VG/L/QeQMGk2ktco/4/mOLr9+H7HkAweHlhm67+P/QX
MSdMCx9ADh+3jBnF/j8+YVaLNyofQMlsMuMV8v4/4LQj1WpoH0BACCmQDkz/
PwsGyM1G5h9A+HH4Gq5R/z/bFHs3Ne4fQK/bx6VNV/8/KHcCmiX2H0Aer2a7
jGL/P8szwiUGAyBA/FWk5gp5/z8ikwu3+BIgQLejHz0Hpv8/lTD4jw0zIEBu
De/Hpqv/P3mhAakUNyBAJne+Ukax/z9TuWjCHDsgQJRKXWiFvP8/w+RO9y9D
IEBy8ZqTA9P/P/nSd3BiUyBAKltqHqPY/z82tWqTcVcgQOHEOalC3v8/C+m6
uIFbIEBQmNi+gen/P2BJdAulYyBACAKoSSHv/z/AH145uGcgQL9rd9TA9P8/
f5umasxrIEB21UZfYPr/P5Q5jp/hbyBALj8W6v///z/7hlXY93MgQCt7UMI=

        "]]},
      Annotation[#, "Charting`Private`Tag$61446#2"]& ], 
     TagBox[
      {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwBEQLu/SFib1JlAgAAACAAAAACAAAALj8W6v///7/9zr464ePiP2/5I4j5
+v+/s53Jl8Hl4j+wszEm8/X/v+W6iySi5+I/MihNYubr/7+61kjNY+viPzcR
hNrM1/+/vGgrXOny4j9A4/HKma//v+AlunP9AeM/UofNqzNf/78RVVirSSDj
P3fPhG1nvv6/Cgv5SHNd4z/U1AvqwWH9v2jF4qWz5OM/HcBvFDcc/L/ahbjQ
UWbkP7VrxAUP3fq/vICkzJjo5D9gjDHw2YL5v6M8pO6XeeU/+JJ7iL8/+L9z
gHB5dATmP6MO3hmY4fa/abMBvuee5j+cSjFy04n1vwBExb6nOuc/gmxheClJ
9L+ajEcets/nP3sDqndy7fK/oualJJF16D9hgM8k1qjxv00PfPl4FOk/lb3l
mJxq8L/PGKB6KrTpP7rfKAysIu6/J9WUGe5l6j8jEEBCVJ7rv1lt96YgEOs/
siqIauLj6L/XGszUdc3rP9/FsSA2Nua/Xumw9FyM7D/lLJUyv7bjv/6HtykD
Q+0/EX6pNi4B4b8pK9dRRw7uPyw27yyl89y/L0DA2PnQ7j+DRO3QuXjXvzLv
O5uCqe8/FVSukFkX0r+11hMF8UHwP7L2xQ/IJMq/p9UD1XOq8D+l2+WN6YS+
v5uI7Dm7HvE/XVEctNtjpL9f4sXgJ47xPzsFL6fg5VS/BJyxmUbF8T95zyZE

        "]], LineBox[CompressedData["
1:eJwB8QIO/SFib1JlAgAAAC4AAAACAAAANwUvp+DlVD8dAWN68sjxPzXiAR6B
WL8/luhUlcl68j8j8Lv5OsLJP/o9kLAl8vI/SaPZzU5Y0j+iDoQG6nbzP0VN
EgP1tdc/+ohQy8r88z+PX9eAMLfcP44agDrnfPQ/x04dDVAS4T+tY5wldgv1
P+0hFX7SmuM/VeLBRwiU9T91dCthjxbmP2+DdQBGHfY/19wQUmbI6D/H4fTH
Dbb2P2B5POcHTOs/SVDC71BI9z/DKzeKwwXuPyA/fz0I6/c/Jgm86KRI8D9p
/YD0+ob4Px28a0UFiPE/EIrNALoj+T8A+gKpcuLyP/FgeCUt0vk/91G9XsUl
9D82FSxVQXn6P9s0XxslhPU//+n7fBUz+z9wVxARItz2P1pZIVp77vs/GZTk
WAQd+D/5pdFG1qH8P65boKfzePk/q151M2Zp/T9XPX9IyL36P+v3t2GcKP4/
sV5tIjr8+z/XbnC9xuj+P/gKQwO5Vf0/smJn262+/z9S0Ts2HZj+PwqVI7K+
RQBACjsLwbyd/j/U0FvFjUcAQMGk2ktco/4/ThEODF1JAEAweHlhm67+P5+E
9zP8TABADh+3jBnF/j8Dln7uPFQAQMlsMuMV8v4/IIZiE8hiAEBACCmQDkz/
P9E5zEQFgABA+HH4Gq5R/z/hqGfS2oEAQK/bx6VNV/8/a3Y1lLCDAEAer2a7
jGL/PyVjf7RchwBA/FWk5gp5/z/0Im9ot44AQLejHz0Hpv8/nljVonadAEBu
De/Hpqv/P31gUHZPnwBAJne+Ukax/z+66lp+KKEAQJRKXWiFvP8/8+U1LNuk
AEBy8ZqTA9P/P0s5p/9CrABAKltqHqPY/z94EUJ4Ha4AQOHEOalC3v8/Njyb
JfivAEBQmNi+gen/P9f9nx6uswBACAKoSSHv/z+bUFdqibUAQL9rd9TA9P8/
pm3k6mS3AEB21UZfYPr/P4w0TaBAuQBALj8W6v///z+ChZeKHLsAQIQCaGQ=

        "]]},
      Annotation[#, 
       "Charting`Private`Tag$61446#3"]& ], {}}, {{}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, {{{}, {
      GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 8.226500282707539}], 
           Offset[{0, 0}, {2.0833333333333335`, 8.226500282707539}], 
           Offset[{0., 0.}, {2.1233333333333335`, 8.226500282707539}], 
           Offset[{0., 0.}, {2.1233333333333335`, 8.226500282707539}], 
           Offset[{0., 0.}, {2.1633333333333336`, 8.226500282707539}], 
           Offset[{0, 0}, {2.243333395304723, 8.226501199578044}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.243333395304723, 
            8.226501199578044}], 
           Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
            8.226501199578044}], 
           Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
            8.226501199578044}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 8.226500282707539}], 
           Offset[{0, 0}, {2.0833333333333335`, 8.226500282707539}], 
           Offset[{0., 0.}, {2.1233333333333335`, 8.226500282707539}], 
           Offset[{0., 0.}, {2.1233333333333335`, 8.226500282707539}], 
           Offset[{0., 0.}, {2.1633333333333336`, 8.226500282707539}], 
           Offset[{0, 0}, {2.243333395304723, 8.226501199578044}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.243333395304723, 
            8.226501199578044}], 
           Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
            8.226501199578044}], 
           Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
            8.226501199578044}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{42., 6.500000000000009}, {2.243333395304723, 
            8.226501199578044}], 
           Offset[{42., -6.499999999999991}, {2.243333395304723, 
            8.226501199578044}], 
           Offset[{10.000000000000002`, -6.499999999999998}, {
            2.243333395304723, 8.226501199578044}], 
           Offset[{10., 6.500000000000002}, {2.243333395304723, 
            8.226501199578044}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"\[Alpha] = .5\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{26., 5.773159728050814*^-15}, \
{2.243333395304723, 8.226501199578044}], {0, 0}]}], GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 2.0913630321016976`}], 
           Offset[{0, 0}, {2.0833333333333335`, 2.0913630321016976`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 2.0913630321016976`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 2.0913630321016976`}], 
           Offset[{0., 0.}, {2.1633333333333336`, 2.0913630321016976`}], 
           Offset[{0, 0}, {2.243333395304723, 2.091363188504443}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.243333395304723, 
            2.091363188504443}], 
           Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
            2.091363188504443}], 
           Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
            2.091363188504443}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{0, 0}, {2.0833333333333335`, 2.0913630321016976`}], 
           Offset[{0, 0}, {2.0833333333333335`, 2.0913630321016976`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 2.0913630321016976`}], 
           Offset[{0., 0.}, {2.1233333333333335`, 2.0913630321016976`}], 
           Offset[{0., 0.}, {2.1633333333333336`, 2.0913630321016976`}], 
           Offset[{0, 0}, {2.243333395304723, 2.091363188504443}], 
           Offset[{5., 1.1102230246251565`*^-15}, {2.243333395304723, 
            2.091363188504443}], 
           Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
            2.091363188504443}], 
           Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
            2.091363188504443}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{42., 6.500000000000009}, {2.243333395304723, 
            2.091363188504443}], 
           Offset[{42., -6.499999999999991}, {2.243333395304723, 
            2.091363188504443}], 
           Offset[{10.000000000000002`, -6.499999999999998}, {
            2.243333395304723, 2.091363188504443}], 
           Offset[{10., 6.500000000000002}, {2.243333395304723, 
            2.091363188504443}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"\[Alpha] = .9\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{26., 5.773159728050814*^-15}, \
{2.243333395304723, 2.091363188504443}], {0, 0}]}]}, GraphicsGroupBox[{
       {GrayLevel[1], AbsoluteThickness[4], Opacity[
         NCache[
          Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
        "Round"], 
        BSplineCurveBox[{
         Offset[{0, 0}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0, 0}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0., 0.}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0., 0.}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0., 0.}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0, 0}, {2.243333395304723, 19.72674450126664}], 
          Offset[{5., 1.1102230246251565`*^-15}, {2.243333395304723, 
           19.72674450126664}], 
          Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
           19.72674450126664}], 
          Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
           19.72674450126664}]}]}, 
       {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
        AbsoluteThickness[1.25], 
        BSplineCurveBox[{
         Offset[{0, 0}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0, 0}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0., 0.}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0., 0.}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0., 0.}, {0.7954279797231197, 19.72674838259419}], 
          Offset[{0, 0}, {2.243333395304723, 19.72674450126664}], 
          Offset[{5., 1.1102230246251565`*^-15}, {2.243333395304723, 
           19.72674450126664}], 
          Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
           19.72674450126664}], 
          Offset[{10., 2.220446049250313*^-15}, {2.243333395304723, 
           19.72674450126664}]}]}, 
       {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
         NCache[
          Rational[2, 3], 0.6666666666666666]]}], 
        PolygonBox[{
         Offset[{42., 6.500000000000009}, {2.243333395304723, 
           19.72674450126664}], 
          Offset[{42., -6.499999999999991}, {2.243333395304723, 
           19.72674450126664}], 
          Offset[{10.000000000000002`, -6.499999999999998}, {
           2.243333395304723, 19.72674450126664}], 
          Offset[{10., 6.500000000000002}, {2.243333395304723, 
           19.72674450126664}]}]}, 
       {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
        AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
        StyleBox[
         RotationBox["\<\"\[Alpha] = .1\"\>",
          BoxRotation->0.],
         StripOnInput->False,
         LineOpacity->1,
         FrontFaceOpacity->1,
         BackFaceOpacity->1,
         Opacity->1,
         FontOpacity->1], 
        Offset[{26., 5.773159728050814*^-15}, \
{2.243333395304723, 19.72674450126664}], {0, 0}]}]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      SuperscriptBox["w", "\[Prime]", MultilineFunction -> None], 
      TraditionalForm], ""}, {
     FormBox["s", TraditionalForm], ""}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {10., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {15., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {20., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {6., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {7., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {8., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {9., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {11., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {12., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {13., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {14., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {16., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {17., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {18., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {19., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {21., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {22., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {23., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {24., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {25., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{-2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-2.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-1.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{All, 62.000006197138944`}, {All, All}},
  ImageSize->400,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{-2, 2}, {0., 19.72674838259419}},
  PlotRangeClipping->False,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.08090169943749476]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.801379782603796*^9, 3.801379803783136*^9}},
 CellLabel->
  "Out[266]=",ExpressionUUID->"fa632fe9-9038-4309-b2be-66b021e2873e"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{837, 774},
WindowMargins->{{163, Automatic}, {-1, Automatic}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 292, 4, 98, "Title",ExpressionUUID->"824dcfa0-5751-4b99-b500-b5712eea01a9"],
Cell[875, 28, 241, 6, 85, "Subtitle",ExpressionUUID->"4f7f9a71-5f70-49fb-8169-5456dfc05bb5"],
Cell[1119, 36, 645, 14, 104, "Text",ExpressionUUID->"d12bce77-43ca-4973-b43c-c30004240db1"],
Cell[CellGroupData[{
Cell[1789, 54, 167, 3, 67, "Section",ExpressionUUID->"59874e66-23fc-4f24-b422-60e6c7ca74dd"],
Cell[1959, 59, 202, 3, 35, "Text",ExpressionUUID->"6c6ecae1-e24a-48b3-961c-b884a480f85c"],
Cell[2164, 64, 591, 15, 73, "Input",ExpressionUUID->"4c791002-f550-4b50-86ef-cd21cf91b294"],
Cell[2758, 81, 282, 8, 35, "Text",ExpressionUUID->"7b3ed350-b501-4db3-860a-28f9ededf6ae"],
Cell[3043, 91, 729, 20, 40, "Input",ExpressionUUID->"6c518972-df53-463a-b986-b39e60b8ffe4"],
Cell[3775, 113, 172, 3, 35, "Text",ExpressionUUID->"dd28e819-9f0e-4742-8e92-994d7c818dab"],
Cell[CellGroupData[{
Cell[3972, 120, 789, 22, 77, "Input",ExpressionUUID->"7b68c253-5f76-4fbe-9c97-f4aeb9fc7a0a"],
Cell[4764, 144, 275, 4, 34, "Output",ExpressionUUID->"4fea19d9-38c9-4338-a4f9-ac6ea84aecac"]
}, Open  ]],
Cell[5054, 151, 381, 11, 48, "Input",ExpressionUUID->"eb44641d-91db-4551-a0d3-3be31fcce33c"],
Cell[5438, 164, 194, 3, 35, "Text",ExpressionUUID->"2c8b3dd8-bb4f-4805-8e99-c1151dceb5dc"],
Cell[5635, 169, 501, 12, 49, "Input",ExpressionUUID->"3935c173-18db-409f-8883-dc0b399276aa"],
Cell[6139, 183, 377, 11, 53, "Input",ExpressionUUID->"9b9721b5-b9cf-4381-9e1d-6c4306657b56"],
Cell[6519, 196, 215, 5, 35, "Text",ExpressionUUID->"ab138e7e-cb39-4324-8b59-bc62c8bc99f9"],
Cell[6737, 203, 379, 11, 47, "Input",ExpressionUUID->"26f623a8-34b3-44ad-a3a8-1dc961b95e86"],
Cell[7119, 216, 270, 6, 35, "Text",ExpressionUUID->"58f2f805-5ac8-42c5-aa5c-a84faba99ddd"],
Cell[7392, 224, 455, 12, 53, "Input",ExpressionUUID->"7534810d-deee-47b1-be64-400c26183171"],
Cell[7850, 238, 591, 17, 42, "Input",ExpressionUUID->"9048dd49-a5bf-487a-93f0-a0a43de71fcd"],
Cell[8444, 257, 277, 6, 35, "Text",ExpressionUUID->"6693868f-016b-4a05-93ed-dd968a07f6ab"],
Cell[8724, 265, 502, 14, 36, "Input",ExpressionUUID->"0daf29b4-16e9-49e7-b546-a603c362d68f"],
Cell[CellGroupData[{
Cell[9251, 283, 178, 3, 54, "Subsection",ExpressionUUID->"81721721-dff7-454c-a8a9-ad0b8dfa50dc"],
Cell[9432, 288, 5802, 137, 716, "Input",ExpressionUUID->"8b7d6aae-fbfd-4492-a81a-7b92c3181bb3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15271, 430, 156, 3, 54, "Subsection",ExpressionUUID->"38780f2e-4c9c-4c18-9881-569ce4fef70a"],
Cell[CellGroupData[{
Cell[15452, 437, 386, 7, 73, "Input",ExpressionUUID->"a68997a7-c527-4e02-9032-369d5deace72"],
Cell[15841, 446, 272, 5, 34, "Output",ExpressionUUID->"8dedf53a-d8f3-4e9c-85bc-d2fa609335b9"],
Cell[CellGroupData[{
Cell[16138, 455, 472, 11, 24, "Print",ExpressionUUID->"69d8931a-ce75-4c2a-bfd2-8922218a7487"],
Cell[16613, 468, 472, 11, 24, "Print",ExpressionUUID->"7e6b0285-5a59-4f3f-84c7-173874cf955b"],
Cell[17088, 481, 474, 11, 24, "Print",ExpressionUUID->"410e337f-1012-40e9-9aee-4072001ef412"],
Cell[17565, 494, 472, 11, 24, "Print",ExpressionUUID->"2b76826f-e585-4869-805a-4e52d7e5eb79"],
Cell[18040, 507, 472, 11, 24, "Print",ExpressionUUID->"d62b71c5-0c5e-43e8-ae7a-b943ef1167d7"],
Cell[18515, 520, 472, 11, 24, "Print",ExpressionUUID->"796d3fde-3d88-49db-a70b-ed90c0c332d8"],
Cell[18990, 533, 471, 11, 24, "Print",ExpressionUUID->"abbd050e-d12f-4764-8fd0-d92e6484ae61"],
Cell[19464, 546, 474, 11, 24, "Print",ExpressionUUID->"0c05bfc4-ff9f-48e0-be2b-430a4acde2c4"],
Cell[19941, 559, 472, 11, 24, "Print",ExpressionUUID->"a279d0f1-b25d-41d5-b281-ca52f85075e8"],
Cell[20416, 572, 472, 11, 24, "Print",ExpressionUUID->"b5ef5cc2-257e-4e08-bd06-e9077a9a1c89"],
Cell[20891, 585, 472, 11, 24, "Print",ExpressionUUID->"761c4f14-b0f1-4b17-b767-0ccd15196272"],
Cell[21366, 598, 469, 11, 24, "Print",ExpressionUUID->"3cd1e69a-1095-4069-b219-f49fe4987e56"],
Cell[21838, 611, 472, 11, 24, "Print",ExpressionUUID->"b75c65c9-3567-4b56-82a1-5954e17f7ee7"],
Cell[22313, 624, 472, 11, 24, "Print",ExpressionUUID->"5f7c52a8-2cba-4f3f-9e85-04f0cd6e2b32"],
Cell[22788, 637, 474, 11, 24, "Print",ExpressionUUID->"1601528b-b854-4056-afee-a5f7c759f70c"],
Cell[23265, 650, 472, 11, 24, "Print",ExpressionUUID->"c1c723ed-ec69-4dd8-b1f5-b3cc4cc68c6f"],
Cell[23740, 663, 472, 11, 24, "Print",ExpressionUUID->"4ca5637b-569c-4522-b4ce-7432788480ba"],
Cell[24215, 676, 468, 11, 24, "Print",ExpressionUUID->"47ec09ad-8548-41e2-92b0-d6cdcf5e9c6b"],
Cell[24686, 689, 472, 11, 24, "Print",ExpressionUUID->"020c5859-af5a-4bd5-a980-1870d40502ca"],
Cell[25161, 702, 471, 11, 24, "Print",ExpressionUUID->"05f0dc67-5b49-452f-b50d-2ec5c75d409d"],
Cell[25635, 715, 468, 11, 24, "Print",ExpressionUUID->"70583d77-1c62-4df7-b027-2d16bede75bf"],
Cell[26106, 728, 472, 11, 24, "Print",ExpressionUUID->"78638122-8707-48de-b5de-22f8a4e3f5c4"],
Cell[26581, 741, 474, 11, 24, "Print",ExpressionUUID->"0a3cb051-5109-427a-86cb-6a3722c4eda1"],
Cell[27058, 754, 472, 11, 24, "Print",ExpressionUUID->"7e5094bf-c58c-4b21-a519-6473944191a8"],
Cell[27533, 767, 472, 11, 24, "Print",ExpressionUUID->"5802a63d-284d-4b69-b3e1-12c997adb086"],
Cell[28008, 780, 474, 11, 24, "Print",ExpressionUUID->"cb86687b-9983-460d-93eb-d25fb694c434"],
Cell[28485, 793, 476, 11, 24, "Print",ExpressionUUID->"09043a44-7018-4458-8265-aea3bd680040"],
Cell[28964, 806, 474, 11, 24, "Print",ExpressionUUID->"ecee2c71-ca11-4352-b841-61ff027bc482"],
Cell[29441, 819, 470, 11, 24, "Print",ExpressionUUID->"cc8e8f25-6cce-40b4-9a53-e47c5f29d772"],
Cell[29914, 832, 472, 11, 24, "Print",ExpressionUUID->"f089efa6-926c-411c-999d-13f449854eed"],
Cell[30389, 845, 472, 11, 24, "Print",ExpressionUUID->"ff79ebbb-35e9-48e4-98d5-88d3fc3a37bd"],
Cell[30864, 858, 468, 11, 24, "Print",ExpressionUUID->"1ed9f935-0e26-4d18-80d5-5b99106074a7"],
Cell[31335, 871, 472, 11, 24, "Print",ExpressionUUID->"0707047f-7243-48c0-8a1f-80c013ddde40"],
Cell[31810, 884, 472, 11, 24, "Print",ExpressionUUID->"3460bc3d-357a-4b6d-a059-27322f22de23"],
Cell[32285, 897, 472, 11, 24, "Print",ExpressionUUID->"a7bcd4fb-b71d-4ca1-aa24-6663f4957410"],
Cell[32760, 910, 472, 11, 24, "Print",ExpressionUUID->"290727cd-0af5-444a-bf2c-fc0918ad6ca8"],
Cell[33235, 923, 468, 11, 24, "Print",ExpressionUUID->"1fe39040-93ea-4024-94eb-da5ee23fda63"],
Cell[33706, 936, 474, 11, 24, "Print",ExpressionUUID->"7b0b939e-6a68-42e0-8175-eeb6db4265fe"],
Cell[34183, 949, 472, 11, 24, "Print",ExpressionUUID->"9ac8aa02-d1ae-4534-a463-62f06d2a9922"],
Cell[34658, 962, 470, 11, 24, "Print",ExpressionUUID->"fd2ea6cd-b3a0-45e9-b7be-4fb7cc96e962"],
Cell[35131, 975, 472, 11, 24, "Print",ExpressionUUID->"44877cc0-ec13-4d3b-9413-e5eac69d0970"],
Cell[35606, 988, 472, 11, 24, "Print",ExpressionUUID->"256f8440-5190-4b80-9e99-0c62c213cb3f"],
Cell[36081, 1001, 474, 11, 24, "Print",ExpressionUUID->"52f463cf-51db-4ca9-9eb1-b888afa66255"],
Cell[36558, 1014, 472, 11, 24, "Print",ExpressionUUID->"cc740316-b899-43f8-99a5-2e2f10808af1"],
Cell[37033, 1027, 474, 11, 24, "Print",ExpressionUUID->"e437219f-e537-46be-95bf-f8446a44afc7"],
Cell[37510, 1040, 474, 11, 24, "Print",ExpressionUUID->"f62df830-26a5-488a-97fd-182786fc4f31"],
Cell[37987, 1053, 472, 11, 24, "Print",ExpressionUUID->"9abfd2ab-c112-4bf6-a027-3a8af36c1eff"],
Cell[38462, 1066, 472, 11, 24, "Print",ExpressionUUID->"2f7b2e8a-2512-43c5-83ee-c98ae363cdc1"],
Cell[38937, 1079, 474, 11, 24, "Print",ExpressionUUID->"4c762987-e59f-4c9b-bc4e-da221767410c"],
Cell[39414, 1092, 472, 11, 24, "Print",ExpressionUUID->"c5e5d76b-01b6-404d-a881-e097683793d6"],
Cell[39889, 1105, 472, 11, 24, "Print",ExpressionUUID->"f5f182b7-b991-46e9-a312-3759a449efa1"],
Cell[40364, 1118, 471, 11, 24, "Print",ExpressionUUID->"be651fb9-84ed-43b5-becc-285ade0948b4"],
Cell[40838, 1131, 472, 11, 24, "Print",ExpressionUUID->"72a69670-00c5-453d-852b-4fc4896501b7"],
Cell[41313, 1144, 472, 11, 24, "Print",ExpressionUUID->"fdd486e8-223e-4f93-ac1e-1ef9a371912d"],
Cell[41788, 1157, 472, 11, 24, "Print",ExpressionUUID->"e19a98f4-01e8-4766-8c33-c4182933bbeb"],
Cell[42263, 1170, 472, 11, 24, "Print",ExpressionUUID->"d1700741-baec-4074-b667-2370312f4434"],
Cell[42738, 1183, 472, 11, 24, "Print",ExpressionUUID->"9f5330f1-6c38-49d2-8475-5846caa7e034"],
Cell[43213, 1196, 472, 11, 24, "Print",ExpressionUUID->"acf589ad-553f-4493-a487-37d1b0e54b73"],
Cell[43688, 1209, 474, 11, 24, "Print",ExpressionUUID->"272ccb43-e675-4242-8954-8f0862f746e4"],
Cell[44165, 1222, 472, 11, 24, "Print",ExpressionUUID->"09ad9cab-a5a0-41ad-a0c9-d4a73cf68771"],
Cell[44640, 1235, 472, 11, 24, "Print",ExpressionUUID->"6c2a1ae0-0590-4f96-b23f-594927215ff1"],
Cell[45115, 1248, 472, 11, 24, "Print",ExpressionUUID->"913f2cf2-148c-409e-8e9f-ca776cdfe3af"],
Cell[45590, 1261, 472, 11, 24, "Print",ExpressionUUID->"4d1cb42d-06de-43cc-8a3e-0afd37945fe3"],
Cell[46065, 1274, 470, 11, 24, "Print",ExpressionUUID->"24456315-4627-4490-ae5b-dba9c137f047"],
Cell[46538, 1287, 472, 11, 24, "Print",ExpressionUUID->"255d85a6-dc34-4f83-ae85-159d94f25e20"]
}, Open  ]],
Cell[47025, 1301, 270, 5, 34, "Output",ExpressionUUID->"9a9c225f-7986-468c-92cb-9be3b70fba30"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[47356, 1313, 173, 3, 67, "Section",ExpressionUUID->"e764da99-c553-4c60-ae7b-b110a8742860"],
Cell[47532, 1318, 387, 11, 47, "Input",ExpressionUUID->"85ff0135-8b2a-460b-9764-27a1b0c9a2ab"],
Cell[47922, 1331, 796, 24, 52, "Input",ExpressionUUID->"f5a95d02-ac38-4386-8006-e68414e1f91f"],
Cell[CellGroupData[{
Cell[48743, 1359, 1279, 35, 73, "Input",ExpressionUUID->"6a7d3762-58db-4daf-8a81-47c6febfd3df"],
Cell[50025, 1396, 34353, 680, 253, "Output",ExpressionUUID->"4492fd5f-db8c-40bf-985c-d129299d2ff3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84415, 2081, 1203, 35, 73, "Input",ExpressionUUID->"d504ca0d-975f-4aea-b11f-3d0b81f1bd41"],
Cell[85621, 2118, 24533, 509, 265, "Output",ExpressionUUID->"fa632fe9-9038-4309-b2be-66b021e2873e"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

