(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    153860,       3403]
NotebookOptionsPosition[    142307,       3224]
NotebookOutlinePosition[    142643,       3239]
CellTagsIndexPosition[    142600,       3236]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Zero-variance-to-escape from a 3D halfspace with isotropic scattering under \
Gamma-2 random flights\
\>", "Title",
 CellChangeTimes->{{3.806554807397616*^9, 
  3.806554831225706*^9}},ExpressionUUID->"0de80e46-e850-4243-9b10-\
130440ad5a73"],

Cell[TextData[{
 "Jaroslav K\[RHacek]iv\[AAcute]nek and Eugene d\[CloseCurlyQuote]Eon\
\[LineSeparator]\[LineSeparator]Supplemental material for ",
 StyleBox["SIGGRAPH 2020",
  FontWeight->"Bold"],
 " course: ",
 StyleBox["Advances in Monte Carlo Rendering: The Legacy of Jaroslav Krivanek",
  FontSlant->"Italic"],
 ".  https://doi.org/10.1145/3388769.3407458"
}], "Text",
 CellChangeTimes->{{3.8025926324724073`*^9, 3.802592646996422*^9}, {
  3.802592692084893*^9, 3.802592707091778*^9}, {3.802592745948763*^9, 
  3.802592782135564*^9}, {3.806554214120068*^9, 
  3.806554240540545*^9}},ExpressionUUID->"c849996f-bd1e-4dfb-b586-\
0feb139a6ae8"],

Cell[CellGroupData[{

Cell["Summary", "Section",
 CellChangeTimes->{{3.806554859332684*^9, 
  3.806554860157164*^9}},ExpressionUUID->"43eb40d8-1d7f-45e8-96ca-\
a550f0d1851b"],

Cell["\<\
This notebook contains two different ways to exactly sample the zero-variance \
walk to escape a 3D half space in generalized radiative transfer (GRT) under \
Gamma-2 random flights between collisions. \
\>", "Text",
 CellChangeTimes->{{3.806554863097533*^9, 
  3.8065549096704283`*^9}},ExpressionUUID->"fd697372-159e-4442-a4bc-\
c67f52c68af6"],

Cell[CellGroupData[{

Cell["Notation", "Subsection",
 CellChangeTimes->{{3.806554911503681*^9, 
  3.8065549122810307`*^9}},ExpressionUUID->"ce47cd10-ba3e-42ee-b35e-\
9feb09d25da5"],

Cell["\<\
Single-scattering albedo: c
Cosine of incoming direction: ui\
\>", "Text",
 CellChangeTimes->{{3.8065549168696632`*^9, 3.806554920913706*^9}, {
  3.806554984458645*^9, 
  3.806554994733966*^9}},ExpressionUUID->"5da7c0ac-33db-433c-9a2a-\
b1e5e8acb632"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Half space - Gamma-2 transport", "Section",
 CellChangeTimes->{{3.744421373046022*^9, 3.744421386403253*^9}, 
   3.806555742025572*^9},ExpressionUUID->"a9c9fce4-4b28-4ceb-a27e-\
0e9c4dc677a1"],

Cell["Analytic albedo (probability to escape the medium):", "Text",
 CellChangeTimes->{{3.806555775783935*^9, 
  3.8065557877810783`*^9}},ExpressionUUID->"58cb0ff6-316f-4c22-9ed0-\
5f0d42517a0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"halfspAProbIsoGamma2`albedo", "[", 
   RowBox[{"c_", ",", "u_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    RowBox[{"2", "+", 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "-", "c"}]], " ", "u"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", 
       SqrtBox[
        RowBox[{"1", "-", "c"}]]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         SqrtBox[
          RowBox[{"1", "-", "c"}]], " ", "u"}]}], ")"}], "2"]}]], " ", 
   FractionBox["c", "2"]}]}]], "Input",
 CellChangeTimes->{{3.72927164760643*^9, 3.729271672314625*^9}, 
   3.7334639375550528`*^9, {3.7438285381952963`*^9, 3.743828575657765*^9}, {
   3.7438289736357603`*^9, 3.7438289852134523`*^9}, 3.7438295809417458`*^9},
 CellLabel->
  "In[4753]:=",ExpressionUUID->"253d4eec-aa24-48bc-8ad9-df51d4d3e01e"],

Cell["importance function for escape:", "Text",
 CellChangeTimes->{{3.744421465483128*^9, 
  3.744421468891789*^9}},ExpressionUUID->"8df90a1c-62cf-402f-9b91-\
a6454379dbb1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"W", "[", 
   RowBox[{"z_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Piecewise", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"z", "\[LessEqual]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", 
           FractionBox["z", "v"]}]], " ", 
         RowBox[{"(", 
          RowBox[{"v", "-", "1"}], ")"}]}], "v"], ",", "True"}], "}"}]}], 
    "}"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.744415569905253*^9, 3.74441560383596*^9}, {
   3.744421488224831*^9, 3.7444214885049*^9}, {3.744502003519833*^9, 
   3.744502019891663*^9}, {3.7445022832772503`*^9, 3.7445022886555233`*^9}, {
   3.744503556389929*^9, 3.744503557712214*^9}, 3.8065557587031527`*^9},
 CellLabel->
  "In[4681]:=",ExpressionUUID->"59005e0a-4a0c-4aa4-bd08-856286c43fd5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Derivation 1", "Section",
 CellChangeTimes->{{3.806554840493545*^9, 3.806554842873069*^9}, {
  3.806555033699008*^9, 
  3.806555035684914*^9}},ExpressionUUID->"b43a5e0b-f454-48f6-8bfa-\
79eb04dcbf14"],

Cell[CellGroupData[{

Cell["GRT statistics for Gamma-2 flights:", "Subsection",
 CellChangeTimes->{{3.806555041659274*^9, 
  3.806555046105866*^9}},ExpressionUUID->"9ea67c27-114f-4133-b543-\
cab7d7c3e86d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Gamma2`pc", "[", "s_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{"-", "s"}], "]"}], "s"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Gamma2`Xc", "[", "s_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Exp", "[", 
    RowBox[{"-", "s"}], "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "+", "s"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Gamma2`pu", "[", "s_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"Exp", "[", 
    RowBox[{"-", "s"}], "]"}], 
   RowBox[{"(", 
    RowBox[{"1", "+", "s"}], ")"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Gamma2`Xu", "[", "s_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", "s"}]], " ", 
   RowBox[{"(", 
    RowBox[{"2", "+", "s"}], ")"}]}]}]}], "Input",
 CellChangeTimes->{{3.744332114416156*^9, 3.744332155585669*^9}, {
  3.744332225500794*^9, 3.74433223185121*^9}},
 CellLabel->
  "In[4813]:=",ExpressionUUID->"5508e65c-6207-4124-a181-0f775b74291d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Various distributions, PDFs, and sampling routines", "Subsection",
 CellChangeTimes->{{3.8065550536649733`*^9, 
  3.806555065942675*^9}},ExpressionUUID->"e8923f22-b3c2-4165-83c4-\
1282ed92a48b"],

Cell[CellGroupData[{

Cell["Initial free-path into medium:", "Subsubsection",
 CellChangeTimes->{{3.806555296478929*^9, 
  3.806555301132803*^9}},ExpressionUUID->"c90c7ffd-24be-4759-b955-\
4913c60dd26d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"entryPDF", "[", 
   RowBox[{"ui_", ",", "v_", ",", "t_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"t", " ", 
        RowBox[{"(", 
         RowBox[{"ui", "+", "v"}], ")"}]}], "v"]}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "t"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"ui", "+", "v"}], ")"}], "2"]}], 
   RowBox[{"v", " ", 
    RowBox[{"(", 
     RowBox[{"ui", "+", 
      RowBox[{"2", " ", "v"}]}], ")"}]}]]}]], "Input",
 CellChangeTimes->{{3.74450357191435*^9, 3.744503581949669*^9}, {
   3.744503630102726*^9, 3.744503649472763*^9}, {3.744503704538378*^9, 
   3.744503706455481*^9}, 3.744503778598826*^9, {3.744504916474401*^9, 
   3.7445049187696877`*^9}},
 CellLabel->
  "In[4817]:=",ExpressionUUID->"517bb267-b44f-436c-91aa-2f46e58f60d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gamma2sample", "[", "scale_", "]"}], ":=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"RandomReal", "[", "]"}], 
      RowBox[{"RandomReal", "[", "]"}]}], "]"}]}], "scale"}]}]], "Input",
 CellChangeTimes->{{3.7445041998768578`*^9, 3.744504247181525*^9}},
 CellLabel->
  "In[4818]:=",ExpressionUUID->"63c5a4e8-829f-4e91-98a4-0b486fafe454"],

Cell[BoxData[
 RowBox[{
  RowBox[{"expsample", "[", "scale_", "]"}], ":=", 
  RowBox[{
   RowBox[{"-", 
    RowBox[{"Log", "[", 
     RowBox[{"RandomReal", "[", "]"}], "]"}]}], "scale"}]}]], "Input",
 CellChangeTimes->{{3.7445047207169857`*^9, 3.744504736689991*^9}},
 CellLabel->
  "In[4819]:=",ExpressionUUID->"deeb7af8-d388-4872-bc29-279f7a170c2f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"entrysample", "[", 
   RowBox[{"ui_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"RandomReal", "[", "]"}], "<", 
       RowBox[{"(", 
        FractionBox[
         RowBox[{
          FractionBox["ui", "v"], "+", "1"}], 
         RowBox[{
          FractionBox["ui", "v"], "+", "2"}]], ")"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"sample", " ", "exp"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"expsample", "[", 
       FractionBox["1", 
        RowBox[{"1", "+", 
         FractionBox["ui", "v"]}]], "]"}], "\[IndentingNewLine]", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"sample", " ", "gamma"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"gamma2sample", "[", 
       FractionBox["1", 
        RowBox[{"1", "+", 
         FractionBox["ui", "v"]}]], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.744504327564702*^9, 3.7445043453278837`*^9}, {
  3.744504748886585*^9, 3.744504808584984*^9}, {3.744504843216528*^9, 
  3.744504847246439*^9}, {3.744504907101821*^9, 3.744504909808688*^9}},
 CellLabel->
  "In[4820]:=",ExpressionUUID->"8af8deb2-f79b-437a-afd3-8f1b261ffa8d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "=", "0.99"}], ",", 
     RowBox[{"v", "=", "13.5"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Histogram", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"entrysample", "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Range", "[", "100000", "]"}]}], "}"}]}], "]"}], ",", 
       "150", ",", "\"\<PDF\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"entryPDF", "[", 
        RowBox[{"u", ",", "v", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{
  3.744504901341896*^9, 3.744504989045223*^9, {3.744505044268196*^9, 
   3.744505123194312*^9}},
 CellLabel->
  "In[4821]:=",ExpressionUUID->"96b34ba1-4312-4361-8be6-ee2c08253dbe"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.301], Thickness[Small]}], {}, 
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.301], Thickness[Small]}], 
      RectangleBox[{0., 0}, {0.1, 0.5436},
       RoundingRadius->0], RectangleBox[{0.1, 0}, {0.2, 0.5602},
       RoundingRadius->0], RectangleBox[{0.2, 0}, {0.3, 0.5279},
       RoundingRadius->0], RectangleBox[{0.3, 0}, {0.4, 0.5095},
       RoundingRadius->0], RectangleBox[{0.4, 0}, {0.5, 0.4973},
       RoundingRadius->0], RectangleBox[{0.5, 0}, {0.6, 0.473},
       RoundingRadius->0], RectangleBox[{0.6, 0}, {0.7, 0.4473},
       RoundingRadius->0], RectangleBox[{0.7, 0}, {0.8, 0.4447},
       RoundingRadius->0], RectangleBox[{0.8, 0}, {0.9, 0.4205},
       RoundingRadius->0], RectangleBox[{0.9, 0}, {1., 0.3885},
       RoundingRadius->0], RectangleBox[{1., 0}, {1.1, 0.3797},
       RoundingRadius->0], RectangleBox[{1.1, 0}, {1.2, 0.3481},
       RoundingRadius->0], RectangleBox[{1.2, 0}, {1.3, 0.3266},
       RoundingRadius->0], RectangleBox[{1.3, 0}, {1.4, 0.3049},
       RoundingRadius->0], RectangleBox[{1.4, 0}, {1.5, 0.2813},
       RoundingRadius->0], RectangleBox[{1.5, 0}, {1.6, 0.2715},
       RoundingRadius->0], RectangleBox[{1.6, 0}, {1.7, 0.2519},
       RoundingRadius->0], RectangleBox[{1.7, 0}, {1.8, 0.2338},
       RoundingRadius->0], RectangleBox[{1.8, 0}, {1.9, 0.2147},
       RoundingRadius->0], RectangleBox[{1.9, 0}, {2., 0.1999},
       RoundingRadius->0], RectangleBox[{2., 0}, {2.1, 0.1833},
       RoundingRadius->0], RectangleBox[{2.1, 0}, {2.2, 0.1746},
       RoundingRadius->0], RectangleBox[{2.2, 0}, {2.3, 0.1638},
       RoundingRadius->0], RectangleBox[{2.3, 0}, {2.4, 0.1501},
       RoundingRadius->0], RectangleBox[{2.4, 0}, {2.5, 0.1368},
       RoundingRadius->0], RectangleBox[{2.5, 0}, {2.6, 0.1256},
       RoundingRadius->0], RectangleBox[{2.6, 0}, {2.7, 0.1214},
       RoundingRadius->0], RectangleBox[{2.7, 0}, {2.8, 0.1095},
       RoundingRadius->0], RectangleBox[{2.8, 0}, {2.9, 0.1002},
       RoundingRadius->0], RectangleBox[{2.9, 0}, {3., 0.0914},
       RoundingRadius->0], RectangleBox[{3., 0}, {3.1, 0.0866},
       RoundingRadius->0], RectangleBox[{3.1, 0}, {3.2, 0.0774},
       RoundingRadius->0], RectangleBox[{3.2, 0}, {3.3, 0.0715},
       RoundingRadius->0], RectangleBox[{3.3, 0}, {3.4, 0.0639},
       RoundingRadius->0], RectangleBox[{3.4, 0}, {3.5, 0.0621},
       RoundingRadius->0], RectangleBox[{3.5, 0}, {3.6, 0.0555},
       RoundingRadius->0], RectangleBox[{3.6, 0}, {3.7, 0.0541},
       RoundingRadius->0], RectangleBox[{3.7, 0}, {3.8, 0.0458},
       RoundingRadius->0], RectangleBox[{3.8, 0}, {3.9, 0.0469},
       RoundingRadius->0], RectangleBox[{3.9, 0}, {4., 0.045},
       RoundingRadius->0], RectangleBox[{4., 0}, {4.1, 0.0366},
       RoundingRadius->0], RectangleBox[{4.1, 0}, {4.2, 0.0323},
       RoundingRadius->0], RectangleBox[{4.2, 0}, {4.3, 0.0276},
       RoundingRadius->0], RectangleBox[{4.3, 0}, {4.4, 0.0248},
       RoundingRadius->0], RectangleBox[{4.4, 0}, {4.5, 0.0242},
       RoundingRadius->0], RectangleBox[{4.5, 0}, {4.6, 0.0245},
       RoundingRadius->0], RectangleBox[{4.6, 0}, {4.7, 0.0186},
       RoundingRadius->0], RectangleBox[{4.7, 0}, {4.8, 0.02},
       RoundingRadius->0], RectangleBox[{4.8, 0}, {4.9, 0.0174},
       RoundingRadius->0], RectangleBox[{4.9, 0}, {5., 0.0162},
       RoundingRadius->0], RectangleBox[{5., 0}, {5.1, 0.0157},
       RoundingRadius->0], RectangleBox[{5.1, 0}, {5.2, 0.0111},
       RoundingRadius->0], RectangleBox[{5.2, 0}, {5.3, 0.0116},
       RoundingRadius->0], RectangleBox[{5.3, 0}, {5.4, 0.0101},
       RoundingRadius->0], RectangleBox[{5.4, 0}, {5.5, 0.0109},
       RoundingRadius->0], RectangleBox[{5.5, 0}, {5.6, 0.0105},
       RoundingRadius->0], RectangleBox[{5.6, 0}, {5.7, 0.0098},
       RoundingRadius->0], RectangleBox[{5.7, 0}, {5.8, 0.0078},
       RoundingRadius->0], RectangleBox[{5.8, 0}, {5.9, 0.0074},
       RoundingRadius->0], RectangleBox[{5.9, 0}, {6., 0.0061},
       RoundingRadius->0], RectangleBox[{6., 0}, {6.1, 0.006},
       RoundingRadius->0], RectangleBox[{6.1, 0}, {6.2, 0.0058},
       RoundingRadius->0], RectangleBox[{6.2, 0}, {6.3, 0.0044},
       RoundingRadius->0], RectangleBox[{6.3, 0}, {6.4, 0.0044},
       RoundingRadius->0], RectangleBox[{6.4, 0}, {6.5, 0.0032},
       RoundingRadius->0], RectangleBox[{6.5, 0}, {6.6, 0.0035},
       RoundingRadius->0], RectangleBox[{6.6, 0}, {6.7, 0.0037},
       RoundingRadius->0], RectangleBox[{6.7, 0}, {6.8, 0.0036},
       RoundingRadius->0], RectangleBox[{6.8, 0}, {6.9, 0.0032},
       RoundingRadius->0], RectangleBox[{6.9, 0}, {7., 0.0021},
       RoundingRadius->0], RectangleBox[{7., 0}, {7.1, 0.0017},
       RoundingRadius->0], RectangleBox[{7.1, 0}, {7.2, 0.0027},
       RoundingRadius->0], RectangleBox[{7.2, 0}, {7.3, 0.0014},
       RoundingRadius->0], RectangleBox[{7.3, 0}, {7.4, 0.0018},
       RoundingRadius->0], RectangleBox[{7.4, 0}, {7.5, 0.0024},
       RoundingRadius->0], RectangleBox[{7.5, 0}, {7.6, 0.0017},
       RoundingRadius->0], RectangleBox[{7.6, 0}, {7.7, 0.0016},
       RoundingRadius->0], RectangleBox[{7.7, 0}, {7.8, 0.0013},
       RoundingRadius->0], RectangleBox[{7.8, 0}, {7.9, 0.0008},
       RoundingRadius->0], RectangleBox[{7.9, 0}, {8., 0.0014},
       RoundingRadius->0], RectangleBox[{8., 0}, {8.1, 0.0008},
       RoundingRadius->0], RectangleBox[{8.1, 0}, {8.2, 0.0011},
       RoundingRadius->0], RectangleBox[{8.2, 0}, {8.3, 0.0008},
       RoundingRadius->0], RectangleBox[{8.3, 0}, {8.4, 0.0009},
       RoundingRadius->0], RectangleBox[{8.4, 0}, {8.5, 0.0002},
       RoundingRadius->0], RectangleBox[{8.5, 0}, {8.6, 0.0007},
       RoundingRadius->0], RectangleBox[{8.6, 0}, {8.7, 0.0004},
       RoundingRadius->0], RectangleBox[{8.7, 0}, {8.8, 0.0007},
       RoundingRadius->0], RectangleBox[{8.8, 0}, {8.9, 0.0003},
       RoundingRadius->0], RectangleBox[{8.9, 0}, {9., 0.0003},
       RoundingRadius->0], RectangleBox[{9., 0}, {9.1, 0.0005},
       RoundingRadius->0], RectangleBox[{9.1, 0}, {9.2, 0.0004},
       RoundingRadius->0], RectangleBox[{9.2, 0}, {9.3, 0.0001},
       RoundingRadius->0], RectangleBox[{9.3, 0}, {9.4, 0.0004},
       RoundingRadius->0], RectangleBox[{9.4, 0}, {9.5, 0.0001},
       RoundingRadius->0], RectangleBox[{9.5, 0}, {9.6, 0.0002},
       RoundingRadius->0], RectangleBox[{9.6, 0}, {9.7, 0.0004},
       RoundingRadius->0], RectangleBox[{9.7, 0}, {9.8, 0.0002},
       RoundingRadius->0], RectangleBox[{9.8, 0}, {9.9, 0.0002},
       RoundingRadius->0], RectangleBox[{9.9, 0}, {10., 0.0001},
       RoundingRadius->0], RectangleBox[{10., 0}, {10.1, 0.0001},
       RoundingRadius->0], RectangleBox[{10.2, 0}, {10.3, 0.0001},
       RoundingRadius->0], RectangleBox[{10.3, 0}, {10.4, 0.0001},
       RoundingRadius->0], RectangleBox[{10.4, 0}, {10.5, 0.0001},
       RoundingRadius->0], RectangleBox[{10.8, 0}, {10.9, 0.0001},
       RoundingRadius->0], RectangleBox[{11.6, 0}, {11.7, 0.0001},
       RoundingRadius->0], RectangleBox[{12., 0}, {12.1, 0.0001},
       RoundingRadius->0], RectangleBox[{12.5, 0}, {12.6, 0.0001},
       RoundingRadius->0], RectangleBox[{12.7, 0}, {12.8, 0.0001},
       RoundingRadius->
        0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVkHs01Hkfx8dlZSmXQZpx+a1cnqhUCl14Pt/SIm0zhlCS3JKGNU1PSqll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        "]]},
      Annotation[#, "Charting`Private`Tag$29873006#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.11, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->NCache[{{0, 
      Rational[11, 2]}, {All, All}}, {{0, 5.5}, {All, All}}],
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.806555482222027*^9, 3.806555802218944*^9, 
  3.806556691926676*^9},
 CellLabel->
  "Out[4821]=",ExpressionUUID->"c8fbd7c0-478d-4993-8bea-c3f65e3f3a47"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Direction samping:", "Subsubsection",
 CellChangeTimes->{{3.8065553306222143`*^9, 
  3.806555332714198*^9}},ExpressionUUID->"f245cd68-4f50-4240-a0ba-\
20e165d745df"],

Cell[BoxData[
 RowBox[{
  RowBox[{"anglePDF", "[", 
   RowBox[{"u_", ",", "v_", ",", "z_"}], "]"}], ":=", 
  TagBox[GridBox[{
     {"\[Piecewise]", GridBox[{
        {
         FractionBox[
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["v", "2"]}], 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"u", "+", "v"}], ")"}], "2"]}]], 
         RowBox[{"u", "\[GreaterEqual]", "0"}]},
        {
         FractionBox[
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "v"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"u", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "v"}], ")"}], " ", "v"}], "+", 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  FractionBox["1", "u"], "+", 
                  FractionBox["1", "v"]}], ")"}], " ", "z"}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"u", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["u", "2"], "+", "v", "+", 
                   RowBox[{"2", " ", "u", " ", "v"}]}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "u"}], ")"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"u", "+", "v"}], ")"}], " ", "z"}]}], ")"}]}]}], 
            ")"}]}], 
          RowBox[{"2", " ", "u", " ", "v", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"u", "+", "v"}], ")"}], "2"]}]], 
         TagBox["True",
          "PiecewiseDefault",
          AutoDelete->True]}
       },
       AllowedDimensions->{2, Automatic},
       Editable->True,
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.84]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}},
       Selectable->True]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxItemSize->{
     "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.35]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   "Piecewise",
   DeleteWithContents->True,
   Editable->False,
   SelectWithContents->True,
   Selectable->False]}]], "Input",
 CellChangeTimes->{{3.744495896120071*^9, 3.744495902334896*^9}, 
   3.744502523589033*^9},
 CellLabel->
  "In[4822]:=",ExpressionUUID->"25eefafa-d5f5-4a0d-a513-f588b3fd02fa"],

Cell["Probablity to sample downwelling direction", "Text",
 CellChangeTimes->{{3.806555397717738*^9, 
  3.806555405945841*^9}},ExpressionUUID->"f507d127-a9d7-4b95-8f1e-\
ce34c2371115"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleDownP", "[", "v_", "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "1"}], "+", "v"}], 
   RowBox[{"2", " ", "v"}]]}]], "Input",
 CellChangeTimes->{{3.7445064218362217`*^9, 3.744506424524897*^9}},
 CellLabel->
  "In[4823]:=",ExpressionUUID->"36d91122-8cf9-481c-91b7-13e447bd8e4d"],

Cell["Down-welling cosine sampling:", "Text",
 CellChangeTimes->{{3.806555414188102*^9, 
  3.806555417796021*^9}},ExpressionUUID->"5ec8ca6a-e418-4ef1-9b19-\
b5c85bbfbba6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleDownDir", "[", "v_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{"v", " ", "#"}], 
     RowBox[{"1", "+", "v", "-", "#"}]], "&"}], "[", 
   RowBox[{"RandomReal", "[", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.744498121870172*^9, 3.744498141036927*^9}},
 CellLabel->
  "In[4824]:=",ExpressionUUID->"d4f0fd67-bc07-4d65-a441-c088310492d2"],

Cell["Up-welling cosine sampling:", "Text",
 CellChangeTimes->{{3.806555437483263*^9, 
  3.8065554416809072`*^9}},ExpressionUUID->"4badf3eb-9cde-4964-a3d9-\
591af2b4cfa1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"df", "[", 
   RowBox[{"u_", ",", "v_", ",", "z_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "v"}], ")"}], " ", "v"}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "u"], "+", 
         FractionBox["1", "v"]}], ")"}], " ", "z"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["u", "2"], "+", "v", "+", 
          RowBox[{"2", " ", "u", " ", "v"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "u"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", "v"}], ")"}], " ", "z"}]}], ")"}]}]}], 
   RowBox[{"u", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "+", "v"}], ")"}], "2"]}]]}]], "Input",
 CellChangeTimes->{{3.744497457174995*^9, 3.744497462518362*^9}, 
   3.744506800439897*^9},
 CellLabel->
  "In[4825]:=",ExpressionUUID->"e1a3d335-592b-418f-a51a-424b1e4723a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f", "[", 
   RowBox[{"k_", ",", "v_", ",", "z_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", "k"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "k"], "+", 
           FractionBox["1", "v"]}], ")"}], " ", "z"}]], " ", "k"}], "+", 
      "v"}], ")"}]}], 
   RowBox[{"k", "+", "v"}]]}]], "Input",
 CellChangeTimes->{{3.744497466476797*^9, 3.744497474949079*^9}, 
   3.7445068724457397`*^9},
 CellLabel->
  "In[4826]:=",ExpressionUUID->"271febe2-097c-49f8-879e-793ffb240a85"],

Cell["3 iterations of Newton\[CloseCurlyQuote]s method:", "Text",
 CellChangeTimes->{{3.7444979127149887`*^9, 3.7444979298876257`*^9}, {
  3.744508682123534*^9, 
  3.744508682617424*^9}},ExpressionUUID->"3c0bc073-af7f-44d7-8b9a-\
5de0f1fea88e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleUpDir", "[", 
   RowBox[{"z_", ",", "v_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "u0", ",", "u1", ",", "u2", ",", "u3"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"x", "=", 
      RowBox[{"RandomReal", "[", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"find", " ", "root", " ", "of", " ", 
        RowBox[{"f", "[", 
         RowBox[{"u", ",", "v", ",", "z"}], "]"}]}], " ", "-", " ", "x"}], 
      " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"u0", "=", 
      RowBox[{"-", "0.5"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"u1", "=", 
      RowBox[{"u0", "-", 
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"u0", ",", "v", ",", "z"}], "]"}], "-", "x"}], 
        RowBox[{"df", "[", 
         RowBox[{"u0", ",", "v", ",", "z"}], "]"}]]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"u2", "=", 
      RowBox[{"u1", "-", 
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"u1", ",", "v", ",", "z"}], "]"}], "-", "x"}], 
        RowBox[{"df", "[", 
         RowBox[{"u1", ",", "v", ",", "z"}], "]"}]]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"u3", "=", 
      RowBox[{"u2", "-", 
       FractionBox[
        RowBox[{
         RowBox[{"f", "[", 
          RowBox[{"u2", ",", "v", ",", "z"}], "]"}], "-", "x"}], 
        RowBox[{"df", "[", 
         RowBox[{"u2", ",", "v", ",", "z"}], "]"}]]}]}], ";", 
     "\[IndentingNewLine]", "u3"}]}], "\[IndentingNewLine]", "]"}]}]], "Input",\

 CellChangeTimes->{{3.744497506164846*^9, 3.74449759939706*^9}, {
  3.744497663893488*^9, 3.74449768503953*^9}, {3.744497724741213*^9, 
  3.744497744599338*^9}, {3.744497909724209*^9, 3.744497951502446*^9}, {
  3.7444980447743196`*^9, 3.7444980468722982`*^9}, {3.744499521837256*^9, 
  3.744499529534622*^9}},
 CellLabel->
  "In[4827]:=",ExpressionUUID->"f278e38d-40fe-4bbd-8f81-83c3fbb26cd9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"z", "=", "0.15"}], ",", 
     RowBox[{"v", "=", "3.1"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Histogram", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"sampleUpDir", "[", 
          RowBox[{"z", ",", "v"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Range", "[", "10000", "]"}]}], "}"}]}], "]"}], ",", "150",
        ",", "\"\<PDF\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"df", "[", 
        RowBox[{"u", ",", "v", ",", "z"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"u", ",", 
         RowBox[{"-", "1"}], ",", "0"}], "}"}], ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.744506907304538*^9, 3.744506959333057*^9}, {
  3.7445069964362507`*^9, 3.744507039079104*^9}},
 CellLabel->
  "In[4828]:=",ExpressionUUID->"f94b6a31-780d-4261-b5ba-a12eef354873"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[
     Opacity[0.]], {}, 
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[
      Opacity[0.]], RectangleBox[{-1., 0}, {-0.995, 1.24},
       RoundingRadius->0], RectangleBox[{-0.995, 0}, {-0.99, 1.02},
       RoundingRadius->0], RectangleBox[{-0.99, 0}, {-0.985, 1.06},
       RoundingRadius->0], RectangleBox[{-0.985, 0}, {-0.98, 1.02},
       RoundingRadius->0], RectangleBox[{-0.98, 0}, {-0.975, 1.28},
       RoundingRadius->0], RectangleBox[{-0.975, 0}, {-0.97, 0.74},
       RoundingRadius->0], RectangleBox[{-0.97, 0}, {-0.965, 1.28},
       RoundingRadius->0], RectangleBox[{-0.965, 0}, {-0.96, 1.12},
       RoundingRadius->0], RectangleBox[{-0.96, 0}, {-0.955, 1.42},
       RoundingRadius->0], RectangleBox[{-0.955, 0}, {-0.95, 1.34},
       RoundingRadius->0], RectangleBox[{-0.95, 0}, {-0.945, 1.02},
       RoundingRadius->0], RectangleBox[{-0.945, 0}, {-0.94, 1.12},
       RoundingRadius->0], RectangleBox[{-0.94, 0}, {-0.935, 1.3},
       RoundingRadius->0], RectangleBox[{-0.935, 0}, {-0.93, 1.04},
       RoundingRadius->0], RectangleBox[{-0.93, 0}, {-0.925, 0.86},
       RoundingRadius->0], RectangleBox[{-0.925, 0}, {-0.92, 1.14},
       RoundingRadius->0], RectangleBox[{-0.92, 0}, {-0.915, 1.},
       RoundingRadius->0], RectangleBox[{-0.915, 0}, {-0.91, 1.2},
       RoundingRadius->0], RectangleBox[{-0.91, 0}, {-0.905, 0.9},
       RoundingRadius->0], RectangleBox[{-0.905, 0}, {-0.9, 1.18},
       RoundingRadius->0], RectangleBox[{-0.9, 0}, {-0.895, 0.96},
       RoundingRadius->0], RectangleBox[{-0.895, 0}, {-0.89, 1.06},
       RoundingRadius->0], RectangleBox[{-0.89, 0}, {-0.885, 0.98},
       RoundingRadius->0], RectangleBox[{-0.885, 0}, {-0.88, 1.2},
       RoundingRadius->0], RectangleBox[{-0.88, 0}, {-0.875, 0.88},
       RoundingRadius->0], RectangleBox[{-0.875, 0}, {-0.87, 0.9},
       RoundingRadius->0], RectangleBox[{-0.87, 0}, {-0.865, 0.94},
       RoundingRadius->0], RectangleBox[{-0.865, 0}, {-0.86, 1.16},
       RoundingRadius->0], RectangleBox[{-0.86, 0}, {-0.855, 1.22},
       RoundingRadius->0], RectangleBox[{-0.855, 0}, {-0.85, 1.08},
       RoundingRadius->0], RectangleBox[{-0.85, 0}, {-0.845, 1.14},
       RoundingRadius->0], RectangleBox[{-0.845, 0}, {-0.84, 1.02},
       RoundingRadius->0], RectangleBox[{-0.84, 0}, {-0.835, 0.94},
       RoundingRadius->0], RectangleBox[{-0.835, 0}, {-0.83, 1.28},
       RoundingRadius->0], RectangleBox[{-0.83, 0}, {-0.825, 1.14},
       RoundingRadius->0], RectangleBox[{-0.825, 0}, {-0.82, 1.3},
       RoundingRadius->0], RectangleBox[{-0.82, 0}, {-0.815, 0.82},
       RoundingRadius->0], RectangleBox[{-0.815, 0}, {-0.81, 0.96},
       RoundingRadius->0], RectangleBox[{-0.81, 0}, {-0.805, 1.14},
       RoundingRadius->0], RectangleBox[{-0.805, 0}, {-0.8, 0.9},
       RoundingRadius->0], RectangleBox[{-0.8, 0}, {-0.795, 1.06},
       RoundingRadius->0], RectangleBox[{-0.795, 0}, {-0.79, 1.26},
       RoundingRadius->0], RectangleBox[{-0.79, 0}, {-0.785, 1.02},
       RoundingRadius->0], RectangleBox[{-0.785, 0}, {-0.78, 1.14},
       RoundingRadius->0], RectangleBox[{-0.78, 0}, {-0.775, 0.86},
       RoundingRadius->0], RectangleBox[{-0.775, 0}, {-0.77, 0.86},
       RoundingRadius->0], RectangleBox[{-0.77, 0}, {-0.765, 0.76},
       RoundingRadius->0], RectangleBox[{-0.765, 0}, {-0.76, 1.14},
       RoundingRadius->0], RectangleBox[{-0.76, 0}, {-0.755, 1.14},
       RoundingRadius->0], RectangleBox[{-0.755, 0}, {-0.75, 1.24},
       RoundingRadius->0], RectangleBox[{-0.75, 0}, {-0.745, 1.04},
       RoundingRadius->0], RectangleBox[{-0.745, 0}, {-0.74, 1.1},
       RoundingRadius->0], RectangleBox[{-0.74, 0}, {-0.735, 0.78},
       RoundingRadius->0], RectangleBox[{-0.735, 0}, {-0.73, 0.88},
       RoundingRadius->0], RectangleBox[{-0.73, 0}, {-0.725, 1.02},
       RoundingRadius->0], RectangleBox[{-0.725, 0}, {-0.72, 0.88},
       RoundingRadius->0], RectangleBox[{-0.72, 0}, {-0.715, 1.16},
       RoundingRadius->0], RectangleBox[{-0.715, 0}, {-0.71, 1.08},
       RoundingRadius->0], RectangleBox[{-0.71, 0}, {-0.705, 0.9},
       RoundingRadius->0], RectangleBox[{-0.705, 0}, {-0.7, 1.26},
       RoundingRadius->0], RectangleBox[{-0.7, 0}, {-0.695, 1.02},
       RoundingRadius->0], RectangleBox[{-0.695, 0}, {-0.69, 1.2},
       RoundingRadius->0], RectangleBox[{-0.69, 0}, {-0.685, 0.94},
       RoundingRadius->0], RectangleBox[{-0.685, 0}, {-0.68, 0.94},
       RoundingRadius->0], RectangleBox[{-0.68, 0}, {-0.675, 0.9},
       RoundingRadius->0], RectangleBox[{-0.675, 0}, {-0.67, 1.16},
       RoundingRadius->0], RectangleBox[{-0.67, 0}, {-0.665, 1.02},
       RoundingRadius->0], RectangleBox[{-0.665, 0}, {-0.66, 0.84},
       RoundingRadius->0], RectangleBox[{-0.66, 0}, {-0.655, 0.84},
       RoundingRadius->0], RectangleBox[{-0.655, 0}, {-0.65, 0.92},
       RoundingRadius->0], RectangleBox[{-0.65, 0}, {-0.645, 1.24},
       RoundingRadius->0], RectangleBox[{-0.645, 0}, {-0.64, 1.06},
       RoundingRadius->0], RectangleBox[{-0.64, 0}, {-0.635, 1.06},
       RoundingRadius->0], RectangleBox[{-0.635, 0}, {-0.63, 0.78},
       RoundingRadius->0], RectangleBox[{-0.63, 0}, {-0.625, 0.92},
       RoundingRadius->0], RectangleBox[{-0.625, 0}, {-0.62, 1.04},
       RoundingRadius->0], RectangleBox[{-0.62, 0}, {-0.615, 1.},
       RoundingRadius->0], RectangleBox[{-0.615, 0}, {-0.61, 1.02},
       RoundingRadius->0], RectangleBox[{-0.61, 0}, {-0.605, 0.92},
       RoundingRadius->0], RectangleBox[{-0.605, 0}, {-0.6, 1.24},
       RoundingRadius->0], RectangleBox[{-0.6, 0}, {-0.595, 1.14},
       RoundingRadius->0], RectangleBox[{-0.595, 0}, {-0.59, 1.28},
       RoundingRadius->0], RectangleBox[{-0.59, 0}, {-0.585, 1.26},
       RoundingRadius->0], RectangleBox[{-0.585, 0}, {-0.58, 1.04},
       RoundingRadius->0], RectangleBox[{-0.58, 0}, {-0.575, 0.96},
       RoundingRadius->0], RectangleBox[{-0.575, 0}, {-0.57, 1.2},
       RoundingRadius->0], RectangleBox[{-0.57, 0}, {-0.565, 0.94},
       RoundingRadius->0], RectangleBox[{-0.565, 0}, {-0.56, 0.98},
       RoundingRadius->0], RectangleBox[{-0.56, 0}, {-0.555, 0.92},
       RoundingRadius->0], RectangleBox[{-0.555, 0}, {-0.55, 0.94},
       RoundingRadius->0], RectangleBox[{-0.55, 0}, {-0.545, 0.84},
       RoundingRadius->0], RectangleBox[{-0.545, 0}, {-0.54, 1.14},
       RoundingRadius->0], RectangleBox[{-0.54, 0}, {-0.535, 1.06},
       RoundingRadius->0], RectangleBox[{-0.535, 0}, {-0.53, 1.2},
       RoundingRadius->0], RectangleBox[{-0.53, 0}, {-0.525, 0.96},
       RoundingRadius->0], RectangleBox[{-0.525, 0}, {-0.52, 1.26},
       RoundingRadius->0], RectangleBox[{-0.52, 0}, {-0.515, 1.06},
       RoundingRadius->0], RectangleBox[{-0.515, 0}, {-0.51, 1.12},
       RoundingRadius->0], RectangleBox[{-0.51, 0}, {-0.505, 1.2},
       RoundingRadius->0], RectangleBox[{-0.505, 0}, {-0.5, 1.32},
       RoundingRadius->0], RectangleBox[{-0.5, 0}, {-0.495, 1.06},
       RoundingRadius->0], RectangleBox[{-0.495, 0}, {-0.49, 1.3},
       RoundingRadius->0], RectangleBox[{-0.49, 0}, {-0.485, 1.},
       RoundingRadius->0], RectangleBox[{-0.485, 0}, {-0.48, 0.94},
       RoundingRadius->0], RectangleBox[{-0.48, 0}, {-0.475, 0.94},
       RoundingRadius->0], RectangleBox[{-0.475, 0}, {-0.47, 1.14},
       RoundingRadius->0], RectangleBox[{-0.47, 0}, {-0.465, 1.34},
       RoundingRadius->0], RectangleBox[{-0.465, 0}, {-0.46, 0.9},
       RoundingRadius->0], RectangleBox[{-0.46, 0}, {-0.455, 1.26},
       RoundingRadius->0], RectangleBox[{-0.455, 0}, {-0.45, 1.12},
       RoundingRadius->0], RectangleBox[{-0.45, 0}, {-0.445, 1.08},
       RoundingRadius->0], RectangleBox[{-0.445, 0}, {-0.44, 1.},
       RoundingRadius->0], RectangleBox[{-0.44, 0}, {-0.435, 0.94},
       RoundingRadius->0], RectangleBox[{-0.435, 0}, {-0.43, 1.18},
       RoundingRadius->0], RectangleBox[{-0.43, 0}, {-0.425, 1.1},
       RoundingRadius->0], RectangleBox[{-0.425, 0}, {-0.42, 0.92},
       RoundingRadius->0], RectangleBox[{-0.42, 0}, {-0.415, 0.86},
       RoundingRadius->0], RectangleBox[{-0.415, 0}, {-0.41, 1.06},
       RoundingRadius->0], RectangleBox[{-0.41, 0}, {-0.405, 1.04},
       RoundingRadius->0], RectangleBox[{-0.405, 0}, {-0.4, 1.06},
       RoundingRadius->0], RectangleBox[{-0.4, 0}, {-0.395, 1.08},
       RoundingRadius->0], RectangleBox[{-0.395, 0}, {-0.39, 1.14},
       RoundingRadius->0], RectangleBox[{-0.39, 0}, {-0.385, 0.82},
       RoundingRadius->0], RectangleBox[{-0.385, 0}, {-0.38, 0.8},
       RoundingRadius->0], RectangleBox[{-0.38, 0}, {-0.375, 0.74},
       RoundingRadius->0], RectangleBox[{-0.375, 0}, {-0.37, 1.22},
       RoundingRadius->0], RectangleBox[{-0.37, 0}, {-0.365, 1.06},
       RoundingRadius->0], RectangleBox[{-0.365, 0}, {-0.36, 1.24},
       RoundingRadius->0], RectangleBox[{-0.36, 0}, {-0.355, 1.02},
       RoundingRadius->0], RectangleBox[{-0.355, 0}, {-0.35, 1.14},
       RoundingRadius->0], RectangleBox[{-0.35, 0}, {-0.345, 1.1},
       RoundingRadius->0], RectangleBox[{-0.345, 0}, {-0.34, 1.1},
       RoundingRadius->0], RectangleBox[{-0.34, 0}, {-0.335, 0.92},
       RoundingRadius->0], RectangleBox[{-0.335, 0}, {-0.33, 0.88},
       RoundingRadius->0], RectangleBox[{-0.33, 0}, {-0.325, 1.16},
       RoundingRadius->0], RectangleBox[{-0.325, 0}, {-0.32, 0.72},
       RoundingRadius->0], RectangleBox[{-0.32, 0}, {-0.315, 0.9},
       RoundingRadius->0], RectangleBox[{-0.315, 0}, {-0.31, 0.92},
       RoundingRadius->0], RectangleBox[{-0.31, 0}, {-0.305, 0.74},
       RoundingRadius->0], RectangleBox[{-0.305, 0}, {-0.3, 0.92},
       RoundingRadius->0], RectangleBox[{-0.3, 0}, {-0.295, 0.96},
       RoundingRadius->0], RectangleBox[{-0.295, 0}, {-0.29, 0.96},
       RoundingRadius->0], RectangleBox[{-0.29, 0}, {-0.285, 0.84},
       RoundingRadius->0], RectangleBox[{-0.285, 0}, {-0.28, 0.96},
       RoundingRadius->0], RectangleBox[{-0.28, 0}, {-0.275, 0.98},
       RoundingRadius->0], RectangleBox[{-0.275, 0}, {-0.27, 1.2},
       RoundingRadius->0], RectangleBox[{-0.27, 0}, {-0.265, 1.04},
       RoundingRadius->0], RectangleBox[{-0.265, 0}, {-0.26, 0.86},
       RoundingRadius->0], RectangleBox[{-0.26, 0}, {-0.255, 1.08},
       RoundingRadius->0], RectangleBox[{-0.255, 0}, {-0.25, 1.22},
       RoundingRadius->0], RectangleBox[{-0.25, 0}, {-0.245, 0.98},
       RoundingRadius->0], RectangleBox[{-0.245, 0}, {-0.24, 1.14},
       RoundingRadius->0], RectangleBox[{-0.24, 0}, {-0.235, 0.88},
       RoundingRadius->0], RectangleBox[{-0.235, 0}, {-0.23, 0.8},
       RoundingRadius->0], RectangleBox[{-0.23, 0}, {-0.225, 1.1},
       RoundingRadius->0], RectangleBox[{-0.225, 0}, {-0.22, 0.84},
       RoundingRadius->0], RectangleBox[{-0.22, 0}, {-0.215, 0.96},
       RoundingRadius->0], RectangleBox[{-0.215, 0}, {-0.21, 1.},
       RoundingRadius->0], RectangleBox[{-0.21, 0}, {-0.205, 1.18},
       RoundingRadius->0], RectangleBox[{-0.205, 0}, {-0.2, 1.02},
       RoundingRadius->0], RectangleBox[{-0.2, 0}, {-0.195, 0.56},
       RoundingRadius->0], RectangleBox[{-0.195, 0}, {-0.19, 0.86},
       RoundingRadius->0], RectangleBox[{-0.19, 0}, {-0.185, 0.76},
       RoundingRadius->0], RectangleBox[{-0.185, 0}, {-0.18, 0.96},
       RoundingRadius->0], RectangleBox[{-0.18, 0}, {-0.175, 0.98},
       RoundingRadius->0], RectangleBox[{-0.175, 0}, {-0.17, 0.98},
       RoundingRadius->0], RectangleBox[{-0.17, 0}, {-0.165, 1.14},
       RoundingRadius->0], RectangleBox[{-0.165, 0}, {-0.16, 0.88},
       RoundingRadius->0], RectangleBox[{-0.16, 0}, {-0.155, 0.98},
       RoundingRadius->0], RectangleBox[{-0.155, 0}, {-0.15, 0.78},
       RoundingRadius->0], RectangleBox[{-0.15, 0}, {-0.145, 0.62},
       RoundingRadius->0], RectangleBox[{-0.145, 0}, {-0.14, 0.94},
       RoundingRadius->0], RectangleBox[{-0.14, 0}, {-0.135, 0.86},
       RoundingRadius->0], RectangleBox[{-0.135, 0}, {-0.13, 0.92},
       RoundingRadius->0], RectangleBox[{-0.13, 0}, {-0.125, 0.98},
       RoundingRadius->0], RectangleBox[{-0.125, 0}, {-0.12, 0.72},
       RoundingRadius->0], RectangleBox[{-0.12, 0}, {-0.115, 1.04},
       RoundingRadius->0], RectangleBox[{-0.115, 0}, {-0.11, 1.18},
       RoundingRadius->0], RectangleBox[{-0.11, 0}, {-0.105, 0.94},
       RoundingRadius->0], RectangleBox[{-0.105, 0}, {-0.1, 0.84},
       RoundingRadius->0], RectangleBox[{-0.1, 0}, {-0.095, 0.96},
       RoundingRadius->0], RectangleBox[{-0.095, 0}, {-0.09, 0.66},
       RoundingRadius->0], RectangleBox[{-0.09, 0}, {-0.085, 0.8},
       RoundingRadius->0], RectangleBox[{-0.085, 0}, {-0.08, 1.},
       RoundingRadius->0], RectangleBox[{-0.08, 0}, {-0.075, 0.94},
       RoundingRadius->0], RectangleBox[{-0.075, 0}, {-0.07, 0.96},
       RoundingRadius->0], RectangleBox[{-0.07, 0}, {-0.065, 0.92},
       RoundingRadius->0], RectangleBox[{-0.065, 0}, {-0.06, 0.7},
       RoundingRadius->0], RectangleBox[{-0.06, 0}, {-0.055, 0.74},
       RoundingRadius->0], RectangleBox[{-0.055, 0}, {-0.05, 0.72},
       RoundingRadius->0], RectangleBox[{-0.05, 0}, {-0.045, 0.82},
       RoundingRadius->0], RectangleBox[{-0.045, 0}, {-0.04, 0.84},
       RoundingRadius->0], RectangleBox[{-0.04, 0}, {-0.035, 0.8},
       RoundingRadius->0], RectangleBox[{-0.035, 0}, {-0.03, 0.64},
       RoundingRadius->0], RectangleBox[{-0.03, 0}, {-0.025, 0.78},
       RoundingRadius->0], RectangleBox[{-0.025, 0}, {-0.02, 0.44},
       RoundingRadius->0], RectangleBox[{-0.02, 0}, {-0.015, 0.46},
       RoundingRadius->0], RectangleBox[{-0.015, 0}, {-0.01, 0.9},
       RoundingRadius->0], RectangleBox[{-0.01, 0}, {-0.005, 0.68},
       RoundingRadius->0], RectangleBox[{-0.005, 0}, {0., 0.7},
       RoundingRadius->
        0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, {{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1Xs4lFsXAHBpSpGoKCWEjqQiQg5qlSKFioSkoxSSLi5RcqlIRKRyKyXX
ZIpBrpHlFhojRYRzEJkxzOV9I9fEN98f+9nP74/1rL3Wftbeik5XrJyFhYSE
vgvW//cEBbHx+XkCd1ufG7xaQULp7Iq6gD8EnrKNLfISuLNL5vH0DIGvNh+4
6yHwulgVzbFxAjVeaqtcFPjZEqNLLA6B3wbVTp8VOOXndSbjG4F5fmcrLAWm
1rLan9AIPLNhRkpd4ArXmuIdjgRaFOvuZpaTcGFk0fj3PD6+9pOYBIElvu+M
kF3Ox1qGNpH0joR/dQaCwy7zcNrXwOhnGQma9TJTF6u56B5wSHGrwIEfd9X1
KXCxnj/LcS0lwUqEWMbw4KByqE/pnRISjmTKlA3XjaC51Zl7ccUkGBVvr4jd
OIINA3EZL4tIwAXtBmW+w+iippIXU0iCVpXrSvevbPTxlynwe0sCo9fL/LAO
Gw+9WLvCuoAEcqfowtfhQ6gVee35bB4JopQYybghFl6avWaXRiMhVzTt6ZQe
Cyvl50rEcknw89waHhXFRJ77coMTb0jQN8tk0HiDaHjbsCmFSkKoIzXKbM8g
5igsm094RUI963nm1eQfmB4LN+68JOHhKzn9NcQAbuyzeLQsg4QQurQWx2gA
AzP2jTimkuDuOHvLPK0fIxS7O14kk9CjfsV806/vaKWbMm2VRIKx5+fLDyy/
Y6Pi336sBBKyN1kPW57rw3+mOlO3xgr626/Avybaiwq/Rq5lPSBh5nZjSmnD
fzgrZ79xJIKErQn3zLlu/6KO547960NJeHPRAINXduPTzGG950EkrFWl9+1o
7cScznvKRddIeGLnOf3N9xvOSCfuWn+FhMVXxqvitTrw+I0M+3ZnEqqNLxwp
/fUVe7hOFMuTJMQ8nOxgJLVhbnAC5ZcFCbb6zY8/xLfhQV23svcCy/9IO1r5
sA0TApTNwgR+o32YTgtrQy1aF2WdwI3fMt4/8m7DFzp/mneZkzAvZ5VhZ9aG
5T36z4IOkXCZ+sZzcKYVo+HeoUETEsxqzyybPdGKXtsL7ukBCaxm2bhw61Y0
yZ1aMbabhODOdjnpI63YO8Z2yRG4lHdQQ31/Ky7aP+ejKPBGGS2r0+qt+Drf
S1lkFwlzF4UT64Rb8cSPS9GN+iQUrE5Xjnr9BXOn2epKuoL+XBjUl//zGUup
0aIbt5Jgzj6uLjL1GY/p7ktq30JCkEuDIjn6GZeV3Bi9K/CgE3VJDfszLrGJ
HWOrkZB30qPD+etnjCs/ok/dTIKpxaxnzuvP+J/eZJbiJhJ8t0tlG9p/xuYO
XZcBRRJe8cLUiy+3YLqQUcTz1SRIeqRtKT/Xgo3NHYV7BL4+WqFaZd+C3bXp
iT+kSTg4+VOJbtKCGQfpEaoCjwg5rOmVb8Ftl7xX0FaRsE1qu9Dilk94cLPj
+VxJQX36nV+Oa3xChsuE2lVRwTyHqfqMEwx0+G1xRmqGgOZmMVElJgO7Jpus
FKYJ6F1FJB/uZuCS1s6Lm6cIEEopasyqY6CEXuVqgwkC9pUarbd/wkCx/v0q
1qME0NkOtZVGDGQPS1s7jBDQdfDhivC4JqT1bHr+vouACbGZnHUGdAyoNrG4
U0SA7t/mMkKadMxN7LBzLiTA1yU5mKlCxxLlv84bvyVgssrINm8lHYOf3IgS
zidgyidSyGTkIzZISLd5vCHgd9/6Y55PPuJKjp7x+nTB+QphqmGyEW+6+B94
+YCAPf0PnXJ4jfjBTz/AOZqAW8sHGY9+NOLG0itRylEELHALTz3V0ohO7/6D
ZxEECMt/OTT2shEreooqb4YSQAl3ei5v04hUrZc8cX8CljqEGvkUNmDL22Wk
oTMBo+Yp+4OzG7BD8uuH4rMEdO8qN3mQ3IBXOOLLNZwIeKPw81B2eAMKa1J5
6xwJOPrD4ViPQwNe4IXR+uwISLygfc54UQOmy8qdlTUnQMXvR6i0TT1uWaky
b6ZJgMSFuTAls3pMlW7gPtAQ1G+/NkJjTz0yldsprdsE/TY8En1QrR7XjAD1
qBoBl4TK4wPnPmC9bkbITmUCCsMeZTFffsCUkq/bsqUE9xW/92PRZB1yA9+e
XzrBB3Xx2P5xbh2qem9pWP2LD+vusKZ1BurQhGW7TGmUD6RnpFoxow470oxB
i8+HZIv2yOLUOlQ0LRrXY/FhiuJ2uMSsDu2OeYr0tPMh1zumrfRFLdb5DX52
e8uHpyMDnKnYWlxuky+lns+H0DM6lL8jajF58+MuIpcPDke6tcuu1qJx9+1O
dyoflm7ZGF92sBbF9u47YJzKh3MDJXbvxmqwRE6p5Ea04HyWfT3lB2qwJbpP
tt2FDzq0lKbCXTW4caTzyeVzfDgq7lSWs6MGm0M231rkJMj3cTD2hUINTu0b
uLbllKCevSNmIZPV2Jounm97jA/1WuNlh7KqMVF5TFkd+OAlJRbftbgaVT65
vi+V4kOUFyOkdbYKr3rtVZpawYdXn6M8m0arkAgr9tGW4EPPfUmL971VWNaN
39KX8sF00WpKanEVimjIrjw1xwP5iQ1e512q8MOvyKc6QzyIpV16xo9EHDrC
iXQs5oHs2O0sDV/E5tQCKlHAgzTd+AKP04imlKpgfxoPaO8rG0e1EY9zzhrf
fcUDepPE+ERPJfbq/HvG9SkP5ofyLeY1KvGbr6uRVSAPLmyYmJP4WoH7D3Qp
JgEPfp4VFbWsrMCVCWm34gx4cD1LXvrRqwrMLTn1PmInD0LVD2yRCqzAANWx
AmcNHqQYJtrKqFRg1wCj4j95HnTY6edtuF6OI7F6aY2zXNj7MOiM5vp3uDjo
9vfThVxQSfdYMyjyDtPOJQVM0biwrMipOX6sDL1m99VFvOZCR6fJ37P0MhSt
sTF4kcaFixskVjT4lWF2lpdYWAwXEmkvqhy+laK7nOY+c3cukM1VCuGPSrBA
3cMucL0gvq+gXT+oBP9bvHz3qTVcKP+ZEclzK8GTymsmdFdy4a70vUmrvSV4
V7+55psIF9afsmyRI4vx2stu6U+jHDDl9ge9tSjG6m3tv8IaOJAiurC3d0kR
lg8q+C26yIEI1XNVk78K8e1i/wBNFw74mHxIk+wvxL5wzU6b0xw4FBzmalRW
iMUVVXejrDkwNi32M9OtECucX5tSDTlgMixFuUR/ix7j4QuTxTjAa1BR+x1Z
gDqBTnP2GSOgH3rId41EHvYGztvsrx4GjvUNyflRmuA9ia+WLRsGpxeO2i0N
NBSX0fvNyRsGS221gCueNJwbCVO5ljIM6v+gWF5dLmbubXqqf3MYhvKH1TTd
c5Adcl840mAY7E/sdttRSkXhoiKKdh4bvgi+r4VRVPyxv2XtqSw2mPKX5Led
oaLtdt6VkGQ27Axpm/IWo+I7z1/0xvtskMo5H174TzZKc+9L7nJjQ7PQ4yyd
Ra+w1qkjcokSG/a8GmLutMrEZfkft96IGwKfB+GOnM2ZeHj7F8bVqCGg+m7u
Sl6Qifs8nIp8Q4dglbE7Y1F+Bk4N+Y0/9BkCVj+/oE0iAy2E65M1bYbgvuzE
zSvNaag0ueejz9ohqBZOmFbKTENxb8vgNSuHYGJ4p3dHQBr62x0PbBAdAsdS
P5ddW9Pwodp1eetZFmgd/2MuFpmKdrqrPLZ9Z0FnNGVdlmkKWokvZZi9ZoG4
b+Zj+w0pOO8VSYpmsiDk3f1168kX6OV3gNOXzAIbW8kFI4df4DPuWtXmRyyY
jVnzKXRZMq47nJVY5c8CF8cT1dzy59gvk3xM35cFLduSCo+5P8cjHks3NXuw
II0un6RIf4YLY0N9wIUFphSV8+/DkpBm7azraMWCglbXkxt3JqFjG2lNtWCB
bGr24UjWU+xvuFEleZAF/F3bdE4YP0Wdi17K2/ewIPaatvC48BN0aJLll2uw
YM7Yd/xkQSL26y2/PriFBa5SpeyaM4n4PFGhQVWVBfr5Bi0xVQn4u+m8CUWR
Bd9HjJ5tDYpHmAu5v0CKBW5HzIkdG+NRKimk47UkC0bfHjcyoMdh1u6zpr7i
LKAEnmcfXB2HHylyf7mJsCCq39PAsiIWVTqsVWIoLFht4h9t5xSLuxhpAV8X
sEBVIlrbNfcxloUVpebPMiHfOyHssvVjZKSLhZnOMEG/M6XbZ+YRfvXWJacm
mWCe+vbWHZNH2FY7y0odY4LHji5Gam8MLiUs7Mc4TJhOGFDIvhODbRe8y3VG
mBA8y/HKU4vB03T/32FsJqhG/tEM4kXjm4jLIrZMQTzNlF4qdx8nZU6sCuxj
wvxk78y2oLuCeawPnf/KBMnqnymG9FCcDD8f876NCUoRlANmq0MxaFyPCGhl
gsl6tcfnc0PQfPzx9bkWJkTv8dmS3nsL5SJp10WamGC4ck3p9iBffLhXjlCs
ZsLpDEPK4dU+eHPmWQUTmXBH1+moe643tk2LZmZXMoFhn8PO7PVAA9e0es0K
JhSbhGnpBrmg/xNX830lTJi70Er3yD2LkvibFCkW5H8gd/Z172n8K+JcHqOQ
CVSa66a9QTbYNZh106ZA0L+pP7bFvUcxzjHggWw+Ex7dVl1hG2SCFJu1777T
mHD2L+pgcJAuNlX6z2fmMuGQM/tL1fDxyomYFEf3HCb8D/n7nFk=
        "]]},
      Annotation[#, "Charting`Private`Tag$29883493#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-1.02, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{-1., 0.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.806555463099162*^9, 3.806555803144182*^9, 
  3.8065566931255493`*^9},
 CellLabel->
  "Out[4828]=",ExpressionUUID->"2b6a2f28-2886-4a16-8d66-8f3d54b2a437"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Distance sampling downwelling", "Subsubsection",
 CellChangeTimes->{{3.806555534500441*^9, 
  3.8065555376872883`*^9}},ExpressionUUID->"c1711543-2b41-495b-a8a5-\
d51438d5940c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stepPDFdown", "[", 
   RowBox[{"u_", ",", "v_", ",", "t_"}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["u", "v"]}], ")"}], "2"], 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "t"}], " ", 
     FractionBox["u", "v"]}], "]"}], 
   RowBox[{"Exp", "[", 
    RowBox[{"-", "t"}], "]"}], "t"}]}]], "Input",
 CellChangeTimes->{{3.744436914567767*^9, 3.744436933793355*^9}, {
  3.7444929430127773`*^9, 3.7444929596466618`*^9}},
 CellLabel->
  "In[4829]:=",ExpressionUUID->"555a157c-38a4-4320-b0b9-ecc2e0dff504"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleStepDown", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"-", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"RandomReal", "[", "]"}], 
      RowBox[{"RandomReal", "[", "]"}]}], "]"}]}], 
   RowBox[{"1", "+", 
    FractionBox["u", "v"]}]]}]], "Input",
 CellChangeTimes->{{3.7444379729861927`*^9, 3.7444379922604313`*^9}, {
  3.744438353172861*^9, 3.744438366708005*^9}, {3.7444929680444937`*^9, 
  3.744492971527801*^9}, {3.744493030883718*^9, 3.744493031031658*^9}},
 CellLabel->
  "In[4830]:=",ExpressionUUID->"9da65e5f-e85a-4217-83ff-fbcbe5e872d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"u", "=", "0.2"}], ",", 
     RowBox[{"v", "=", "1.4"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Histogram", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"sampleStepDown", "[", 
          RowBox[{"u", ",", "v"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", 
           RowBox[{"Range", "[", "100000", "]"}]}], "}"}]}], "]"}], ",", 
       "150", ",", "\"\<PDF\>\""}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"stepPDFdown", "[", 
        RowBox[{"u", ",", "v", ",", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "6"}], "}"}]}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.7444380083218203`*^9, 3.744438064438846*^9}, {
  3.744493003716444*^9, 3.74449302252995*^9}},
 CellLabel->
  "In[4831]:=",ExpressionUUID->"ec66f28e-7f1a-457e-981a-a98a71d72109"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.26599999999999996`], Thickness[Small]}], {}, 
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
      Opacity[0.26599999999999996`], Thickness[Small]}], 
      RectangleBox[{0., 0}, {0.1, 0.0594},
       RoundingRadius->0], RectangleBox[{0.1, 0}, {0.2, 0.1684},
       RoundingRadius->0], RectangleBox[{0.2, 0}, {0.3, 0.245},
       RoundingRadius->0], RectangleBox[{0.3, 0}, {0.4, 0.3048},
       RoundingRadius->0], RectangleBox[{0.4, 0}, {0.5, 0.3564},
       RoundingRadius->0], RectangleBox[{0.5, 0}, {0.6, 0.38},
       RoundingRadius->0], RectangleBox[{0.6, 0}, {0.7, 0.4116},
       RoundingRadius->0], RectangleBox[{0.7, 0}, {0.8, 0.4164},
       RoundingRadius->0], RectangleBox[{0.8, 0}, {0.9, 0.4133},
       RoundingRadius->0], RectangleBox[{0.9, 0}, {1., 0.424},
       RoundingRadius->0], RectangleBox[{1., 0}, {1.1, 0.426},
       RoundingRadius->0], RectangleBox[{1.1, 0}, {1.2, 0.4056},
       RoundingRadius->0], RectangleBox[{1.2, 0}, {1.3, 0.3926},
       RoundingRadius->0], RectangleBox[{1.3, 0}, {1.4, 0.3724},
       RoundingRadius->0], RectangleBox[{1.4, 0}, {1.5, 0.3523},
       RoundingRadius->0], RectangleBox[{1.5, 0}, {1.6, 0.3475},
       RoundingRadius->0], RectangleBox[{1.6, 0}, {1.7, 0.3289},
       RoundingRadius->0], RectangleBox[{1.7, 0}, {1.8, 0.3093},
       RoundingRadius->0], RectangleBox[{1.8, 0}, {1.9, 0.287},
       RoundingRadius->0], RectangleBox[{1.9, 0}, {2., 0.2653},
       RoundingRadius->0], RectangleBox[{2., 0}, {2.1, 0.2548},
       RoundingRadius->0], RectangleBox[{2.1, 0}, {2.2, 0.2473},
       RoundingRadius->0], RectangleBox[{2.2, 0}, {2.3, 0.2235},
       RoundingRadius->0], RectangleBox[{2.3, 0}, {2.4, 0.2112},
       RoundingRadius->0], RectangleBox[{2.4, 0}, {2.5, 0.1905},
       RoundingRadius->0], RectangleBox[{2.5, 0}, {2.6, 0.1838},
       RoundingRadius->0], RectangleBox[{2.6, 0}, {2.7, 0.1696},
       RoundingRadius->0], RectangleBox[{2.7, 0}, {2.8, 0.1578},
       RoundingRadius->0], RectangleBox[{2.8, 0}, {2.9, 0.1385},
       RoundingRadius->0], RectangleBox[{2.9, 0}, {3., 0.1315},
       RoundingRadius->0], RectangleBox[{3., 0}, {3.1, 0.1176},
       RoundingRadius->0], RectangleBox[{3.1, 0}, {3.2, 0.1154},
       RoundingRadius->0], RectangleBox[{3.2, 0}, {3.3, 0.1035},
       RoundingRadius->0], RectangleBox[{3.3, 0}, {3.4, 0.0967},
       RoundingRadius->0], RectangleBox[{3.4, 0}, {3.5, 0.083},
       RoundingRadius->0], RectangleBox[{3.5, 0}, {3.6, 0.0813},
       RoundingRadius->0], RectangleBox[{3.6, 0}, {3.7, 0.0772},
       RoundingRadius->0], RectangleBox[{3.7, 0}, {3.8, 0.0659},
       RoundingRadius->0], RectangleBox[{3.8, 0}, {3.9, 0.0588},
       RoundingRadius->0], RectangleBox[{3.9, 0}, {4., 0.0553},
       RoundingRadius->0], RectangleBox[{4., 0}, {4.1, 0.0494},
       RoundingRadius->0], RectangleBox[{4.1, 0}, {4.2, 0.0494},
       RoundingRadius->0], RectangleBox[{4.2, 0}, {4.3, 0.0435},
       RoundingRadius->0], RectangleBox[{4.3, 0}, {4.4, 0.0407},
       RoundingRadius->0], RectangleBox[{4.4, 0}, {4.5, 0.0357},
       RoundingRadius->0], RectangleBox[{4.5, 0}, {4.6, 0.0319},
       RoundingRadius->0], RectangleBox[{4.6, 0}, {4.7, 0.0259},
       RoundingRadius->0], RectangleBox[{4.7, 0}, {4.8, 0.0295},
       RoundingRadius->0], RectangleBox[{4.8, 0}, {4.9, 0.024},
       RoundingRadius->0], RectangleBox[{4.9, 0}, {5., 0.0213},
       RoundingRadius->0], RectangleBox[{5., 0}, {5.1, 0.0193},
       RoundingRadius->0], RectangleBox[{5.1, 0}, {5.2, 0.0187},
       RoundingRadius->0], RectangleBox[{5.2, 0}, {5.3, 0.021},
       RoundingRadius->0], RectangleBox[{5.3, 0}, {5.4, 0.0143},
       RoundingRadius->0], RectangleBox[{5.4, 0}, {5.5, 0.0137},
       RoundingRadius->0], RectangleBox[{5.5, 0}, {5.6, 0.012},
       RoundingRadius->0], RectangleBox[{5.6, 0}, {5.7, 0.013},
       RoundingRadius->0], RectangleBox[{5.7, 0}, {5.8, 0.0096},
       RoundingRadius->0], RectangleBox[{5.8, 0}, {5.9, 0.0091},
       RoundingRadius->0], RectangleBox[{5.9, 0}, {6., 0.0093},
       RoundingRadius->0], RectangleBox[{6., 0}, {6.1, 0.0058},
       RoundingRadius->0], RectangleBox[{6.1, 0}, {6.2, 0.0066},
       RoundingRadius->0], RectangleBox[{6.2, 0}, {6.3, 0.0057},
       RoundingRadius->0], RectangleBox[{6.3, 0}, {6.4, 0.0059},
       RoundingRadius->0], RectangleBox[{6.4, 0}, {6.5, 0.0043},
       RoundingRadius->0], RectangleBox[{6.5, 0}, {6.6, 0.0048},
       RoundingRadius->0], RectangleBox[{6.6, 0}, {6.7, 0.0049},
       RoundingRadius->0], RectangleBox[{6.7, 0}, {6.8, 0.0031},
       RoundingRadius->0], RectangleBox[{6.8, 0}, {6.9, 0.0036},
       RoundingRadius->0], RectangleBox[{6.9, 0}, {7., 0.0027},
       RoundingRadius->0], RectangleBox[{7., 0}, {7.1, 0.0031},
       RoundingRadius->0], RectangleBox[{7.1, 0}, {7.2, 0.0028},
       RoundingRadius->0], RectangleBox[{7.2, 0}, {7.3, 0.0031},
       RoundingRadius->0], RectangleBox[{7.3, 0}, {7.4, 0.0017},
       RoundingRadius->0], RectangleBox[{7.4, 0}, {7.5, 0.0018},
       RoundingRadius->0], RectangleBox[{7.5, 0}, {7.6, 0.0024},
       RoundingRadius->0], RectangleBox[{7.6, 0}, {7.7, 0.0021},
       RoundingRadius->0], RectangleBox[{7.7, 0}, {7.8, 0.0008},
       RoundingRadius->0], RectangleBox[{7.8, 0}, {7.9, 0.0017},
       RoundingRadius->0], RectangleBox[{7.9, 0}, {8., 0.0014},
       RoundingRadius->0], RectangleBox[{8., 0}, {8.1, 0.0006},
       RoundingRadius->0], RectangleBox[{8.1, 0}, {8.2, 0.0008},
       RoundingRadius->0], RectangleBox[{8.2, 0}, {8.3, 0.0008},
       RoundingRadius->0], RectangleBox[{8.3, 0}, {8.4, 0.0014},
       RoundingRadius->0], RectangleBox[{8.4, 0}, {8.5, 0.0003},
       RoundingRadius->0], RectangleBox[{8.5, 0}, {8.6, 0.0007},
       RoundingRadius->0], RectangleBox[{8.6, 0}, {8.7, 0.0008},
       RoundingRadius->0], RectangleBox[{8.7, 0}, {8.8, 0.0001},
       RoundingRadius->0], RectangleBox[{8.8, 0}, {8.9, 0.0009},
       RoundingRadius->0], RectangleBox[{8.9, 0}, {9., 0.0004},
       RoundingRadius->0], RectangleBox[{9., 0}, {9.1, 0.0005},
       RoundingRadius->0], RectangleBox[{9.1, 0}, {9.2, 0.0003},
       RoundingRadius->0], RectangleBox[{9.2, 0}, {9.3, 0.0005},
       RoundingRadius->0], RectangleBox[{9.3, 0}, {9.4, 0.0001},
       RoundingRadius->0], RectangleBox[{9.4, 0}, {9.5, 0.0003},
       RoundingRadius->0], RectangleBox[{9.5, 0}, {9.6, 0.0002},
       RoundingRadius->0], RectangleBox[{9.6, 0}, {9.7, 0.0001},
       RoundingRadius->0], RectangleBox[{9.7, 0}, {9.8, 0.0004},
       RoundingRadius->0], RectangleBox[{9.8, 0}, {9.9, 0.0003},
       RoundingRadius->0], RectangleBox[{10.1, 0}, {10.2, 0.0003},
       RoundingRadius->0], RectangleBox[{10.2, 0}, {10.3, 0.0002},
       RoundingRadius->0], RectangleBox[{10.4, 0}, {10.5, 0.0001},
       RoundingRadius->0], RectangleBox[{10.5, 0}, {10.6, 0.0001},
       RoundingRadius->0], RectangleBox[{10.6, 0}, {10.7, 0.0002},
       RoundingRadius->0], RectangleBox[{11., 0}, {11.1, 0.0003},
       RoundingRadius->0], RectangleBox[{11.3, 0}, {11.4, 0.0001},
       RoundingRadius->0], RectangleBox[{11.7, 0}, {11.8, 0.0001},
       RoundingRadius->0], RectangleBox[{12., 0}, {12.1, 0.0001},
       RoundingRadius->
        0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, \
{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwN1Xc4VX8cB3BRUZRkXCP8UkmLUkmK96m0U0lUhLIqRESi1EUkXBmJkFFR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        "]]},
      Annotation[#, "Charting`Private`Tag$29883798#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.12, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0, 6}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.806555509675768*^9, 3.806555803675662*^9, 
  3.806556693755412*^9},
 CellLabel->
  "Out[4831]=",ExpressionUUID->"9a3abf2e-e16f-4501-b7c7-a2e00a84c27e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Distance sampling upwelling", "Subsubsection",
 CellChangeTimes->{{3.8065555247468348`*^9, 
  3.8065555302304153`*^9}},ExpressionUUID->"a0f8edc4-e184-4da8-bb5b-\
57b97345b13f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pdfStepUp", "[", 
   RowBox[{"z0_", ",", "t_", ",", "v_", ",", "u_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"t", " ", "u", " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "+", "v"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {"1", 
            RowBox[{
             RowBox[{
              RowBox[{"t", " ", "u"}], "+", "z0"}], "\[LessEqual]", "0"}]},
           {
            FractionBox[
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               RowBox[{"-", 
                FractionBox[
                 RowBox[{
                  RowBox[{"t", " ", "u"}], "+", "z0"}], "v"]}]], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "v"}], ")"}]}], "v"], 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False], ")"}]}], 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "-", 
       FractionBox["z0", "v"]}]], " ", "u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "v"}], ")"}], " ", "v"}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"t", "+", 
       FractionBox["z0", "u"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["u", "2"], "+", "v", "+", 
          RowBox[{"2", " ", "u", " ", "v"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "u"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", "v"}], ")"}], " ", "z0"}]}], ")"}]}]}]]}]], "Input",\

 CellChangeTimes->{{3.74444122836584*^9, 3.7444412517484837`*^9}, 
   3.744507378702284*^9},
 CellLabel->
  "In[4832]:=",ExpressionUUID->"3a810217-6353-48e3-b060-54a9fda8d070"],

Cell[BoxData[
 RowBox[{
  RowBox[{"escapeP", "[", 
   RowBox[{"z0_", ",", "v_", ",", "u_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", "u"], "+", 
        FractionBox["1", "v"]}], ")"}], " ", "z0"}]], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"u", "+", "v"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"u", "-", "z0"}], ")"}]}], 
   RowBox[{
    RowBox[{"u", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "v"}], ")"}], " ", "v"}], "+", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox["1", "u"], "+", 
         FractionBox["1", "v"]}], ")"}], " ", "z0"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"u", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["u", "2"], "+", "v", "+", 
          RowBox[{"2", " ", "u", " ", "v"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "u"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"u", "+", "v"}], ")"}], " ", "z0"}]}], ")"}]}]}]]}]], "Input",\

 CellChangeTimes->{{3.744476984498692*^9, 3.7444769963320017`*^9}, 
   3.7445074062604094`*^9},
 CellLabel->
  "In[4833]:=",ExpressionUUID->"6bb09515-963c-45cd-9528-93cca314c5f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stepPDFupNoEscape", "[", 
   RowBox[{"z0_", ",", "u_", ",", "v_", ",", "t_"}], "]"}], ":=", 
  RowBox[{"-", 
   FractionBox[
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"t", " ", 
         RowBox[{"(", 
          RowBox[{"u", "+", "v"}], ")"}]}], "v"]}]], " ", "t", " ", "u", " ", 
     
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"u", "+", "v"}], ")"}], "2"]}], 
    RowBox[{"v", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "u"}], " ", "v"}], "+", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            FractionBox["1", "u"], "+", 
            FractionBox["1", "v"]}], ")"}], " ", "z0"}]], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"u", " ", "v"}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"u", "+", "v"}], ")"}], " ", "z0"}]}], ")"}]}]}], 
      ")"}]}]]}]}]], "Input",
 CellChangeTimes->{{3.744482479272777*^9, 3.7444824986961927`*^9}, {
   3.744493397044469*^9, 3.7444934003778048`*^9}, 3.7445074501509457`*^9},
 CellLabel->
  "In[4834]:=",ExpressionUUID->"9eb4a583-6567-4970-8cdf-a24ea3c40e57"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleStepUp", "[", 
   RowBox[{"z0_", ",", "u_", ",", "v_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "v"}], "-", 
    RowBox[{"v", " ", 
     RowBox[{"ProductLog", "[", 
      RowBox[{
       RowBox[{"-", "1"}], ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "\[ExponentialE]"]}], "+", 
        RowBox[{
         RowBox[{"RandomReal", "[", "]"}], 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", "E"], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"z0", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox["1", "u"], "+", 
                 FractionBox["1", "v"]}], ")"}]}]}], ")"}], 
            SuperscriptBox["\[ExponentialE]", 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 FractionBox["1", "u"], "+", 
                 FractionBox["1", "v"]}], ")"}], " ", "z0"}]}]]}]}], 
          ")"}]}]}]}], "]"}]}]}], 
   RowBox[{"u", "+", "v"}]]}]], "Input",
 CellLabel->
  "In[4835]:=",ExpressionUUID->"0f56d00d-e7b9-472f-80a4-db423ee6701c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Histogram", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"sampleStepUp", "[", 
        RowBox[{"1.1", ",", 
         RowBox[{"-", "0.3"}], ",", "1.3"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", 
         RowBox[{"Range", "[", "100000", "]"}]}], "}"}]}], "]"}], ",", "150", 
     ",", "\"\<PDF\>\""}], "]"}], ",", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"stepPDFupNoEscape", "[", 
      RowBox[{"1.1", ",", 
       RowBox[{"-", "0.3"}], ",", "1.3", ",", "t"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "6"}], "}"}]}], "]"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.7444380083218203`*^9, 3.744438064438846*^9}, {
  3.744482265574279*^9, 3.744482290019477*^9}, {3.744482508638978*^9, 
  3.744482514630857*^9}, {3.7444825526402893`*^9, 3.744482599336643*^9}, {
  3.744482681440908*^9, 3.744482681911294*^9}, {3.744493402778372*^9, 
  3.744493426933476*^9}},
 CellLabel->
  "In[4836]:=",ExpressionUUID->"851e3960-72f5-4ca3-b4ac-6d233acbd095"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[
     Opacity[0.]], {}, 
     {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[
      Opacity[0.]], RectangleBox[{0., 0}, {0.02, 0.009},
       RoundingRadius->0], RectangleBox[{0.02, 0}, {0.04, 0.0225},
       RoundingRadius->0], RectangleBox[{0.04, 0}, {0.06, 0.037},
       RoundingRadius->0], RectangleBox[{0.06, 0}, {0.08, 0.052},
       RoundingRadius->0], RectangleBox[{0.08, 0}, {0.1, 0.0725},
       RoundingRadius->0], RectangleBox[{0.1, 0}, {0.12, 0.069},
       RoundingRadius->0], RectangleBox[{0.12, 0}, {0.14, 0.0915},
       RoundingRadius->0], RectangleBox[{0.14, 0}, {0.16, 0.0995},
       RoundingRadius->0], RectangleBox[{0.16, 0}, {0.18, 0.1315},
       RoundingRadius->0], RectangleBox[{0.18, 0}, {0.2, 0.131},
       RoundingRadius->0], RectangleBox[{0.2, 0}, {0.22, 0.125},
       RoundingRadius->0], RectangleBox[{0.22, 0}, {0.24, 0.151},
       RoundingRadius->0], RectangleBox[{0.24, 0}, {0.26, 0.1595},
       RoundingRadius->0], RectangleBox[{0.26, 0}, {0.28, 0.1575},
       RoundingRadius->0], RectangleBox[{0.28, 0}, {0.3, 0.1935},
       RoundingRadius->0], RectangleBox[{0.3, 0}, {0.32, 0.207},
       RoundingRadius->0], RectangleBox[{0.32, 0}, {0.34, 0.1945},
       RoundingRadius->0], RectangleBox[{0.34, 0}, {0.36, 0.1935},
       RoundingRadius->0], RectangleBox[{0.36, 0}, {0.38, 0.2005},
       RoundingRadius->0], RectangleBox[{0.38, 0}, {0.4, 0.212},
       RoundingRadius->0], RectangleBox[{0.4, 0}, {0.42, 0.252},
       RoundingRadius->0], RectangleBox[{0.42, 0}, {0.44, 0.241},
       RoundingRadius->0], RectangleBox[{0.44, 0}, {0.46, 0.2505},
       RoundingRadius->0], RectangleBox[{0.46, 0}, {0.48, 0.211},
       RoundingRadius->0], RectangleBox[{0.48, 0}, {0.5, 0.265},
       RoundingRadius->0], RectangleBox[{0.5, 0}, {0.52, 0.2565},
       RoundingRadius->0], RectangleBox[{0.52, 0}, {0.54, 0.275},
       RoundingRadius->0], RectangleBox[{0.54, 0}, {0.56, 0.2805},
       RoundingRadius->0], RectangleBox[{0.56, 0}, {0.58, 0.27},
       RoundingRadius->0], RectangleBox[{0.58, 0}, {0.6, 0.2875},
       RoundingRadius->0], RectangleBox[{0.6, 0}, {0.62, 0.2785},
       RoundingRadius->0], RectangleBox[{0.62, 0}, {0.64, 0.287},
       RoundingRadius->0], RectangleBox[{0.64, 0}, {0.66, 0.3215},
       RoundingRadius->0], RectangleBox[{0.66, 0}, {0.68, 0.293},
       RoundingRadius->0], RectangleBox[{0.68, 0}, {0.7, 0.328},
       RoundingRadius->0], RectangleBox[{0.7, 0}, {0.72, 0.31},
       RoundingRadius->0], RectangleBox[{0.72, 0}, {0.74, 0.349},
       RoundingRadius->0], RectangleBox[{0.74, 0}, {0.76, 0.3175},
       RoundingRadius->0], RectangleBox[{0.76, 0}, {0.78, 0.315},
       RoundingRadius->0], RectangleBox[{0.78, 0}, {0.8, 0.319},
       RoundingRadius->0], RectangleBox[{0.8, 0}, {0.82, 0.332},
       RoundingRadius->0], RectangleBox[{0.82, 0}, {0.84, 0.321},
       RoundingRadius->0], RectangleBox[{0.84, 0}, {0.86, 0.3455},
       RoundingRadius->0], RectangleBox[{0.86, 0}, {0.88, 0.347},
       RoundingRadius->0], RectangleBox[{0.88, 0}, {0.9, 0.3535},
       RoundingRadius->0], RectangleBox[{0.9, 0}, {0.92, 0.3305},
       RoundingRadius->0], RectangleBox[{0.92, 0}, {0.94, 0.36},
       RoundingRadius->0], RectangleBox[{0.94, 0}, {0.96, 0.3685},
       RoundingRadius->0], RectangleBox[{0.96, 0}, {0.98, 0.3375},
       RoundingRadius->0], RectangleBox[{0.98, 0}, {1., 0.355},
       RoundingRadius->0], RectangleBox[{1., 0}, {1.02, 0.354},
       RoundingRadius->0], RectangleBox[{1.02, 0}, {1.04, 0.354},
       RoundingRadius->0], RectangleBox[{1.04, 0}, {1.06, 0.373},
       RoundingRadius->0], RectangleBox[{1.06, 0}, {1.08, 0.3375},
       RoundingRadius->0], RectangleBox[{1.08, 0}, {1.1, 0.3495},
       RoundingRadius->0], RectangleBox[{1.1, 0}, {1.12, 0.352},
       RoundingRadius->0], RectangleBox[{1.12, 0}, {1.14, 0.364},
       RoundingRadius->0], RectangleBox[{1.14, 0}, {1.16, 0.375},
       RoundingRadius->0], RectangleBox[{1.16, 0}, {1.18, 0.383},
       RoundingRadius->0], RectangleBox[{1.18, 0}, {1.2, 0.386},
       RoundingRadius->0], RectangleBox[{1.2, 0}, {1.22, 0.349},
       RoundingRadius->0], RectangleBox[{1.22, 0}, {1.24, 0.3595},
       RoundingRadius->0], RectangleBox[{1.24, 0}, {1.26, 0.3555},
       RoundingRadius->0], RectangleBox[{1.26, 0}, {1.28, 0.352},
       RoundingRadius->0], RectangleBox[{1.28, 0}, {1.3, 0.355},
       RoundingRadius->0], RectangleBox[{1.3, 0}, {1.32, 0.3525},
       RoundingRadius->0], RectangleBox[{1.32, 0}, {1.34, 0.387},
       RoundingRadius->0], RectangleBox[{1.34, 0}, {1.36, 0.386},
       RoundingRadius->0], RectangleBox[{1.36, 0}, {1.38, 0.348},
       RoundingRadius->0], RectangleBox[{1.38, 0}, {1.4, 0.349},
       RoundingRadius->0], RectangleBox[{1.4, 0}, {1.42, 0.3635},
       RoundingRadius->0], RectangleBox[{1.42, 0}, {1.44, 0.378},
       RoundingRadius->0], RectangleBox[{1.44, 0}, {1.46, 0.366},
       RoundingRadius->0], RectangleBox[{1.46, 0}, {1.48, 0.344},
       RoundingRadius->0], RectangleBox[{1.48, 0}, {1.5, 0.383},
       RoundingRadius->0], RectangleBox[{1.5, 0}, {1.52, 0.364},
       RoundingRadius->0], RectangleBox[{1.52, 0}, {1.54, 0.3825},
       RoundingRadius->0], RectangleBox[{1.54, 0}, {1.56, 0.3535},
       RoundingRadius->0], RectangleBox[{1.56, 0}, {1.58, 0.3705},
       RoundingRadius->0], RectangleBox[{1.58, 0}, {1.6, 0.3555},
       RoundingRadius->0], RectangleBox[{1.6, 0}, {1.62, 0.3585},
       RoundingRadius->0], RectangleBox[{1.62, 0}, {1.64, 0.369},
       RoundingRadius->0], RectangleBox[{1.64, 0}, {1.66, 0.363},
       RoundingRadius->0], RectangleBox[{1.66, 0}, {1.68, 0.3545},
       RoundingRadius->0], RectangleBox[{1.68, 0}, {1.7, 0.3415},
       RoundingRadius->0], RectangleBox[{1.7, 0}, {1.72, 0.362},
       RoundingRadius->0], RectangleBox[{1.72, 0}, {1.74, 0.354},
       RoundingRadius->0], RectangleBox[{1.74, 0}, {1.76, 0.3435},
       RoundingRadius->0], RectangleBox[{1.76, 0}, {1.78, 0.315},
       RoundingRadius->0], RectangleBox[{1.78, 0}, {1.8, 0.345},
       RoundingRadius->0], RectangleBox[{1.8, 0}, {1.82, 0.358},
       RoundingRadius->0], RectangleBox[{1.82, 0}, {1.84, 0.331},
       RoundingRadius->0], RectangleBox[{1.84, 0}, {1.86, 0.3485},
       RoundingRadius->0], RectangleBox[{1.86, 0}, {1.88, 0.3875},
       RoundingRadius->0], RectangleBox[{1.88, 0}, {1.9, 0.3325},
       RoundingRadius->0], RectangleBox[{1.9, 0}, {1.92, 0.3595},
       RoundingRadius->0], RectangleBox[{1.92, 0}, {1.94, 0.337},
       RoundingRadius->0], RectangleBox[{1.94, 0}, {1.96, 0.341},
       RoundingRadius->0], RectangleBox[{1.96, 0}, {1.98, 0.3315},
       RoundingRadius->0], RectangleBox[{1.98, 0}, {2., 0.3275},
       RoundingRadius->0], RectangleBox[{2., 0}, {2.02, 0.321},
       RoundingRadius->0], RectangleBox[{2.02, 0}, {2.04, 0.3445},
       RoundingRadius->0], RectangleBox[{2.04, 0}, {2.06, 0.311},
       RoundingRadius->0], RectangleBox[{2.06, 0}, {2.08, 0.3325},
       RoundingRadius->0], RectangleBox[{2.08, 0}, {2.1, 0.328},
       RoundingRadius->0], RectangleBox[{2.1, 0}, {2.12, 0.322},
       RoundingRadius->0], RectangleBox[{2.12, 0}, {2.14, 0.288},
       RoundingRadius->0], RectangleBox[{2.14, 0}, {2.16, 0.316},
       RoundingRadius->0], RectangleBox[{2.16, 0}, {2.18, 0.2985},
       RoundingRadius->0], RectangleBox[{2.18, 0}, {2.2, 0.314},
       RoundingRadius->0], RectangleBox[{2.2, 0}, {2.22, 0.289},
       RoundingRadius->0], RectangleBox[{2.22, 0}, {2.24, 0.3105},
       RoundingRadius->0], RectangleBox[{2.24, 0}, {2.26, 0.307},
       RoundingRadius->0], RectangleBox[{2.26, 0}, {2.28, 0.3015},
       RoundingRadius->0], RectangleBox[{2.28, 0}, {2.3, 0.3165},
       RoundingRadius->0], RectangleBox[{2.3, 0}, {2.32, 0.2785},
       RoundingRadius->0], RectangleBox[{2.32, 0}, {2.34, 0.3035},
       RoundingRadius->0], RectangleBox[{2.34, 0}, {2.36, 0.3065},
       RoundingRadius->0], RectangleBox[{2.36, 0}, {2.38, 0.293},
       RoundingRadius->0], RectangleBox[{2.38, 0}, {2.4, 0.297},
       RoundingRadius->0], RectangleBox[{2.4, 0}, {2.42, 0.279},
       RoundingRadius->0], RectangleBox[{2.42, 0}, {2.44, 0.2945},
       RoundingRadius->0], RectangleBox[{2.44, 0}, {2.46, 0.2795},
       RoundingRadius->0], RectangleBox[{2.46, 0}, {2.48, 0.2745},
       RoundingRadius->0], RectangleBox[{2.48, 0}, {2.5, 0.286},
       RoundingRadius->0], RectangleBox[{2.5, 0}, {2.52, 0.2885},
       RoundingRadius->0], RectangleBox[{2.52, 0}, {2.54, 0.26},
       RoundingRadius->0], RectangleBox[{2.54, 0}, {2.56, 0.2625},
       RoundingRadius->0], RectangleBox[{2.56, 0}, {2.58, 0.271},
       RoundingRadius->0], RectangleBox[{2.58, 0}, {2.6, 0.272},
       RoundingRadius->0], RectangleBox[{2.6, 0}, {2.62, 0.263},
       RoundingRadius->0], RectangleBox[{2.62, 0}, {2.64, 0.2645},
       RoundingRadius->0], RectangleBox[{2.64, 0}, {2.66, 0.2675},
       RoundingRadius->0], RectangleBox[{2.66, 0}, {2.68, 0.2435},
       RoundingRadius->0], RectangleBox[{2.68, 0}, {2.7, 0.25},
       RoundingRadius->0], RectangleBox[{2.7, 0}, {2.72, 0.248},
       RoundingRadius->0], RectangleBox[{2.72, 0}, {2.74, 0.254},
       RoundingRadius->0], RectangleBox[{2.74, 0}, {2.76, 0.245},
       RoundingRadius->0], RectangleBox[{2.76, 0}, {2.78, 0.258},
       RoundingRadius->0], RectangleBox[{2.78, 0}, {2.8, 0.2435},
       RoundingRadius->0], RectangleBox[{2.8, 0}, {2.82, 0.257},
       RoundingRadius->0], RectangleBox[{2.82, 0}, {2.84, 0.253},
       RoundingRadius->0], RectangleBox[{2.84, 0}, {2.86, 0.244},
       RoundingRadius->0], RectangleBox[{2.86, 0}, {2.88, 0.2345},
       RoundingRadius->0], RectangleBox[{2.88, 0}, {2.9, 0.22},
       RoundingRadius->0], RectangleBox[{2.9, 0}, {2.92, 0.2405},
       RoundingRadius->0], RectangleBox[{2.92, 0}, {2.94, 0.2425},
       RoundingRadius->0], RectangleBox[{2.94, 0}, {2.96, 0.2205},
       RoundingRadius->0], RectangleBox[{2.96, 0}, {2.98, 0.228},
       RoundingRadius->0], RectangleBox[{2.98, 0}, {3., 0.2325},
       RoundingRadius->0], RectangleBox[{3., 0}, {3.02, 0.2155},
       RoundingRadius->0], RectangleBox[{3.02, 0}, {3.04, 0.214},
       RoundingRadius->0], RectangleBox[{3.04, 0}, {3.06, 0.2365},
       RoundingRadius->0], RectangleBox[{3.06, 0}, {3.08, 0.214},
       RoundingRadius->0], RectangleBox[{3.08, 0}, {3.1, 0.2445},
       RoundingRadius->0], RectangleBox[{3.1, 0}, {3.12, 0.219},
       RoundingRadius->0], RectangleBox[{3.12, 0}, {3.14, 0.215},
       RoundingRadius->0], RectangleBox[{3.14, 0}, {3.16, 0.231},
       RoundingRadius->0], RectangleBox[{3.16, 0}, {3.18, 0.2145},
       RoundingRadius->0], RectangleBox[{3.18, 0}, {3.2, 0.2235},
       RoundingRadius->0], RectangleBox[{3.2, 0}, {3.22, 0.21},
       RoundingRadius->0], RectangleBox[{3.22, 0}, {3.24, 0.208},
       RoundingRadius->0], RectangleBox[{3.24, 0}, {3.26, 0.205},
       RoundingRadius->0], RectangleBox[{3.26, 0}, {3.28, 0.2025},
       RoundingRadius->0], RectangleBox[{3.28, 0}, {3.3, 0.2005},
       RoundingRadius->0], RectangleBox[{3.3, 0}, {3.32, 0.1885},
       RoundingRadius->0], RectangleBox[{3.32, 0}, {3.34, 0.191},
       RoundingRadius->0], RectangleBox[{3.34, 0}, {3.36, 0.202},
       RoundingRadius->0], RectangleBox[{3.36, 0}, {3.38, 0.1725},
       RoundingRadius->0], RectangleBox[{3.38, 0}, {3.4, 0.198},
       RoundingRadius->0], RectangleBox[{3.4, 0}, {3.42, 0.18},
       RoundingRadius->0], RectangleBox[{3.42, 0}, {3.44, 0.178},
       RoundingRadius->0], RectangleBox[{3.44, 0}, {3.46, 0.2155},
       RoundingRadius->0], RectangleBox[{3.46, 0}, {3.48, 0.1665},
       RoundingRadius->0], RectangleBox[{3.48, 0}, {3.5, 0.197},
       RoundingRadius->0], RectangleBox[{3.5, 0}, {3.52, 0.1865},
       RoundingRadius->0], RectangleBox[{3.52, 0}, {3.54, 0.18},
       RoundingRadius->0], RectangleBox[{3.54, 0}, {3.56, 0.1825},
       RoundingRadius->0], RectangleBox[{3.56, 0}, {3.58, 0.1915},
       RoundingRadius->0], RectangleBox[{3.58, 0}, {3.6, 0.1675},
       RoundingRadius->0], RectangleBox[{3.6, 0}, {3.62, 0.1895},
       RoundingRadius->0], RectangleBox[{3.62, 0}, {3.64, 0.1835},
       RoundingRadius->0], RectangleBox[{3.64, 0}, {3.66, 0.1615},
       RoundingRadius->0], RectangleBox[{3.66, 0}, {3.68, 0.05},
       RoundingRadius->
        0]}, {}, {}}, {{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}}}, \
{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1nk4VV8XB3BJESohNypFhqRIoZHvKSpDoiJSyVimTE2GRJMiF5EmU0ou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        "]]},
      Annotation[#, "Charting`Private`Tag$29884252#1"]& ]}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.0736, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0., 3.68}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.806555564846146*^9, 3.806555806470606*^9, 
  3.806556696912271*^9},
 CellLabel->
  "Out[4836]=",ExpressionUUID->"53631a6e-c6fd-4138-b62e-843d39ba81d6"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The zero-variance estimator", "Subsection",
 CellChangeTimes->{{3.806555067762857*^9, 
  3.8065550724994993`*^9}},ExpressionUUID->"ec8235a4-34aa-4b2b-802f-\
3a4b5ed719d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gamma2HalfSpaceZeroVariance", "[", 
   RowBox[{"c_", ",", "ui_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "w", ",", "pos", ",", "dir", ",", "step", ",", "u", ",", "v", ",", 
      "stepE", ",", "epsilon"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"epsilon", "=", 
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"pos", "=", 
      RowBox[{"{", 
       RowBox[{"0.", ",", "0.", ",", "0."}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dir", "=", 
      RowBox[{"{", 
       RowBox[{
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["ui", "2"]}]], ",", "0.", ",", "ui"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"v", "=", 
      FractionBox["1", 
       SqrtBox[
        RowBox[{"1", "-", "c"}]]]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"discrete", " ", "eigenvalue", " ", 
       SubscriptBox["\[Nu]", "0"]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"step", "=", 
      RowBox[{"entrysample", "[", 
       RowBox[{"ui", ",", "v"}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"distance", " ", "sampling", " ", "from", " ", "boundary"}], 
      " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"w", "=", 
      FractionBox[
       RowBox[{"Gamma2`pu", "[", "step", "]"}], 
       RowBox[{"entryPDF", "[", 
        RowBox[{"ui", ",", "v", ",", "step"}], "]"}]]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "boundary", " ", "step", " ", "importance", " ", "sampling", " ", 
       "weight"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"pos", "+=", 
      RowBox[{"step", " ", "*", " ", "dir"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"pos", "[", 
         RowBox[{"[", "3", "]"}], "]"}], "\[GreaterEqual]", "0"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{
          RowBox[{"\"\<x: \>\"", "<>", 
           RowBox[{"ToString", "[", 
            RowBox[{"pos", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "]"}], "<>", 
           "\"\<, \\tw * W[x]: \>\""}], ",", 
          RowBox[{"w", "   ", 
           RowBox[{"W", "[", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "3", "]"}], "]"}], ",", "v"}], "]"}]}]}], "]"}], 
        ";", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
         "debug", " ", "the", " ", "product", " ", "of", " ", "weight", " ", 
          "and", " ", "importance"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"w", " ", "*=", " ", "c"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"decide", " ", 
          RowBox[{"upward", "/", "downward"}]}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"RandomReal", "[", "]"}], "<", 
           RowBox[{"sampleDownP", "[", "v", "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"sample", " ", "downward", " ", "dir"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{"u", "=", 
           RowBox[{"sampleDownDir", "[", "v", "]"}]}], "\[IndentingNewLine]", 
          ",", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"sample", " ", "upward", " ", "dir"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"u", "=", 
            RowBox[{"sampleUpDir", "[", 
             RowBox[{
              RowBox[{"pos", "[", 
               RowBox[{"[", "3", "]"}], "]"}], ",", "v"}], "]"}]}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"dir", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"Sin", "[", "#", "]"}], 
              SqrtBox[
               RowBox[{"1", "-", 
                SuperscriptBox["u", "2"]}]]}], ",", 
             RowBox[{
              RowBox[{"Cos", "[", "#", "]"}], 
              SqrtBox[
               RowBox[{"1", "-", 
                SuperscriptBox["u", "2"]}]]}], ",", "u"}], "}"}], "&"}], "[", 
          
          RowBox[{"2", " ", "Pi", " ", 
           RowBox[{"RandomReal", "[", "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"w", "*=", 
         FractionBox["0.5", 
          RowBox[{"anglePDF", "[", 
           RowBox[{"u", ",", "v", ",", 
            RowBox[{"pos", "[", 
             RowBox[{"[", "3", "]"}], "]"}]}], "]"}]]}], ";", " ", 
        RowBox[{"(*", " ", 
         RowBox[{
         "weight", " ", "factor", " ", "for", " ", "direction", " ", "cosine",
           " ", "sampling"}], " ", "*)"}], "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"u", "\[GreaterEqual]", "0"}], ",", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"sample", " ", "downward", " ", "step"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"step", "=", 
            RowBox[{"sampleStepDown", "[", 
             RowBox[{"u", ",", "v"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"w", "*=", 
            FractionBox[
             RowBox[{"Gamma2`pc", "[", "step", "]"}], 
             RowBox[{"stepPDFdown", "[", 
              RowBox[{"u", ",", "v", ",", "step"}], "]"}]]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"pos", "+=", 
            RowBox[{"step", " ", "dir"}]}], ";"}], "\[IndentingNewLine]", ",",
           "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"sample", " ", "upward", " ", "step"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"RandomReal", "[", "]"}], "<", 
              RowBox[{"escapeP", "[", 
               RowBox[{
                RowBox[{"pos", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], ",", "v", ",", "u"}], 
               "]"}]}], ",", "\[IndentingNewLine]", 
             RowBox[{"(*", " ", "escape", " ", "*)"}], "\[IndentingNewLine]", 
             
             RowBox[{
              RowBox[{"step", "=", 
               RowBox[{
                FractionBox[
                 RowBox[{"-", 
                  RowBox[{"pos", "[", 
                   RowBox[{"[", "3", "]"}], "]"}]}], "u"], "+", "epsilon"}]}],
               ";", "\[IndentingNewLine]", 
              RowBox[{"w", "*=", 
               FractionBox[
                RowBox[{"Gamma2`Xc", "[", 
                 FractionBox[
                  RowBox[{"-", 
                   RowBox[{"pos", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}], "u"], "]"}], 
                RowBox[{"escapeP", "[", 
                 RowBox[{
                  RowBox[{"pos", "[", 
                   RowBox[{"[", "3", "]"}], "]"}], ",", "v", ",", "u"}], 
                 "]"}]]}], ";", "\[IndentingNewLine]", 
              RowBox[{"pos", "+=", 
               RowBox[{"step", "*", "dir"}]}], ";"}], "\[IndentingNewLine]", 
             "\[IndentingNewLine]", ",", "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{"non", " ", "escape"}], " ", "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"step", "=", 
               RowBox[{"sampleStepUp", "[", 
                RowBox[{
                 RowBox[{"pos", "[", 
                  RowBox[{"[", "3", "]"}], "]"}], ",", "u", ",", "v"}], 
                "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"w", "*=", 
               FractionBox[
                RowBox[{"Gamma2`pc", "[", "step", "]"}], 
                RowBox[{"pdfStepUp", "[", 
                 RowBox[{
                  RowBox[{"pos", "[", 
                   RowBox[{"[", "3", "]"}], "]"}], ",", "step", ",", "v", ",",
                   "u"}], "]"}]]}], ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              RowBox[{"pos", "+=", 
               RowBox[{"step", "*", "dir"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"pos", "[", 
                  RowBox[{"[", "3", "]"}], "]"}], "<", "0"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"pos", "[", 
                   RowBox[{"[", "3", "]"}], "]"}], "=", "epsilon"}], ";"}]}], 
               "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
            "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", "w"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.7444935222349157`*^9, 3.744493549871361*^9}, {
   3.744493627506421*^9, 3.744493629972639*^9}, {3.7444937209188766`*^9, 
   3.7444937531150837`*^9}, {3.744494414916932*^9, 3.744494431034837*^9}, {
   3.744494618774138*^9, 3.7444946553649273`*^9}, {3.744494783246043*^9, 
   3.744494783478857*^9}, {3.744498051554512*^9, 3.7444980614300947`*^9}, {
   3.744498144322191*^9, 3.744498213763509*^9}, {3.744498338955802*^9, 
   3.7444983587687073`*^9}, {3.744498499270945*^9, 3.744498544102058*^9}, {
   3.7444988802248697`*^9, 3.744498882987701*^9}, {3.744498944228588*^9, 
   3.74449903994188*^9}, {3.744499072170867*^9, 3.744499089009614*^9}, {
   3.744499129036952*^9, 3.744499227248589*^9}, {3.744499260011828*^9, 
   3.744499262932176*^9}, {3.744499303352442*^9, 3.744499431481258*^9}, {
   3.744499598752839*^9, 3.7444996677806*^9}, {3.744499868199932*^9, 
   3.744499880234274*^9}, {3.744499929188222*^9, 3.744499937108178*^9}, {
   3.7445002348386593`*^9, 3.744500236018033*^9}, 3.744500474974907*^9, {
   3.7445075551583433`*^9, 3.744507630329193*^9}, {3.806555675258706*^9, 
   3.80655572329698*^9}, {3.80655589188523*^9, 3.8065559180582237`*^9}, {
   3.806555955042776*^9, 3.8065559599186697`*^9}, {3.806556012958746*^9, 
   3.806556026368675*^9}},
 CellLabel->
  "In[4837]:=",ExpressionUUID->"5109478a-5a54-4ddc-a2cc-72d2acb2b641"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Testing", "Subsection",
 CellChangeTimes->{{3.806556489942006*^9, 
  3.80655649055326*^9}},ExpressionUUID->"67c55ee6-3990-4a4d-814e-\
04945dd0b53a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"single", "-", 
    RowBox[{"scattering", " ", "albedo"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", " ", "=", " ", "0.97"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"incoming", " ", "cosine"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ui", " ", "=", " ", "0.64"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.806556493127002*^9, 3.806556514791133*^9}, {
  3.8065565991757193`*^9, 3.8065566023432083`*^9}},
 CellLabel->
  "In[4838]:=",ExpressionUUID->"b6eec451-6f68-40ef-b195-0c2999a80e7a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gamma2HalfSpaceZeroVariance", "[", 
  RowBox[{"\[Alpha]", ",", "ui"}], "]"}]], "Input",
 CellChangeTimes->{{3.806556347698432*^9, 3.806556349359964*^9}, {
   3.806556524099358*^9, 3.806556527307867*^9}, 3.806556648642576*^9},
 CellLabel->
  "In[4840]:=",ExpressionUUID->"767a5a9f-a808-422f-a44f-a6d202532023"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.2803, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.707153371685638`"}],
  SequenceForm["x: 1.2803, \tw * W[x]: ", 0.707153371685638],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697068845*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"88c3c332-b92b-4f05-b75f-7ceb1be6bb5b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.86317, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856379`"}],
  SequenceForm["x: 2.86317, \tw * W[x]: ", 0.7071533716856379],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.80655669707246*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"e57812cc-92c9-4116-b39b-69e8381b9c9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.08817, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856373`"}],
  SequenceForm["x: 6.08817, \tw * W[x]: ", 0.7071533716856373],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697078885*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"07b11239-3779-4b5e-9dbc-ed40b89f0c72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.01681, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856375`"}],
  SequenceForm["x: 6.01681, \tw * W[x]: ", 0.7071533716856375],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697081949*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"43882d0d-dc51-4b64-8c81-f608efdff74f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.18182, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856375`"}],
  SequenceForm["x: 6.18182, \tw * W[x]: ", 0.7071533716856375],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697087154*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"dc887ec6-4cf3-4311-80da-8b682a8741d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 6.15364, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856375`"}],
  SequenceForm["x: 6.15364, \tw * W[x]: ", 0.7071533716856375],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697090558*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"da71e30b-4b1c-4d5c-a860-5790bd0c2de3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.30174, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856375`"}],
  SequenceForm["x: 3.30174, \tw * W[x]: ", 0.7071533716856375],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697094206*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"2a3a2eca-94e2-41f0-8631-740a637c7436"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.73179, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856373`"}],
  SequenceForm["x: 3.73179, \tw * W[x]: ", 0.7071533716856373],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697097198*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"b6d368c8-b0ea-4820-a0c4-685954f219f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.72209, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 4.72209, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697100075*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"327c9413-daed-4c47-9497-a4d4daf3e412"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.60312, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856373`"}],
  SequenceForm["x: 2.60312, \tw * W[x]: ", 0.7071533716856373],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697103879*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"043ee5c0-a3c2-459c-bcd9-13e5f5b10246"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.44366, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 5.44366, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697106797*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"981c3fdb-324f-4f73-b4b4-f91be0d092ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 5.74336, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 5.74336, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.8065566971100683`*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"4af65d96-4eec-43d3-aa1c-89ba6f8a723f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 4.83497, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856373`"}],
  SequenceForm["x: 4.83497, \tw * W[x]: ", 0.7071533716856373],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.8065566971132517`*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"1791d2c7-a49f-4dfe-a567-bad4dfcca2cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.08101, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856373`"}],
  SequenceForm["x: 3.08101, \tw * W[x]: ", 0.7071533716856373],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697116115*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"5656e561-a009-4e13-a809-59ea56e783ac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 3.32809, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 3.32809, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.806556697119546*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"d688b37c-711d-44c4-bf52-1386c84f6950"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.532, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 2.532, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.8065566971221743`*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"736ad9a4-012c-4301-acc5-25c75d86d1a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.33334, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856373`"}],
  SequenceForm["x: 2.33334, \tw * W[x]: ", 0.7071533716856373],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}, {
   3.8065566547936153`*^9, 3.80655669712508*^9}},
 CellLabel->
  "During evaluation of \
In[4840]:=",ExpressionUUID->"f7391ba9-f6e6-4f5b-ae8f-a5e8659edacd"]
}, Open  ]],

Cell[BoxData["0.7071533716856374`"], "Output",
 CellChangeTimes->{
  3.806556349869074*^9, {3.8065564219880943`*^9, 3.8065564510548887`*^9}, 
   3.806556529136786*^9, {3.806556559489759*^9, 3.806556610990638*^9}, {
   3.806556654807398*^9, 3.806556697127721*^9}},
 CellLabel->
  "Out[4840]=",ExpressionUUID->"d6bc0dba-28a0-4db4-bd68-095c8af92880"]
}, Open  ]],

Cell["Make sure this agrees with the analytic albedo:", "Text",
 CellChangeTimes->{{3.806556548706697*^9, 
  3.806556553734799*^9}},ExpressionUUID->"591a5d66-db97-4e8a-bffb-\
eb9bf31e632e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"halfspAProbIsoGamma2`albedo", "[", 
  RowBox[{"\[Alpha]", ",", "ui"}], "]"}]], "Input",
 CellChangeTimes->{{3.806556542934869*^9, 3.806556545449602*^9}},
 CellLabel->
  "In[4841]:=",ExpressionUUID->"60dedfbe-0840-4b25-aeb0-f052ad7f71ff"],

Cell[BoxData["0.707153371685638`"], "Output",
 CellChangeTimes->{3.8065565457901707`*^9, 3.806556604194611*^9, 
  3.806556654825947*^9, 3.806556697141676*^9},
 CellLabel->
  "Out[4841]=",ExpressionUUID->"768d7073-3b62-4245-9516-2164655bf52a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exit-resampling variation", "Section",
 CellChangeTimes->{{3.806554846344178*^9, 
  3.806554854388001*^9}},ExpressionUUID->"d8007b2d-f1df-4daa-8ec1-\
9e9e9f53404b"],

Cell[CellGroupData[{

Cell["Various distributions, PDFs, and sampling routines", "Subsection",
 CellChangeTimes->{{3.8065550536649733`*^9, 
  3.806555065942675*^9}},ExpressionUUID->"fdd65857-5a72-46d3-9f79-\
f214f161ff3a"],

Cell[CellGroupData[{

Cell["Desired PDF for escaping from given depth z:", "Subsubsection",
 CellChangeTimes->{{3.806556275469968*^9, 
  3.806556290803709*^9}},ExpressionUUID->"78adb377-82dd-4218-a7e2-\
cff9000b4c48"],

Cell[BoxData[
 RowBox[{
  RowBox[{"angleEscapePDF", "[", 
   RowBox[{"u_", ",", "z_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"z", "+", 
      FractionBox["z", "u"]}]], " ", 
    RowBox[{"(", 
     RowBox[{"u", "-", "z"}], ")"}]}], "u"]}]], "Input",
 CellChangeTimes->{{3.801548641451517*^9, 3.801548650739477*^9}},
 CellLabel->
  "In[4736]:=",ExpressionUUID->"909d7c8b-a558-4395-bbfa-b553050d13ae"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Direction Sampling:", "Subsubsection",
 CellChangeTimes->{{3.806556294087915*^9, 
  3.806556296799773*^9}},ExpressionUUID->"bfe260f4-897d-4246-a760-\
f4da1b8a2669"],

Cell["Case eigenmode:", "Text",
 CellChangeTimes->{{3.806556220680572*^9, 
  3.806556231108946*^9}},ExpressionUUID->"4258c202-2928-4723-a2ec-\
1f4f99a46555"],

Cell[BoxData[
 RowBox[{
  RowBox[{"phi", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  RowBox[{
   FractionBox[
    FractionBox[
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      SuperscriptBox["v", "2"]}], 
     SuperscriptBox["v", "2"]], "2"], 
   SuperscriptBox[
    RowBox[{"(", 
     FractionBox["1", 
      RowBox[{"1", "+", 
       RowBox[{"u", "/", "v"}]}]], ")"}], "2"]}]}]], "Input",
 CellChangeTimes->{{3.801469854712627*^9, 3.801469867418467*^9}, 
   3.8014713481533957`*^9},
 CellLabel->
  "In[4737]:=",ExpressionUUID->"4d3bb706-5acd-4d22-ab54-54f3748ff326"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleDir", "[", "v_", "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"1", "+", "v", "-", 
       RowBox[{"2", " ", "v", " ", "#"}]}], 
      RowBox[{"1", "+", "v", "-", 
       RowBox[{"2", " ", "#"}]}]]}], "&"}], "[", 
   RowBox[{"RandomReal", "[", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.801469871054996*^9, 3.801469877242038*^9}, {
  3.801469911290532*^9, 3.801469921246352*^9}},
 CellLabel->
  "In[4738]:=",ExpressionUUID->"84c9c873-d266-4fc6-8933-8308b36a00e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Intercollision distance sampling:", "Subsubsection",
 CellChangeTimes->{{3.8065563000221577`*^9, 
  3.8065563079160767`*^9}},ExpressionUUID->"a81d9df1-c219-48f9-89cb-\
cc4ce420a8d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stepPDF", "[", 
   RowBox[{"u_", ",", "v_", ",", "t_"}], "]"}], ":=", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox["u", "v"]}], ")"}], "2"], 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "t"}], " ", 
     FractionBox["u", "v"]}], "]"}], 
   RowBox[{"Exp", "[", 
    RowBox[{"-", "t"}], "]"}], "t"}]}]], "Input",
 CellLabel->
  "In[4739]:=",ExpressionUUID->"293600be-f507-4967-bce5-de8c62eb8ca3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleStep", "[", 
   RowBox[{"u_", ",", "v_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"-", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"RandomReal", "[", "]"}], 
      RowBox[{"RandomReal", "[", "]"}]}], "]"}]}], 
   RowBox[{"1", "+", 
    FractionBox["u", "v"]}]]}]], "Input",
 CellLabel->
  "In[4740]:=",ExpressionUUID->"0b593f6a-db90-44ec-9036-e567bd48fb35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DwivEscProb", "[", 
   RowBox[{"z_", ",", "v_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        FractionBox["1", "v"]}], ")"}], " ", "z"}]], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", "v"}], ")"}]}], 
   RowBox[{"2", " ", "v"}]]}]], "Input",
 CellChangeTimes->{{3.801552586330529*^9, 3.801552596862755*^9}},
 CellLabel->
  "In[4742]:=",ExpressionUUID->"5a9fac96-a90b-4509-abe1-6458dd0fbe19"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The zero-variance estimator", "Subsection",
 CellChangeTimes->{{3.806555067762857*^9, 
  3.8065550724994993`*^9}},ExpressionUUID->"64ef6475-2da4-430c-bb79-\
057770878448"],

Cell[BoxData[
 RowBox[{
  RowBox[{"gamma2HalfSpaceZeroVarianceExitResampling", "[", 
   RowBox[{"c_", ",", "ui_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "w", ",", "pos", ",", "dir", ",", "s", ",", "u", ",", "v", ",", "d", ",",
       "count", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"pos", "=", 
      RowBox[{"{", 
       RowBox[{"0.", ",", "0.", ",", "0."}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dir", "=", 
      RowBox[{"{", 
       RowBox[{
        SqrtBox[
         RowBox[{"1", "-", 
          SuperscriptBox["ui", "2"]}]], ",", "0.", ",", "ui"}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"v", "=", 
      FractionBox["1", 
       SqrtBox[
        RowBox[{"1", "-", "c"}]]]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{"the", " ", "discrete", " ", "eigenvalue", " ", 
       SubscriptBox["\[Nu]", "0"]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"s", "=", 
      RowBox[{"entrysample", "[", 
       RowBox[{"ui", ",", "v"}], "]"}]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "entry", " ", "free", " ", "path", " ", "length", " ", "sampling"}], 
      " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"w", "=", 
      FractionBox[
       RowBox[{"Gamma2`pu", "[", "s", "]"}], 
       RowBox[{"entryPDF", "[", 
        RowBox[{"ui", ",", "v", ",", "s"}], "]"}]]}], ";", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "importance", " ", "sampling", " ", "weight", " ", "for", " ", "entry", 
       " ", "s"}], "*)"}], "\[IndentingNewLine]", 
     RowBox[{"pos", "+=", 
      RowBox[{"s", " ", "*", " ", "dir"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"count", " ", "=", " ", "1"}], ";", "\[IndentingNewLine]", 
     RowBox[{"While", "[", 
      RowBox[{
       RowBox[{"count", " ", "<", " ", "100"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"count", " ", "+=", "1"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{
          RowBox[{"\"\<x: \>\"", "<>", 
           RowBox[{"ToString", "[", 
            RowBox[{"pos", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "]"}], "<>", 
           "\"\<, \\tw * W[x]: \>\""}], ",", 
          RowBox[{"w", "   ", 
           RowBox[{"W", "[", 
            RowBox[{
             RowBox[{"pos", "[", 
              RowBox[{"[", "3", "]"}], "]"}], ",", "v"}], "]"}]}]}], "]"}], 
        ";", " ", "\[IndentingNewLine]", 
        RowBox[{"w", " ", "*=", " ", "c"}], ";", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{"u", "=", 
         RowBox[{"sampleDir", "[", "v", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"dir", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"Sin", "[", "#", "]"}], 
              SqrtBox[
               RowBox[{"1", "-", 
                SuperscriptBox["u", "2"]}]]}], ",", 
             RowBox[{
              RowBox[{"Cos", "[", "#", "]"}], 
              SqrtBox[
               RowBox[{"1", "-", 
                SuperscriptBox["u", "2"]}]]}], ",", "u"}], "}"}], "&"}], "[", 
          
          RowBox[{"2", " ", "Pi", " ", 
           RowBox[{"RandomReal", "[", "]"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"s", " ", "=", " ", 
         RowBox[{"sampleStep", "[", 
          RowBox[{"u", ",", "v"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"z", "=", 
         RowBox[{"pos", "[", 
          RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"pos", "[", 
             RowBox[{"[", "3", "]"}], "]"}], "+", 
            RowBox[{"s", " ", "u"}]}], "<", "0"}], ",", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"resample", " ", "outgoing", " ", "dir"}], " ", "*)"}], 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"u", "=", 
            RowBox[{"-", 
             FractionBox[
              RowBox[{"pos", "[", 
               RowBox[{"[", "3", "]"}], "]"}], 
              RowBox[{"ProductLog", "[", 
               RowBox[{"-", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["\[ExponentialE]", 
                   RowBox[{"pos", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]], " ", 
                  RowBox[{"pos", "[", 
                   RowBox[{"[", "3", "]"}], "]"}]}], 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", 
                  RowBox[{"RandomReal", "[", "]"}]}]]}], "]"}]]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"dir", "=", 
            RowBox[{
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"Sin", "[", "#", "]"}], 
                 SqrtBox[
                  RowBox[{"1", "-", 
                   SuperscriptBox["u", "2"]}]]}], ",", 
                RowBox[{
                 RowBox[{"Cos", "[", "#", "]"}], 
                 SqrtBox[
                  RowBox[{"1", "-", 
                   SuperscriptBox["u", "2"]}]]}], ",", "u"}], "}"}], "&"}], 
             "[", 
             RowBox[{"2", " ", "Pi", " ", 
              RowBox[{"RandomReal", "[", "]"}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"d", "=", 
            FractionBox[
             RowBox[{"pos", "[", 
              RowBox[{"[", "3", "]"}], "]"}], 
             RowBox[{"-", "u"}]]}], ";", "\[IndentingNewLine]", 
           RowBox[{"pos", "+=", 
            RowBox[{"dir", "  ", "d"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"w", "*=", " ", 
            RowBox[{
             FractionBox[
              RowBox[{"(", 
               RowBox[{"1", "/", "2"}], ")"}], 
              RowBox[{
               RowBox[{"DwivEscProb", "[", 
                RowBox[{"z", ",", "v"}], "]"}], " ", 
               RowBox[{"angleEscapePDF", "[", 
                RowBox[{"u", ",", "z"}], "]"}]}]], 
             FractionBox[
              RowBox[{"Gamma2`Xc", "[", 
               FractionBox["z", 
                RowBox[{"-", "u"}]], "]"}], "1"]}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Break", "[", "]"}], ";"}], "\[IndentingNewLine]", ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"w", " ", "*=", " ", 
            FractionBox[
             RowBox[{"(", 
              RowBox[{"1", "/", "2"}], ")"}], 
             RowBox[{"phi", "[", 
              RowBox[{"u", ",", "v"}], "]"}]]}], ";", "\[IndentingNewLine]", 
           RowBox[{"pos", " ", "+=", " ", 
            RowBox[{"dir", " ", "*", " ", "s"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{"w", " ", "*=", " ", 
            FractionBox[
             RowBox[{"Gamma2`pc", "[", "s", "]"}], 
             RowBox[{"stepPDF", "[", 
              RowBox[{"u", ",", "v", ",", "s"}], "]"}]]}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";", "\[IndentingNewLine]", "w"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.801469299812983*^9, 3.801469300783965*^9}, 
   3.801469373035061*^9, {3.801469406324437*^9, 3.801469408905418*^9}, {
   3.801470095298279*^9, 3.801470183677979*^9}, {3.801470215005612*^9, 
   3.801470216288437*^9}, {3.80147026373771*^9, 3.8014702655016127`*^9}, {
   3.801470324859098*^9, 3.80147036684686*^9}, {3.801470665337426*^9, 
   3.8014707133020067`*^9}, {3.801470761470017*^9, 3.801470849576995*^9}, {
   3.8014710227000847`*^9, 3.801471062535285*^9}, {3.8014712126614923`*^9, 
   3.80147122490823*^9}, 3.801471255663143*^9, 3.801471316197131*^9, {
   3.8014720089640408`*^9, 3.80147201052853*^9}, {3.801472099693966*^9, 
   3.801472099981688*^9}, {3.801473235890717*^9, 3.8014732455019484`*^9}, {
   3.801473653446528*^9, 3.801473688350786*^9}, {3.801473727449868*^9, 
   3.801473785096678*^9}, {3.801473837814022*^9, 3.80147389993327*^9}, {
   3.801502017934745*^9, 3.801502019292642*^9}, {3.8015020626007347`*^9, 
   3.80150212980622*^9}, {3.801502184675343*^9, 3.801502207027728*^9}, {
   3.801502369536316*^9, 3.8015023774129543`*^9}, {3.8015024456173687`*^9, 
   3.8015024509326963`*^9}, {3.801503434185342*^9, 3.801503454080652*^9}, 
   3.801504415181981*^9, {3.801504530078739*^9, 3.801504562905159*^9}, 
   3.801550958958407*^9, {3.8015524774824057`*^9, 3.801552500318768*^9}, {
   3.8015526191566477`*^9, 3.801552626423196*^9}, {3.801552670997081*^9, 
   3.801552671207152*^9}, {3.806555084524976*^9, 3.8065551642099037`*^9}, {
   3.806555615099401*^9, 3.806555617552746*^9}, 3.8065563378118896`*^9},
 CellLabel->
  "In[4743]:=",ExpressionUUID->"06419842-68c0-4b0c-9600-2fd6acbac50a"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Testing", "Subsection",
 CellChangeTimes->{{3.806556489942006*^9, 
  3.80655649055326*^9}},ExpressionUUID->"2148af0f-3ffa-4847-a36a-\
06bfe82c51e6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"single", "-", 
    RowBox[{"scattering", " ", "albedo"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]", " ", "=", " ", "0.97"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"incoming", " ", "cosine"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ui", " ", "=", " ", "0.64"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.806556493127002*^9, 3.806556514791133*^9}, {
  3.8065565991757193`*^9, 3.8065566023432083`*^9}},
 CellLabel->
  "In[4796]:=",ExpressionUUID->"ffc13dfe-5cbd-41d4-99c4-96f1c4dc34cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gamma2HalfSpaceZeroVarianceExitResampling", "[", 
  RowBox[{"\[Alpha]", ",", "ui"}], "]"}]], "Input",
 CellChangeTimes->{{3.806556347698432*^9, 3.806556349359964*^9}, {
  3.806556524099358*^9, 3.806556527307867*^9}},
 CellLabel->
  "In[4805]:=",ExpressionUUID->"fcefae4b-b588-462f-b528-c0a1f14420c1"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.975626, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856379`"}],
  SequenceForm["x: 0.975626, \tw * W[x]: ", 0.7071533716856379],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109547462`*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"16222ab2-f583-49bb-b643-04070a25a44e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.10694, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856382`"}],
  SequenceForm["x: 2.10694, \tw * W[x]: ", 0.7071533716856382],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610957467*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"305c7028-9662-45de-ae11-3eb73baa2828"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.96152, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856382`"}],
  SequenceForm["x: 1.96152, \tw * W[x]: ", 0.7071533716856382],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610964466*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"15363a36-7a67-492f-bf79-5ef5d8a7eb0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.16315, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.707153371685638`"}],
  SequenceForm["x: 1.16315, \tw * W[x]: ", 0.707153371685638],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610966703*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"83fd2a48-8afc-4e59-8699-eab5e825b11e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.67279, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.707153371685638`"}],
  SequenceForm["x: 1.67279, \tw * W[x]: ", 0.707153371685638],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610968738*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"685d121b-5cc5-4f55-b858-5f4d6e3171e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.80623, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856379`"}],
  SequenceForm["x: 0.80623, \tw * W[x]: ", 0.7071533716856379],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610970931*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"bde8fa31-fd69-4da0-b79a-65698df82c97"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.49138, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 0.49138, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610975031*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"e312670d-18bd-4c2a-904b-64612ffe775c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.470267, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 0.470267, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610977253*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"626a65cd-fe65-4250-a45f-5de2a558e2b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.68513, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 1.68513, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610979536*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"b83f9643-db9a-4e24-b3f9-ac2559ace814"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 1.82037, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856375`"}],
  SequenceForm["x: 1.82037, \tw * W[x]: ", 0.7071533716856375],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.8065566109815607`*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"8990bbd1-3e6b-4470-b037-7989a0bebe71"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.34001, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856374`"}],
  SequenceForm["x: 2.34001, \tw * W[x]: ", 0.7071533716856374],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610983567*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"4fcc39b6-4a02-4eef-b0d7-a81bb49dc23d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 2.12706, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856376`"}],
  SequenceForm["x: 2.12706, \tw * W[x]: ", 0.7071533716856376],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610985911*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"b465c579-b06f-488f-a746-9c18239c8b99"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"x: 0.0332499, \\tw * W[x]: \"\>", "\[InvisibleSpace]", 
   "0.7071533716856377`"}],
  SequenceForm["x: 0.0332499, \tw * W[x]: ", 0.7071533716856377],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8065563496104393`*^9, {3.8065564219736547`*^9, 3.806556451014482*^9}, 
   3.806556529133017*^9, {3.80655655947917*^9, 3.806556610988525*^9}},
 CellLabel->
  "During evaluation of \
In[4805]:=",ExpressionUUID->"16a4c2e6-ae54-4541-a82e-c5efdb8e97b1"]
}, Open  ]],

Cell[BoxData["0.7071533716856379`"], "Output",
 CellChangeTimes->{
  3.806556349869074*^9, {3.8065564219880943`*^9, 3.8065564510548887`*^9}, 
   3.806556529136786*^9, {3.806556559489759*^9, 3.806556610990638*^9}},
 CellLabel->
  "Out[4805]=",ExpressionUUID->"ce91643a-f024-4b04-adf5-8cc758d08550"]
}, Open  ]],

Cell["Make sure this agrees with the analytic albedo:", "Text",
 CellChangeTimes->{{3.806556548706697*^9, 
  3.806556553734799*^9}},ExpressionUUID->"185425e9-7347-4054-b589-\
763bdaa4ac54"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"halfspAProbIsoGamma2`albedo", "[", 
  RowBox[{"\[Alpha]", ",", "ui"}], "]"}]], "Input",
 CellChangeTimes->{{3.806556542934869*^9, 3.806556545449602*^9}},
 CellLabel->
  "In[4799]:=",ExpressionUUID->"dd02c5c2-10aa-4313-8a1b-3cd0d7541251"],

Cell[BoxData["0.707153371685638`"], "Output",
 CellChangeTimes->{3.8065565457901707`*^9, 3.806556604194611*^9},
 CellLabel->
  "Out[4799]=",ExpressionUUID->"faf4922d-b0b9-458b-97be-d96786a08bc2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 675},
WindowMargins->{{Automatic, 21}, {Automatic, 8}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 251, 6, 222, "Title",ExpressionUUID->"0de80e46-e850-4243-9b10-130440ad5a73"],
Cell[834, 30, 645, 14, 104, "Text",ExpressionUUID->"c849996f-bd1e-4dfb-b586-0feb139a6ae8"],
Cell[CellGroupData[{
Cell[1504, 48, 152, 3, 67, "Section",ExpressionUUID->"43eb40d8-1d7f-45e8-96ca-a550f0d1851b"],
Cell[1659, 53, 354, 7, 58, "Text",ExpressionUUID->"fd697372-159e-4442-a4bc-c67f52c68af6"],
Cell[CellGroupData[{
Cell[2038, 64, 158, 3, 54, "Subsection",ExpressionUUID->"ce47cd10-ba3e-42ee-b35e-9feb09d25da5"],
Cell[2199, 69, 261, 7, 58, "Text",ExpressionUUID->"5da7c0ac-33db-433c-9a2a-b1e5e8acb632"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2509, 82, 198, 3, 67, "Section",ExpressionUUID->"a9c9fce4-4b28-4ceb-a27e-0e9c4dc677a1"],
Cell[2710, 87, 195, 3, 35, "Text",ExpressionUUID->"58cb0ff6-316f-4c22-9ed0-5f0d42517a0a"],
Cell[2908, 92, 880, 26, 65, "Input",ExpressionUUID->"253d4eec-aa24-48bc-8ad9-df51d4d3e01e"],
Cell[3791, 120, 173, 3, 35, "Text",ExpressionUUID->"8df90a1c-62cf-402f-9b91-a6454379dbb1"],
Cell[3967, 125, 930, 25, 56, "Input",ExpressionUUID->"59005e0a-4a0c-4aa4-bd08-856286c43fd5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4934, 155, 206, 4, 67, "Section",ExpressionUUID->"b43a5e0b-f454-48f6-8bfa-79eb04dcbf14"],
Cell[CellGroupData[{
Cell[5165, 163, 183, 3, 54, "Subsection",ExpressionUUID->"9ea67c27-114f-4133-b543-cab7d7c3e86d"],
Cell[5351, 168, 1046, 32, 128, "Input",ExpressionUUID->"5508e65c-6207-4124-a181-0f775b74291d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6434, 205, 200, 3, 54, "Subsection",ExpressionUUID->"e8923f22-b3c2-4165-83c4-1282ed92a48b"],
Cell[CellGroupData[{
Cell[6659, 212, 181, 3, 45, "Subsubsection",ExpressionUUID->"c90c7ffd-24be-4759-b955-4913c60dd26d"],
Cell[6843, 217, 909, 26, 60, "Input",ExpressionUUID->"517bb267-b44f-436c-91aa-2f46e58f60d4"],
Cell[7755, 245, 412, 11, 30, "Input",ExpressionUUID->"63c5a4e8-829f-4e91-98a4-0b486fafe454"],
Cell[8170, 258, 351, 9, 30, "Input",ExpressionUUID->"deeb7af8-d388-4872-bc29-279f7a170c2f"],
Cell[8524, 269, 1407, 36, 321, "Input",ExpressionUUID->"8af8deb2-f79b-437a-afd3-8f1b261ffa8d"],
Cell[CellGroupData[{
Cell[9956, 309, 1171, 31, 136, "Input",ExpressionUUID->"96b34ba1-4312-4361-8be6-ee2c08253dbe"],
Cell[11130, 342, 11087, 186, 242, "Output",ExpressionUUID->"c8fbd7c0-478d-4993-8bea-c3f65e3f3a47"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22266, 534, 171, 3, 45, "Subsubsection",ExpressionUUID->"f245cd68-4f50-4240-a0ba-20e165d745df"],
Cell[22440, 539, 3326, 93, 95, "Input",ExpressionUUID->"25eefafa-d5f5-4a0d-a513-f588b3fd02fa"],
Cell[25769, 634, 184, 3, 35, "Text",ExpressionUUID->"f507d127-a9d7-4b95-8f1e-ce34c2371115"],
Cell[25956, 639, 330, 9, 47, "Input",ExpressionUUID->"36d91122-8cf9-481c-91b7-13e447bd8e4d"],
Cell[26289, 650, 171, 3, 35, "Text",ExpressionUUID->"5ec8ca6a-e418-4ef1-9b19-b5c85bbfbba6"],
Cell[26463, 655, 406, 11, 46, "Input",ExpressionUUID->"d4f0fd67-bc07-4d65-a441-c088310492d2"],
Cell[26872, 668, 171, 3, 35, "Text",ExpressionUUID->"4badf3eb-9cde-4964-a3d9-591af2b4cfa1"],
Cell[27046, 673, 1136, 36, 63, "Input",ExpressionUUID->"e1a3d335-592b-418f-a51a-424b1e4723a9"],
Cell[28185, 711, 691, 22, 65, "Input",ExpressionUUID->"271febe2-097c-49f8-879e-793ffb240a85"],
Cell[28879, 735, 244, 4, 35, "Text",ExpressionUUID->"3c0bc073-af7f-44d7-8b9a-5de0f1fea88e"],
Cell[29126, 741, 2066, 54, 302, "Input",ExpressionUUID->"f278e38d-40fe-4bbd-8f81-83c3fbb26cd9"],
Cell[CellGroupData[{
Cell[31217, 799, 1188, 31, 136, "Input",ExpressionUUID->"f94b6a31-780d-4261-b5ba-a12eef354873"],
Cell[32408, 832, 20208, 318, 242, "Output",ExpressionUUID->"2b6a2f28-2886-4a16-8d66-8f3d54b2a437"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[52665, 1156, 182, 3, 45, "Subsubsection",ExpressionUUID->"c1711543-2b41-495b-a8a5-d51438d5940c"],
Cell[52850, 1161, 609, 18, 45, "Input",ExpressionUUID->"555a157c-38a4-4320-b0b9-ecc2e0dff504"],
Cell[53462, 1181, 629, 16, 56, "Input",ExpressionUUID->"9da65e5f-e85a-4217-83ff-fbcbe5e872d0"],
Cell[CellGroupData[{
Cell[54116, 1201, 1120, 29, 136, "Input",ExpressionUUID->"ec66f28e-7f1a-457e-981a-a98a71d72109"],
Cell[55239, 1232, 14039, 234, 242, "Output",ExpressionUUID->"9a3abf2e-e16f-4501-b7c7-a2e00a84c27e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[69327, 1472, 182, 3, 45, "Subsubsection",ExpressionUUID->"a0f8edc4-e184-4da8-bb5b-57b97345b13f"],
Cell[69512, 1477, 3328, 96, 99, "Input",ExpressionUUID->"3a810217-6353-48e3-b060-54a9fda8d070"],
Cell[72843, 1575, 1388, 45, 71, "Input",ExpressionUUID->"6bb09515-963c-45cd-9528-93cca314c5f1"],
Cell[74234, 1622, 1275, 39, 76, "Input",ExpressionUUID->"9eb4a583-6567-4970-8cdf-a24ea3c40e57"],
Cell[75512, 1663, 1267, 39, 89, "Input",ExpressionUUID->"0f56d00d-e7b9-472f-80a4-db423ee6701c"],
Cell[CellGroupData[{
Cell[76804, 1706, 1158, 28, 94, "Input",ExpressionUUID->"851e3960-72f5-4ca3-b4ac-6d233acbd095"],
Cell[77965, 1736, 19837, 320, 243, "Output",ExpressionUUID->"53631a6e-c6fd-4138-b62e-843d39ba81d6"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[97863, 2063, 177, 3, 54, "Subsection",ExpressionUUID->"ec8235a4-34aa-4b2b-802f-3a4b5ed719d5"],
Cell[98043, 2068, 10363, 242, 1329, "Input",ExpressionUUID->"5109478a-5a54-4ddc-a2cc-72d2acb2b641"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108443, 2315, 154, 3, 54, "Subsection",ExpressionUUID->"67c55ee6-3990-4a4d-814e-04945dd0b53a"],
Cell[108600, 2320, 640, 16, 94, "Input",ExpressionUUID->"b6eec451-6f68-40ef-b195-0c2999a80e7a"],
Cell[CellGroupData[{
Cell[109265, 2340, 333, 6, 30, "Input",ExpressionUUID->"767a5a9f-a808-422f-a44f-a6d202532023"],
Cell[CellGroupData[{
Cell[109623, 2350, 547, 12, 24, "Print",ExpressionUUID->"88c3c332-b92b-4f05-b75f-7ceb1be6bb5b"],
Cell[110173, 2364, 550, 12, 24, "Print",ExpressionUUID->"e57812cc-92c9-4116-b39b-69e8381b9c9a"],
Cell[110726, 2378, 551, 12, 24, "Print",ExpressionUUID->"07b11239-3779-4b5e-9dbc-ed40b89f0c72"],
Cell[111280, 2392, 551, 12, 24, "Print",ExpressionUUID->"43882d0d-dc51-4b64-8c81-f608efdff74f"],
Cell[111834, 2406, 551, 12, 24, "Print",ExpressionUUID->"dc887ec6-4cf3-4311-80da-8b682a8741d8"],
Cell[112388, 2420, 551, 12, 24, "Print",ExpressionUUID->"da71e30b-4b1c-4d5c-a860-5790bd0c2de3"],
Cell[112942, 2434, 551, 12, 24, "Print",ExpressionUUID->"2a3a2eca-94e2-41f0-8631-740a637c7436"],
Cell[113496, 2448, 551, 12, 24, "Print",ExpressionUUID->"b6d368c8-b0ea-4820-a0c4-685954f219f7"],
Cell[114050, 2462, 551, 12, 24, "Print",ExpressionUUID->"327c9413-daed-4c47-9497-a4d4daf3e412"],
Cell[114604, 2476, 551, 12, 24, "Print",ExpressionUUID->"043ee5c0-a3c2-459c-bcd9-13e5f5b10246"],
Cell[115158, 2490, 551, 12, 24, "Print",ExpressionUUID->"981c3fdb-324f-4f73-b4b4-f91be0d092ee"],
Cell[115712, 2504, 553, 12, 24, "Print",ExpressionUUID->"4af65d96-4eec-43d3-aa1c-89ba6f8a723f"],
Cell[116268, 2518, 553, 12, 24, "Print",ExpressionUUID->"1791d2c7-a49f-4dfe-a567-bad4dfcca2cb"],
Cell[116824, 2532, 551, 12, 24, "Print",ExpressionUUID->"5656e561-a009-4e13-a809-59ea56e783ac"],
Cell[117378, 2546, 551, 12, 24, "Print",ExpressionUUID->"d688b37c-711d-44c4-bf52-1386c84f6950"],
Cell[117932, 2560, 549, 12, 24, "Print",ExpressionUUID->"736ad9a4-012c-4301-acc5-25c75d86d1a1"],
Cell[118484, 2574, 550, 12, 24, "Print",ExpressionUUID->"f7391ba9-f6e6-4f5b-ae8f-a5e8659edacd"]
}, Open  ]],
Cell[119049, 2589, 347, 6, 34, "Output",ExpressionUUID->"d6bc0dba-28a0-4db4-bd68-095c8af92880"]
}, Open  ]],
Cell[119411, 2598, 189, 3, 35, "Text",ExpressionUUID->"591a5d66-db97-4e8a-bffb-eb9bf31e632e"],
Cell[CellGroupData[{
Cell[119625, 2605, 261, 5, 30, "Input",ExpressionUUID->"60dedfbe-0840-4b25-aeb0-f052ad7f71ff"],
Cell[119889, 2612, 242, 4, 34, "Output",ExpressionUUID->"768d7073-3b62-4245-9516-2164655bf52a"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[120192, 2623, 170, 3, 67, "Section",ExpressionUUID->"d8007b2d-f1df-4daa-8ec1-9e9e9f53404b"],
Cell[CellGroupData[{
Cell[120387, 2630, 200, 3, 54, "Subsection",ExpressionUUID->"fdd65857-5a72-46d3-9f79-f214f161ff3a"],
Cell[CellGroupData[{
Cell[120612, 2637, 195, 3, 45, "Subsubsection",ExpressionUUID->"78adb377-82dd-4218-a7e2-cff9000b4c48"],
Cell[120810, 2642, 454, 13, 57, "Input",ExpressionUUID->"909d7c8b-a558-4395-bbfa-b553050d13ae"]
}, Open  ]],
Cell[CellGroupData[{
Cell[121301, 2660, 170, 3, 45, "Subsubsection",ExpressionUUID->"bfe260f4-897d-4246-a760-f4da1b8a2669"],
Cell[121474, 2665, 157, 3, 35, "Text",ExpressionUUID->"4258c202-2928-4723-a2ec-1f4f99a46555"],
Cell[121634, 2670, 579, 19, 61, "Input",ExpressionUUID->"4d3bb706-5acd-4d22-ab54-54f3748ff326"],
Cell[122216, 2691, 550, 15, 47, "Input",ExpressionUUID->"84c9c873-d266-4fc6-8933-8308b36a00e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[122803, 2711, 188, 3, 45, "Subsubsection",ExpressionUUID->"a81d9df1-c219-48f9-89cb-cc4ce420a8d9"],
Cell[122994, 2716, 486, 16, 45, "Input",ExpressionUUID->"293600be-f507-4967-bce5-de8c62eb8ca3"],
Cell[123483, 2734, 409, 13, 56, "Input",ExpressionUUID->"0b593f6a-db90-44ec-9036-e567bd48fb35"],
Cell[123895, 2749, 556, 17, 57, "Input",ExpressionUUID->"5a9fac96-a90b-4509-abe1-6458dd0fbe19"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[124500, 2772, 177, 3, 54, "Subsection",ExpressionUUID->"64ef6475-2da4-430c-bb79-057770878448"],
Cell[124680, 2777, 8862, 206, 1007, "Input",ExpressionUUID->"06419842-68c0-4b0c-9600-2fd6acbac50a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133579, 2988, 154, 3, 54, "Subsection",ExpressionUUID->"2148af0f-3ffa-4847-a36a-06bfe82c51e6"],
Cell[133736, 2993, 640, 16, 94, "Input",ExpressionUUID->"ffc13dfe-5cbd-41d4-99c4-96f1c4dc34cb"],
Cell[CellGroupData[{
Cell[134401, 3013, 324, 6, 30, "Input",ExpressionUUID->"fcefae4b-b588-462f-b528-c0a1f14420c1"],
Cell[CellGroupData[{
Cell[134750, 3023, 501, 11, 24, "Print",ExpressionUUID->"16222ab2-f583-49bb-b643-04070a25a44e"],
Cell[135254, 3036, 497, 11, 24, "Print",ExpressionUUID->"305c7028-9662-45de-ae11-3eb73baa2828"],
Cell[135754, 3049, 497, 11, 24, "Print",ExpressionUUID->"15363a36-7a67-492f-bf79-5ef5d8a7eb0b"],
Cell[136254, 3062, 495, 11, 24, "Print",ExpressionUUID->"83fd2a48-8afc-4e59-8699-eab5e825b11e"],
Cell[136752, 3075, 495, 11, 24, "Print",ExpressionUUID->"685d121b-5cc5-4f55-b858-5f4d6e3171e9"],
Cell[137250, 3088, 497, 11, 24, "Print",ExpressionUUID->"bde8fa31-fd69-4da0-b79a-65698df82c97"],
Cell[137750, 3101, 497, 11, 24, "Print",ExpressionUUID->"e312670d-18bd-4c2a-904b-64612ffe775c"],
Cell[138250, 3114, 499, 11, 24, "Print",ExpressionUUID->"626a65cd-fe65-4250-a45f-5de2a558e2b1"],
Cell[138752, 3127, 497, 11, 24, "Print",ExpressionUUID->"b83f9643-db9a-4e24-b3f9-ac2559ace814"],
Cell[139252, 3140, 499, 11, 24, "Print",ExpressionUUID->"8990bbd1-3e6b-4470-b037-7989a0bebe71"],
Cell[139754, 3153, 497, 11, 24, "Print",ExpressionUUID->"4fcc39b6-4a02-4eef-b0d7-a81bb49dc23d"],
Cell[140254, 3166, 497, 11, 24, "Print",ExpressionUUID->"b465c579-b06f-488f-a746-9c18239c8b99"],
Cell[140754, 3179, 501, 11, 24, "Print",ExpressionUUID->"16a4c2e6-ae54-4541-a82e-c5efdb8e97b1"]
}, Open  ]],
Cell[141270, 3193, 297, 5, 34, "Output",ExpressionUUID->"ce91643a-f024-4b04-adf5-8cc758d08550"]
}, Open  ]],
Cell[141582, 3201, 189, 3, 35, "Text",ExpressionUUID->"185425e9-7347-4054-b589-763bdaa4ac54"],
Cell[CellGroupData[{
Cell[141796, 3208, 261, 5, 30, "Input",ExpressionUUID->"dd02c5c2-10aa-4313-8a1b-3cd0d7541251"],
Cell[142060, 3215, 195, 3, 34, "Output",ExpressionUUID->"faf4922d-b0b9-458b-97be-d96786a08bc2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

